# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Colorado."""


ADAMS = "001"
ALAMOSA = "003"
ARAPAHOE = "005"
ARCHULETA = "007"
BACA = "009"
BENT = "011"
BOULDER = "013"
BROOMFIELD = "014"
CHAFFEE = "015"
CHEYENNE = "017"
CLEAR_CREEK = "019"
CONEJOS = "021"
COSTILLA = "023"
CROWLEY = "025"
CUSTER = "027"
DELTA = "029"
DENVER = "031"
DOLORES = "033"
DOUGLAS = "035"
EAGLE = "037"
EL_PASO = "041"
ELBERT = "039"
FREMONT = "043"
GARFIELD = "045"
GILPIN = "047"
GRAND = "049"
GUNNISON = "051"
HINSDALE = "053"
HUERFANO = "055"
JACKSON = "057"
JEFFERSON = "059"
KIOWA = "061"
KIT_CARSON = "063"
LA_PLATA = "067"
LAKE = "065"
LARIMER = "069"
LAS_ANIMAS = "071"
LINCOLN = "073"
LOGAN = "075"
MESA = "077"
MINERAL = "079"
MOFFAT = "081"
MONTEZUMA = "083"
MONTROSE = "085"
MORGAN = "087"
OTERO = "089"
OURAY = "091"
PARK = "093"
PHILLIPS = "095"
PITKIN = "097"
PROWERS = "099"
PUEBLO = "101"
RIO_BLANCO = "103"
RIO_GRANDE = "105"
ROUTT = "107"
SAGUACHE = "109"
SAN_JUAN = "111"
SAN_MIGUEL = "113"
SEDGWICK = "115"
SUMMIT = "117"
TELLER = "119"
WASHINGTON = "121"
WELD = "123"
YUMA = "125"
