# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Oklahoma."""


ACHILLE_TOWN = "00100"
ADA_CITY = "00200"
ADAIR_TOWN = "00250"
ADAMS_CDP = "00300"
ADAMSON_CDP = "00350"
ADDINGTON_TOWN = "00450"
AFTON_TOWN = "00600"
AGRA_TOWN = "00700"
AKINS_CDP = "00900"
ALBANY_CDP = "00950"
ALBION_TOWN = "01050"
ALDERSON_TOWN = "01150"
ALEX_TOWN = "01250"
ALINE_TOWN = "01350"
ALLEN_TOWN = "01400"
ALTUS_CITY = "01700"
ALVA_CITY = "01800"
AMBER_TOWN = "01900"
AMES_TOWN = "01950"
AMORITA_TOWN = "02000"
ANADARKO_CITY = "02050"
ANTLERS_CITY = "02250"
APACHE_TOWN = "02300"
ARAPAHO_TOWN = "02500"
ARCADIA_TOWN = "02550"
ARDMORE_CITY = "02600"
ARKOMA_TOWN = "02650"
ARMSTRONG_TOWN = "02750"
ARNETT_TOWN = "02800"
ARPELAR_CDP = "02900"
ASHER_TOWN = "03000"
ASHLAND_TOWN = "03050"
ATOKA_CITY = "03300"
ATWOOD_TOWN = "03350"
AVANT_TOWN = "03500"
AVARD_CDP = "03550"
BACHE_CDP = "03750"
BADGER_LEE_CDP = "03815"
BAKER_CDP = "03900"
BALLOU_CDP = "04075"
BARBER_CDP = "04200"
BARNSDALL_CITY = "04250"
BARON_CDP = "04350"
BARTLESVILLE_CITY = "04450"
BEARDEN_TOWN = "04700"
BEAVER_TOWN = "04750"
BEE_CDP = "04950"
BEGGS_CITY = "05000"
BELFONTE_CDP = "05070"
BELL_CDP = "05090"
BENNINGTON_TOWN = "05400"
BENTLEY_CDP = "05450"
BERNICE_TOWN = "05550"
BESSIE_TOWN = "05650"
BETHANY_CITY = "05700"
BETHEL_ACRES_TOWN = "05800"
BIG_CABIN_TOWN = "05900"
BILLINGS_TOWN = "06100"
BINGER_TOWN = "06200"
BISON_CDP = "06350"
BIXBY_CITY = "06400"
BLACKBURN_TOWN = "06450"
BLACKGUM_CDP = "06500"
BLACKWELL_CITY = "06600"
BLAIR_TOWN = "06650"
BLANCHARD_CITY = "06700"
BLANCO_CDP = "06750"
BLUE_CDP = "06900"
BLUEJACKET_TOWN = "06950"
BOISE_CITY_CITY = "07300"
BOKCHITO_TOWN = "07350"
BOKOSHE_TOWN = "07450"
BOLEY_TOWN = "07500"
BOSWELL_TOWN = "07750"
BOWLEGS_TOWN = "07950"
BOWRING_CDP = "08000"
BOX_CDP = "08050"
BOYNTON_TOWN = "08150"
BRADLEY_TOWN = "08300"
BRAGGS_TOWN = "08400"
BRAMAN_TOWN = "08450"
BRAY_TOWN = "08550"
BRECKENRIDGE_TOWN = "08600"
BRENT_CDP = "08650"
BRIARTOWN_CDP = "08700"
BRIDGE_CREEK_TOWN = "08725"
BRIDGEPORT_CITY = "08750"
BRIGGS_CDP = "08775"
BRISTOW_CITY = "08900"
BROKEN_ARROW_CITY = "09050"
BROKEN_BOW_CITY = "09100"
BROMIDE_TOWN = "09150"
BROOKSVILLE_TOWN = "09400"
BRUSH_CREEK_CDP = "09612"
BRUSHY_CDP = "09650"
BRYANT_CDP = "09700"
BUFFALO_TOWN = "09850"
BUG_TUSSLE_CDP = "09875"
BULL_HOLLOW_CDP = "09887"
BUNCH_CDP = "09900"
BURBANK_TOWN = "09950"
BURLINGTON_TOWN = "10050"
BURNEYVILLE_CDP = "10150"
BURNS_FLAT_TOWN = "10250"
BUSHYHEAD_CDP = "10400"
BUTLER_CDP = "10460"
BUTLER_TOWN = "10450"
BYARS_TOWN = "10550"
BYNG_TOWN = "10600"
BYRON_TOWN = "10650"
CACHE_CITY = "10700"
CADDO_TOWN = "10800"
CALERA_TOWN = "10950"
CALUMET_TOWN = "11050"
CALVIN_TOWN = "11100"
CAMARGO_TOWN = "11150"
CAMERON_TOWN = "11300"
CANADIAN_SHORES_CDP = "11530"
CANADIAN_TOWN = "11450"
CANEY_CDP = "11562"
CANEY_RIDGE_CDP = "11575"
CANEY_TOWN = "11550"
CANTON_TOWN = "11600"
CANUTE_TOWN = "11650"
CAPRON_TOWN = "11750"
CARLISLE_CDP = "11975"
CARLTON_LANDING_TOWN = "11990"
CARMEN_TOWN = "12000"
CARNEGIE_TOWN = "12050"
CARNEY_TOWN = "12100"
CARRIER_TOWN = "12200"
CARTER_TOWN = "12300"
CARTWRIGHT_CDP = "12550"
CASHION_TOWN = "12650"
CASTLE_TOWN = "12750"
CATOOSA_CITY = "12900"
CAVE_SPRING_CDP = "12910"
CAYUGA_CDP = "12915"
CEDAR_CREST_CDP = "12930"
CEDAR_LAKE_CDP = "12937"
CEDAR_VALLEY_CITY = "12960"
CEMENT_TOWN = "13000"
CENTRAHOMA_CITY = "13100"
CENTRAL_HIGH_TOWN = "13135"
CHANCE_CDP = "13475"
CHANDLER_CITY = "13500"
CHATTANOOGA_TOWN = "13600"
CHECOTAH_CITY = "13650"
CHELSEA_TOWN = "13700"
CHEROKEE_CITY = "13750"
CHERRY_TREE_CDP = "13775"
CHESTER_CDP = "13800"
CHEWEY_CDP = "13850"
CHEYENNE_TOWN = "13900"
CHICKASHA_CITY = "13950"
CHOCTAW_CITY = "14200"
CHOUTEAU_TOWN = "14300"
CHRISTIE_CDP = "14350"
CIMARRON_CITY_TOWN = "14500"
CLAREMORE_CITY = "14700"
CLARITA_CDP = "14750"
CLARKSVILLE_CDP = "14800"
CLAYTON_TOWN = "14900"
CLEARVIEW_TOWN = "15050"
CLEO_SPRINGS_TOWN = "15300"
CLEORA_CDP = "15250"
CLEVELAND_CITY = "15350"
CLINTON_CITY = "15400"
CLOUD_CREEK_CDP = "15625"
COALGATE_CITY = "15800"
COLBERT_TOWN = "16050"
COLCORD_TOWN = "16100"
COLE_TOWN = "16200"
COLEMAN_CDP = "16250"
COLLINSVILLE_CITY = "16350"
COLONY_TOWN = "16400"
COMANCHE_CITY = "16450"
COMMERCE_CITY = "16500"
CONNERVILLE_CDP = "16700"
COOKSON_CDP = "16950"
COOPERTON_TOWN = "17050"
COPAN_TOWN = "17100"
COPELAND_CDP = "17110"
CORN_TOWN = "17300"
CORNISH_TOWN = "17350"
COTTONWOOD_CDP = "17450"
COUNCIL_HILL_TOWN = "17550"
COVINGTON_TOWN = "17700"
COWETA_CITY = "17800"
COWLINGTON_TOWN = "17850"
COYLE_TOWN = "17950"
CRESCENT_SPRINGS_CDP = "18275"
CRESCENT_CITY = "18250"
CROMWELL_TOWN = "18450"
CROWDER_TOWN = "18550"
CUMBERLAND_CDP = "18750"
CUSHING_CITY = "18850"
CUSTER_CITY_TOWN = "18950"
CYRIL_TOWN = "19000"
DACOMA_TOWN = "19050"
DALE_CDP = "19150"
DAVENPORT_TOWN = "19350"
DAVIDSON_TOWN = "19400"
DAVIS_CITY = "19450"
DEER_CREEK_TOWN = "19650"
DEER_LICK_CDP = "19665"
DEL_CITY_CITY = "19900"
DELAWARE_TOWN = "19850"
DENNIS_CDP = "20100"
DEPEW_TOWN = "20300"
DEVOL_TOWN = "20450"
DEWAR_TOWN = "20500"
DEWEY_CITY = "20550"
DIBBLE_TOWN = "20650"
DICKSON_TOWN = "20700"
DILL_CITY_TOWN = "20850"
DISNEY_TOWN = "20900"
DIXON_CDP = "21000"
DODGE_CDP = "21020"
DOTYVILLE_CDP = "21150"
DOUGHERTY_TOWN = "21200"
DOUGLAS_TOWN = "21250"
DOVER_TOWN = "21350"
DRIPPING_SPRINGS_CDP = "21672"
DROWNING_CREEK_CDP = "21676"
DRUMMOND_TOWN = "21700"
DRUMRIGHT_CITY = "21750"
DRY_CREEK_CDP = "21755"
DUCHESS_LANDING_CDP = "21760"
DUNCAN_CITY = "21900"
DURANT_CITY = "22050"
DURHAM_CDP = "22100"
DUSTIN_TOWN = "22200"
DWIGHT_MISSION_CDP = "22275"
EAGLE_CITY_CDP = "22300"
EAGLETOWN_CDP = "22350"
EAKLY_TOWN = "22400"
EARL_CDP = "22450"
EARLSBORO_TOWN = "22500"
EAST_DUKE_TOWN = "22550"
EDGEWATER_PARK_CDP = "23100"
EDMOND_CITY = "23200"
EL_RENO_CITY = "23700"
ELDON_CDP = "23300"
ELDORADO_TOWN = "23350"
ELGIN_CITY = "23450"
ELK_CITY_CITY = "23500"
ELM_GROVE_CDP = "23575"
ELMER_TOWN = "23550"
ELMORE_CITY_TOWN = "23600"
ELOHIM_CITY_CDP = "23675"
EMET_CDP = "23850"
EMPIRE_CITY_TOWN = "23900"
ENID_CITY = "23950"
ENTERPRISE_CDP = "24050"
ERICK_CITY = "24200"
ERIN_SPRINGS_TOWN = "24300"
ETOWAH_TOWN = "24460"
ETTA_CDP = "24500"
EUFAULA_CITY = "24650"
EVENING_SHADE_CDP = "24762"
FAIR_OAKS_TOWN = "25000"
FAIRFAX_TOWN = "24850"
FAIRFIELD_CDP = "24875"
FAIRLAND_TOWN = "24900"
FAIRMONT_TOWN = "24950"
FAIRVIEW_CITY = "25100"
FALLIS_TOWN = "25250"
FANSHAWE_TOWN = "25400"
FARGO_TOWN = "25450"
FAXON_TOWN = "25650"
FAY_CDP = "25700"
FELT_CDP = "25850"
FINLEY_CDP = "26000"
FITTSTOWN_CDP = "26200"
FITZHUGH_TOWN = "26250"
FLETCHER_TOWN = "26350"
FLINT_CREEK_CDP = "26415"
FLUTE_SPRINGS_CDP = "26525"
FORAKER_TOWN = "26750"
FOREST_PARK_TOWN = "26850"
FORGAN_TOWN = "26900"
FORT_COBB_TOWN = "27100"
FORT_COFFEE_TOWN = "27150"
FORT_GIBSON_TOWN = "27200"
FORT_SUPPLY_TOWN = "27350"
FORT_TOWSON_TOWN = "27400"
FOSS_TOWN = "27450"
FOSTER_TOWN = "27500"
FOX_CDP = "27550"
FOYIL_TOWN = "27600"
FRANCIS_TOWN = "27650"
FREDERICK_CITY = "27800"
FREEDOM_TOWN = "27850"
FRIENDSHIP_TOWN = "27900"
GAGE_TOWN = "28250"
GANS_TOWN = "28350"
GARBER_CITY = "28500"
GARVIN_TOWN = "28700"
GATE_TOWN = "28800"
GEARY_CITY = "28900"
GENE_AUTRY_TOWN = "28950"
GERONIMO_TOWN = "29100"
GERTY_TOWN = "29150"
GIDEON_CDP = "29300"
GLENCOE_TOWN = "29400"
GLENPOOL_CITY = "29600"
GOLDEN_CDP = "29800"
GOLDSBY_TOWN = "29850"
GOLTRY_TOWN = "29900"
GOODWELL_TOWN = "30200"
GORE_TOWN = "30300"
GOTEBO_TOWN = "30350"
GOULD_TOWN = "30400"
GOWEN_CDP = "30500"
GRACEMONT_TOWN = "30600"
GRAINOLA_TOWN = "30750"
GRAND_LAKE_TOWNE_TOWN = "30900"
GRANDFIELD_CITY = "30850"
GRANDVIEW_CDP = "30915"
GRANITE_TOWN = "30950"
GRANT_CDP = "31000"
GRAYSON_TOWN = "31150"
GREASY_CDP = "31165"
GREENFIELD_TOWN = "31250"
GREENVILLE_CDP = "31375"
GREGORY_CDP = "31425"
GROVE_CITY = "31600"
GUTHRIE_CITY = "31700"
GUYMON_CITY = "31750"
HAILEYVILLE_CITY = "31900"
HALLETT_TOWN = "32050"
HAMMON_TOWN = "32250"
HANNA_TOWN = "32350"
HANSON_CDP = "32400"
HARDESTY_TOWN = "32550"
HARRAH_CITY = "32750"
HARTSHORNE_CITY = "32850"
HASKELL_TOWN = "32900"
HASTINGS_TOWN = "33000"
HAWORTH_TOWN = "33150"
HAYWOOD_CDP = "33250"
HEADRICK_TOWN = "33300"
HEALDTON_CITY = "33350"
HEAVENER_CITY = "33400"
HELENA_TOWN = "33450"
HENDRIX_TOWN = "33600"
HENNEPIN_CDP = "33650"
HENNESSEY_TOWN = "33700"
HENRYETTA_CITY = "33750"
HICKORY_TOWN = "34150"
HILLSDALE_TOWN = "34650"
HINTON_TOWN = "34750"
HITCHCOCK_TOWN = "34850"
HITCHITA_TOWN = "34900"
HOBART_CITY = "35000"
HOCHATOWN_CDP = "35030"
HODGEN_CDP = "35150"
HOFFMAN_TOWN = "35300"
HOLDENVILLE_CITY = "35400"
HOLLIS_CITY = "35500"
HOLLISTER_TOWN = "35550"
HOMESTEAD_CDP = "35800"
HOMINY_CITY = "35850"
HONEY_HILL_CDP = "35875"
HOOKER_CITY = "36000"
HOOT_OWL_TOWN = "36020"
HOPETON_CDP = "36050"
HORNTOWN_TOWN = "36090"
HOUGH_CDP = "36115"
HOWE_TOWN = "36150"
HOYT_CDP = "36200"
HUGO_CITY = "36300"
HULBERT_TOWN = "36400"
HUNTER_TOWN = "36600"
HYDRO_TOWN = "36700"
IXL_TOWN = "37410"
IDABEL_CITY = "36750"
INDIAHOMA_TOWN = "36850"
INDIANOLA_CDP = "36945"
INDIANOLA_TOWN = "36950"
INGALLS_CDP = "37000"
INOLA_TOWN = "37100"
IRON_POST_CDP = "37275"
ISABELLA_CDP = "37350"
JAY_CITY = "37650"
JEFFERSON_TOWN = "37750"
JENKS_CITY = "37800"
JENNINGS_TOWN = "37850"
JET_TOWN = "38000"
JOHNSON_PRAIRIE_CDP = "38201"
JOHNSON_TOWN = "38200"
JONES_TOWN = "38350"
JUSTICE_CDP = "38475"
KANSAS_TOWN = "38600"
KATIE_TOWN = "38700"
KAW_CITY_CITY = "38800"
KEEFTON_CDP = "38850"
KELLYVILLE_TOWN = "39000"
KEMP_TOWN = "39050"
KENDRICK_TOWN = "39150"
KENEFIC_TOWN = "39200"
KENTON_CDP = "39400"
KENWOOD_CDP = "39450"
KEOTA_TOWN = "39500"
KETCHUM_TOWN = "39550"
KEYES_TOWN = "39600"
KEYS_CDP = "39625"
KIEFER_TOWN = "39750"
KILDARE_TOWN = "39800"
KINGFISHER_CITY = "39850"
KINGSTON_TOWN = "39900"
KINTA_TOWN = "39950"
KIOWA_TOWN = "40000"
KNOWLES_TOWN = "40100"
KONAWA_CITY = "40200"
KREBS_CITY = "40300"
KREMLIN_TOWN = "40400"
LAHOMA_TOWN = "40700"
LAKE_ALUMA_TOWN = "40800"
LAKE_ELLSWORTH_ADDITION_CDP = "40875"
LAKESIDE_VILLAGE_CDP = "41050"
LAMAR_TOWN = "41250"
LAMBERT_TOWN = "41300"
LAMONT_TOWN = "41350"
LANE_CDP = "41400"
LANGLEY_TOWN = "41500"
LANGSTON_TOWN = "41550"
LATTA_CDP = "41680"
LAVERNE_TOWN = "41700"
LAWRENCE_CREEK_TOWN = "41760"
LAWTON_CITY = "41850"
LAWTONKA_ACRES_CDP = "41856"
LE_FLORE_TOWN = "42150"
LEACH_CDP = "41900"
LEBANON_CDP = "41950"
LEEDEY_TOWN = "42050"
LEHIGH_CITY = "42200"
LENAPAH_TOWN = "42300"
LEON_TOWN = "42450"
LEONARD_CDP = "42500"
LEQUIRE_CDP = "42600"
LEXINGTON_CITY = "42700"
LIBERTY_CDP = "42850"
LIBERTY_TOWN = "42860"
LIMA_TOWN = "43000"
LIMESTONE_CDP = "43057"
LINDSAY_CITY = "43150"
LITTLE_CITY_CDP = "43400"
LITTLE_PONDEROSA_CDP = "43425"
LITTLE_ROCK_CDP = "43442"
LOCO_TOWN = "43450"
LOCUST_GROVE_TOWN = "43500"
LONE_CHIMNEY_TOWN = "43725"
LONE_GROVE_CITY = "43750"
LONE_WOLF_TOWN = "43850"
LONG_CDP = "43900"
LONGDALE_TOWN = "43950"
LONGTOWN_CDP = "43975"
LOOKEBA_TOWN = "44000"
LOST_CITY_CDP = "44075"
LOTSEE_TOWN = "44100"
LOVELAND_TOWN = "44150"
LOVELL_CDP = "44200"
LOWREY_CDP = "44275"
LOYAL_TOWN = "44300"
LUCIEN_CDP = "44350"
LUTHER_TOWN = "44500"
LYONS_SWITCH_CDP = "44775"
MACOMB_TOWN = "45500"
MADILL_CITY = "45750"
MALLARD_BAY_CDP = "45930"
MANCHESTER_TOWN = "46000"
MANGUM_CITY = "46050"
MANITOU_TOWN = "46150"
MANNFORD_TOWN = "46200"
MANNSVILLE_TOWN = "46300"
MARAMEC_TOWN = "46400"
MARBLE_CITY_TOWN = "46450"
MARIETTA_CDP = "46488"
MARIETTA_CITY = "46500"
MARLAND_TOWN = "46550"
MARLOW_CITY = "46600"
MARSHALL_TOWN = "46650"
MARTHA_TOWN = "46700"
MAUD_CITY = "46900"
MAY_TOWN = "47000"
MAYSVILLE_TOWN = "47150"
MAZIE_CDP = "47200"
MCALESTER_CITY = "44800"
MCBRIDE_CDP = "44900"
MCCORD_CDP = "44925"
MCCURTAIN_TOWN = "44950"
MCLOUD_CITY = "45350"
MEAD_TOWN = "47250"
MEDFORD_CITY = "47300"
MEDICINE_PARK_TOWN = "47350"
MEEKER_TOWN = "47450"
MEHAN_CDP = "47550"
MENO_TOWN = "47750"
MERIDIAN_TOWN = "47800"
MIAMI_CITY = "48000"
MIDDLEBERG_CDP = "48100"
MIDWEST_CITY_CITY = "48350"
MILBURN_TOWN = "48400"
MILFAY_CDP = "48450"
MILL_CREEK_TOWN = "48500"
MILLERTON_TOWN = "48600"
MINCO_CITY = "48750"
MOFFETT_TOWN = "49000"
MONROE_CDP = "49050"
MOODYS_CDP = "49100"
MOORE_CITY = "49200"
MOORELAND_TOWN = "49250"
MORRIS_CITY = "49400"
MORRISON_TOWN = "49450"
MOUNDS_TOWN = "49550"
MOUNTAIN_PARK_TOWN = "49600"
MOUNTAIN_VIEW_TOWN = "49650"
MOYERS_CDP = "49750"
MULBERRY_CDP = "49825"
MULDROW_TOWN = "49850"
MULE_BARN_TOWN = "49860"
MULHALL_TOWN = "49900"
MURPHY_CDP = "49950"
MUSKOGEE_CITY = "50050"
MUSTANG_CITY = "50100"
MUTUAL_TOWN = "50150"
NARCISSA_CDP = "50200"
NARDIN_CDP = "50250"
NASH_TOWN = "50300"
NASHOBA_CDP = "50350"
NELAGONEY_CDP = "50800"
NESCATUNGA_CDP = "50975"
NEW_ALLUWE_TOWN = "51050"
NEW_CORDELL_CITY = "51250"
NEW_EUCHA_CDP = "51275"
NEW_WOODVILLE_TOWN = "51750"
NEWCASTLE_CITY = "51150"
NEWKIRK_CITY = "51300"
NICHOLS_HILLS_CITY = "51800"
NICOMA_PARK_CITY = "51850"
NICUT_CDP = "51900"
NINNEKAH_TOWN = "52100"
NOBLE_CITY = "52150"
NORGE_TOWN = "52450"
NORMAN_CITY = "52500"
NORTH_ENID_TOWN = "52600"
NORTH_MIAMI_TOWN = "52700"
NORWOOD_CDP = "52859"
NOTCHIETOWN_CDP = "52862"
NOWATA_CITY = "52900"
OAK_GROVE_TOWN = "53210"
OAK_HILL_PINEY_CDP = "53301"
OAKHURST_CDP = "53350"
OAKLAND_TOWN = "53400"
OAKS_TOWN = "53550"
OAKWOOD_TOWN = "53600"
OCHELATA_TOWN = "53700"
OILTON_CITY = "54000"
OKARCHE_TOWN = "54050"
OKAY_TOWN = "54100"
OKEENE_TOWN = "54150"
OKEMAH_CITY = "54200"
OKLAHOMA_CITY_CITY = "55000"
OKMULGEE_CITY = "55150"
OKTAHA_TOWN = "55200"
OLD_EUCHA_CDP = "55275"
OLD_GREEN_CDP = "55285"
OLIVE_CDP = "55350"
OLUSTEE_TOWN = "55450"
OOLOGAH_TOWN = "55750"
OPTIMA_TOWN = "55850"
ORLANDO_TOWN = "56050"
OSAGE_TOWN = "56150"
OWASSO_CITY = "56650"
PADEN_TOWN = "56800"
PANAMA_TOWN = "56900"
PANOLA_CDP = "56950"
PAOLI_TOWN = "57100"
PARADISE_HILL_TOWN = "57150"
PARK_HILL_CDP = "57300"
PAULS_VALLEY_CITY = "57550"
PAWHUSKA_CITY = "57600"
PAWNEE_CITY = "57650"
PEAVINE_CDP = "57875"
PECKHAM_CDP = "57900"
PEGGS_CDP = "57950"
PENSACOLA_TOWN = "58050"
PEORIA_TOWN = "58100"
PERKINS_CITY = "58150"
PERRY_CITY = "58250"
PERSHING_CDP = "58300"
PETTIT_CDP = "58400"
PHILLIPS_TOWN = "58500"
PICKETT_CDP = "58650"
PIEDMONT_CITY = "58700"
PIN_OAK_ACRES_CDP = "59175"
PINEY_CDP = "59100"
PINHOOK_CORNER_CDP = "59125"
PINK_TOWN = "59150"
PITTSBURG_TOWN = "59350"
PLATTER_CDP = "59500"
POCASSET_TOWN = "59700"
POCOLA_TOWN = "59750"
PONCA_CITY_CITY = "59850"
POND_CREEK_CITY = "59950"
PONTOTOC_CDP = "60000"
PORTER_TOWN = "60150"
PORUM_TOWN = "60250"
POTEAU_CITY = "60350"
PRAGUE_CITY = "60500"
PRESTON_CDP = "60650"
PROCTOR_CDP = "60750"
PRUE_TOWN = "60850"
PRYOR_CREEK_CITY = "61000"
PUMP_BACK_CDP = "61020"
PUMPKIN_HOLLOW_CDP = "61113"
PURCELL_CITY = "61150"
PUTNAM_TOWN = "61250"
QUAPAW_TOWN = "61400"
QUAY_CDP = "61450"
QUINLAN_CDP = "61500"
QUINTON_TOWN = "61550"
RALSTON_TOWN = "61650"
RAMONA_TOWN = "61700"
RANDLETT_TOWN = "61850"
RATLIFF_CITY_TOWN = "61900"
RATTAN_TOWN = "61950"
RAVIA_TOWN = "62000"
REAGAN_CDP = "62100"
RED_OAK_TOWN = "62550"
RED_ROCK_TOWN = "62650"
REDBIRD_SMITH_CDP = "62275"
REDBIRD_TOWN = "62200"
REMY_CDP = "62875"
RENFROW_TOWN = "62900"
RENTIESVILLE_TOWN = "62950"
REYDON_TOWN = "63100"
RINGLING_TOWN = "63350"
RINGWOOD_TOWN = "63450"
RIPLEY_TOWN = "63500"
RIVER_BOTTOM_CDP = "63537"
ROCK_ISLAND_TOWN = "63600"
ROCKY_FORD_CDP = "63715"
ROCKY_MOUNTAIN_CDP = "63720"
ROCKY_POINT_CDP = "63730"
ROCKY_TOWN = "63700"
ROFF_TOWN = "63750"
ROLAND_TOWN = "63800"
ROOSEVELT_TOWN = "63900"
ROSE_CDP = "63950"
ROSEDALE_TOWN = "64000"
ROSSTON_TOWN = "64050"
RUSH_SPRINGS_TOWN = "64300"
RYAN_TOWN = "64600"
SALINA_TOWN = "64950"
SALLISAW_CITY = "65000"
SAMS_CORNER_CDP = "65062"
SAND_HILL_CDP = "65240"
SAND_POINT_CDP = "65250"
SAND_SPRINGS_CITY = "65300"
SAPULPA_CITY = "65400"
SASAKWA_TOWN = "65500"
SAVANNA_TOWN = "65600"
SAWYER_TOWN = "65650"
SAYRE_CITY = "65700"
SCHULTER_TOWN = "65900"
SCIPIO_CDP = "65950"
SEILING_CITY = "66250"
SELMAN_CDP = "66300"
SEMINOLE_CITY = "66350"
SENTINEL_TOWN = "66400"
SEQUOYAH_CDP = "66450"
SEWARD_CDP = "66500"
SHADY_GROVE_CDP_CHEROKEE_COUNTY = "66510"
SHADY_GROVE_CDP_MCINTOSH_COUNTY = "66520"
SHADY_POINT_TOWN = "66550"
SHAMROCK_TOWN = "66600"
SHARON_TOWN = "66650"
SHATTUCK_TOWN = "66750"
SHAWNEE_CITY = "66800"
SHIDLER_CITY = "67200"
SHORT_CDP = "67400"
SILO_TOWN = "67550"
SIMMS_CDP = "67625"
SKEDEE_TOWN = "67800"
SKIATOOK_CITY = "67850"
SLAUGHTERVILLE_TOWN = "67950"
SLICK_TOWN = "68000"
SMITH_VILLAGE_TOWN = "68200"
SMITHVILLE_TOWN = "68250"
SNAKE_CREEK_CDP = "68275"
SNYDER_CITY = "68400"
SOPER_TOWN = "68500"
SOUR_JOHN_CDP = "68537"
SOUTH_COFFEYVILLE_TOWN = "68600"
SPARKS_TOWN = "68950"
SPARROWHAWK_CDP = "68951"
SPAULDING_TOWN = "69000"
SPAVINAW_TOWN = "69050"
SPENCER_CITY = "69200"
SPERRY_TOWN = "69300"
SPIRO_TOWN = "69350"
SPORTMANS_SHORES_CDP = "69392"
SPORTSMEN_ACRES_TOWN = "69400"
SPRINGER_TOWN = "69500"
ST_LOUIS_TOWN = "64850"
STEELY_HOLLOW_CDP = "70037"
STERLING_TOWN = "70150"
STIDHAM_TOWN = "70200"
STIGLER_CITY = "70250"
STILLWATER_CITY = "70300"
STILWELL_CITY = "70350"
STONEWALL_TOWN = "70500"
STONEY_POINT_CDP = "70512"
STRANG_TOWN = "70750"
STRATFORD_TOWN = "70800"
STRINGTOWN_TOWN = "70850"
STRONG_CITY_TOWN = "70950"
STROUD_CITY = "71000"
STUART_TOWN = "71050"
SUGDEN_TOWN = "71250"
SULPHUR_CITY = "71350"
SUMMIT_TOWN = "71450"
SUMNER_CDP = "71500"
SUNRAY_CDP = "71650"
SWEETWATER_TOWN = "71900"
SWINK_CDP = "71950"
SYCAMORE_CDP = "71965"
TAFT_TOWN = "72050"
TAGG_FLATS_CDP = "72075"
TAHLEQUAH_CITY = "72100"
TALALA_TOWN = "72200"
TALIHINA_TOWN = "72250"
TALOGA_TOWN = "72350"
TAMAHA_TOWN = "72400"
TATUMS_TOWN = "72500"
TAYLOR_FERRY_CDP = "72610"
TECUMSEH_CITY = "72650"
TEMPLE_TOWN = "72750"
TENKILLER_CDP = "72775"
TERESITA_CDP = "72800"
TERLTON_TOWN = "72850"
TERRAL_TOWN = "72900"
TEXANNA_CDP = "72950"
TEXHOMA_TOWN = "73100"
TEXOLA_TOWN = "73150"
THACKERVILLE_TOWN = "73200"
THE_VILLAGE_CITY = "73250"
THOMAS_CITY = "73450"
TIAWAH_CDP = "73600"
TIPTON_TOWN = "73850"
TISHOMINGO_CITY = "73900"
TITANIC_CDP = "73950"
TONKAWA_TRIBAL_HOUSING_CDP = "74159"
TONKAWA_CITY = "74150"
TOPPERS_CDP = "74180"
TRIBBEY_TOWN = "74400"
TRYON_TOWN = "74550"
TULLAHASSEE_TOWN = "74650"
TULSA_CITY = "75000"
TUPELO_CITY = "75050"
TURLEY_CDP = "75150"
TURPIN_CDP = "75200"
TUSHKA_TOWN = "75250"
TUSKAHOMA_CDP = "75300"
TUTTLE_CITY = "75450"
TWIN_LAKES_CDP = "75575"
TWIN_OAKS_CDP = "75600"
TYRONE_TOWN = "75750"
UNION_CITY_TOWN = "75950"
UTICA_CDP = "76350"
VALLEY_BROOK_TOWN = "76500"
VALLEY_PARK_TOWN = "76600"
VALLIANT_TOWN = "76650"
VANOSS_CDP = "76850"
VELMA_TOWN = "76900"
VERA_TOWN = "76950"
VERDEN_TOWN = "77000"
VERDIGRIS_TOWN = "77050"
VIAN_TOWN = "77250"
VICI_TOWN = "77300"
VINITA_CITY = "77550"
WAGONER_CITY = "77850"
WAINWRIGHT_TOWN = "77900"
WAKITA_TOWN = "77950"
WALTERS_CITY = "78150"
WANETTE_TOWN = "78200"
WANN_TOWN = "78250"
WAPANUCKA_TOWN = "78300"
WARDVILLE_CDP = "78350"
WARNER_TOWN = "78400"
WARR_ACRES_CITY = "78500"
WARWICK_TOWN = "78650"
WASHINGTON_TOWN = "78700"
WASHITA_CDP = "78750"
WATONGA_CITY = "78950"
WATOVA_CDP = "79000"
WATTS_TOWN = "79100"
WAUHILLAU_CDP = "79150"
WAUKOMIS_TOWN = "79200"
WAURIKA_CITY = "79250"
WAYNE_TOWN = "79300"
WAYNOKA_CITY = "79350"
WEATHERFORD_CITY = "79450"
WEBB_CITY_TOWN = "79600"
WEBBERS_FALLS_TOWN = "79650"
WELCH_TOWN = "79750"
WELEETKA_TOWN = "79800"
WELLING_CDP = "79850"
WELLSTON_TOWN = "79900"
WELTY_CDP = "80000"
WEST_PEAVINE_CDP = "80230"
WEST_SILOAM_SPRINGS_TOWN = "80350"
WESTPORT_TOWN = "80250"
WESTVILLE_TOWN = "80450"
WETUMKA_CITY = "80500"
WEWOKA_CITY = "80550"
WHIPPOORWILL_CDP = "80675"
WHITE_EAGLE_CDP = "80750"
WHITE_OAK_CDP = "80850"
WHITE_WATER_CDP = "80912"
WHITEFIELD_TOWN = "80800"
WHITEHORN_COVE_CDP = "80813"
WHITESBORO_CDP = "80900"
WICKLIFFE_CDP = "80975"
WILBURTON_CITY = "81000"
WILLOW_TOWN = "81300"
WILSON_CITY = "81500"
WINCHESTER_TOWN = "81575"
WISTER_TOWN = "81750"
WOODALL_CDP = "81912"
WOODLAWN_PARK_TOWN = "82000"
WOODWARD_CITY = "82150"
WRIGHT_CITY_TOWN = "82200"
WYANDOTTE_TOWN = "82250"
WYNNEWOOD_CITY = "82400"
WYNONA_TOWN = "82450"
YALE_CITY = "82500"
YEAGER_TOWN = "82650"
YUKON_CITY = "82950"
ZEB_CDP = "83030"
ZENA_CDP = "83050"
ZION_CDP = "83125"
