# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Missouri."""


ADRIAN_CITY = "00244"
ADVANCE_CITY = "00262"
AFFTON_CDP = "00280"
AGENCY_VILLAGE = "00298"
AIRPORT_DRIVE_VILLAGE = "00424"
ALBA_CITY = "00496"
ALBANY_CITY = "00514"
ALDRICH_VILLAGE = "00568"
ALEXANDRIA_CITY = "00604"
ALLENDALE_VILLAGE = "00712"
ALLENVILLE_VILLAGE = "00748"
ALMA_CITY = "00802"
ALTAMONT_VILLAGE = "00910"
ALTENBURG_CITY = "00928"
ALTON_CITY = "00964"
AMAZONIA_VILLAGE = "01018"
AMITY_TOWN = "01054"
AMORET_CITY = "01072"
AMSTERDAM_CITY = "01090"
ANDERSON_CITY = "01198"
ANNADA_VILLAGE = "01252"
ANNAPOLIS_CITY = "01270"
ANNISTON_TOWN = "01288"
APPLETON_CITY_CITY = "01522"
ARBELA_TOWN = "01576"
ARBYRD_CITY = "01630"
ARCADIA_CITY = "01648"
ARCHIE_CITY = "01702"
ARCOLA_VILLAGE = "01720"
ARGYLE_TOWN = "01828"
ARKOE_TOWN = "01864"
ARMSTRONG_CITY = "01954"
ARNOLD_CITY = "01972"
ARROW_POINT_VILLAGE = "02034"
ARROW_ROCK_TOWN = "02044"
ASBURY_CITY = "02098"
ASH_GROVE_CITY = "02188"
ASHBURN_TOWN = "02152"
ASHLAND_CITY = "02242"
ASHLEY_CDP = "02260"
ATLANTA_CITY = "02422"
AUGUSTA_TOWN = "02512"
AULLVILLE_VILLAGE = "02530"
AURORA_SPRINGS_CDP = "02584"
AURORA_CITY = "02548"
AUXVASSE_CITY = "02638"
AVA_CITY = "02674"
AVALON_CDP = "02692"
AVILLA_TOWN = "02746"
AVONDALE_CITY = "02800"
BAGNELL_TOWN = "02962"
BAKER_VILLAGE = "03034"
BAKERSFIELD_VILLAGE = "03052"
BALDWIN_PARK_VILLAGE = "03124"
BALLWIN_CITY = "03160"
BARING_CITY = "03322"
BARNARD_CITY = "03340"
BARNETT_CITY = "03376"
BARNHART_CDP = "03394"
BATES_CITY_CITY = "03556"
BATTLEFIELD_CITY = "03592"
BEL_NOR_VILLAGE = "04348"
BEL_RIDGE_VILLAGE = "04366"
BELL_CITY_CITY = "04132"
BELLA_VILLA_CITY = "04114"
BELLE_CITY = "04150"
BELLEFONTAINE_NEIGHBORS_CITY = "04222"
BELLERIVE_ACRES_CITY = "04248"
BELLFLOWER_CITY = "04330"
BELTON_CITY = "04384"
BENNETT_SPRINGS_CDP = "04525"
BENT_TREE_HARBOR_CDP = "04864"
BENTON_CITY_VILLAGE = "04834"
BENTON_CITY = "04798"
BERGER_CITY = "04888"
BERKELEY_CITY = "04906"
BERNIE_CITY = "04960"
BERTRAND_CITY = "04996"
BETHANY_CITY = "05068"
BETHEL_VILLAGE = "05104"
BEVERLY_HILLS_CITY = "05248"
BEVIER_CITY = "05266"
BIEHLE_CDP = "05320"
BIG_LAKE_VILLAGE = "05495"
BIG_SPRING_CDP = "05608"
BIGELOW_VILLAGE = "05464"
BILLINGS_CITY = "05626"
BIRCH_TREE_CITY = "05734"
BIRMINGHAM_VILLAGE = "05824"
BISMARCK_CITY = "05878"
BLACK_JACK_CITY = "06004"
BLACKBURN_CITY = "05950"
BLACKWATER_CITY = "06148"
BLAIRSTOWN_CITY = "06238"
BLANCHARD_CDP = "06247"
BLAND_CITY = "06256"
BLODGETT_VILLAGE = "06346"
BLOOMFIELD_CITY = "06382"
BLOOMSDALE_CITY = "06454"
BLUE_EYE_TOWN = "06526"
BLUE_SPRINGS_CITY = "06652"
BLUE_SUMMIT_CDP = "06670"
BLYTHEDALE_VILLAGE = "06742"
BOGARD_CITY = "06832"
BOLCKOW_CITY = "06922"
BOLIVAR_CITY = "06976"
BONNE_TERRE_CITY = "07102"
BOONVILLE_CITY = "07318"
BOSWORTH_CITY = "07426"
BOURBON_CITY = "07534"
BOWLING_GREEN_CITY = "07660"
BRAGG_CITY_TOWN = "07876"
BRANDSVILLE_CITY = "07948"
BRANSON_WEST_CITY = "07989"
BRANSON_CITY = "07966"
BRASHEAR_CITY = "08002"
BRAYMER_CITY = "08038"
BRECKENRIDGE_HILLS_CITY = "08164"
BRECKENRIDGE_CITY = "08128"
BRENTWOOD_CITY = "08236"
BREWER_CDP = "08272"
BRIARWOOD_ESTATES_CDP = "08294"
BRIDGETON_CITY = "08398"
BRIMSON_VILLAGE = "08470"
BRONAUGH_CITY = "08614"
BROOKFIELD_CITY = "08650"
BROOKLYN_HEIGHTS_TOWN = "08776"
BROSELEY_CDP = "08812"
BROWNING_CITY = "08884"
BROWNINGTON_TOWN = "08902"
BRUMLEY_TOWN = "08974"
BRUNSWICK_CITY = "09046"
BUCKLIN_CITY = "09388"
BUCKNER_CITY = "09424"
BUELL_CDP = "09496"
BUFFALO_CITY = "09514"
BULL_CREEK_VILLAGE = "09642"
BUNCETON_CITY = "09658"
BUNKER_CITY = "09694"
BURFORDVILLE_CDP = "09784"
BURGESS_CDP = "09802"
BURLINGTON_JUNCTION_CITY = "09838"
BUTLER_CITY = "10054"
BUTTERFIELD_CITY = "10144"
BYRNES_MILL_CITY = "10240"
CABOOL_CITY = "10288"
CAINSVILLE_CITY = "10342"
CAIRO_VILLAGE = "10360"
CALEDONIA_VILLAGE = "10432"
CALHOUN_CITY = "10450"
CALIFORNIA_CITY = "10468"
CALLAO_CITY = "10486"
CALVERTON_PARK_CITY = "10612"
CAMDEN_POINT_CITY = "10792"
CAMDEN_CITY = "10738"
CAMDENTON_CITY = "10810"
CAMERON_CITY = "10828"
CAMPBELL_CITY = "10864"
CANALOU_CITY = "11026"
CANTON_CITY = "11134"
CAPE_GIRARDEAU_CITY = "11242"
CARDWELL_CITY = "11350"
CARL_JUNCTION_CITY = "11368"
CARROLLTON_CITY = "11566"
CARTERVILLE_CITY = "11638"
CARTHAGE_CITY = "11656"
CARUTHERSVILLE_CITY = "11692"
CARYTOWN_CITY = "11728"
CASSVILLE_CITY = "11890"
CASTLE_POINT_CDP = "11908"
CATRON_TOWN = "12052"
CAVE_TOWN = "12079"
CEDAR_HILL_CDP = "12358"
CEDAR_HILL_LAKES_VILLAGE = "12376"
CENTER_CITY = "12592"
CENTERTOWN_TOWN = "12664"
CENTERVIEW_CITY = "12682"
CENTERVILLE_CITY = "12718"
CENTRALIA_CITY = "12898"
CHAFFEE_CITY = "12988"
CHAIN_OF_ROCKS_VILLAGE = "13006"
CHAIN_O_LAKES_VILLAGE = "13015"
CHAMOIS_CITY = "13060"
CHAMP_VILLAGE = "13078"
CHARLACK_CITY = "13330"
CHARLESTON_CITY = "13366"
CHARMWOOD_TOWN = "13390"
CHEROKEE_PASS_CDP = "13474"
CHESAPEAKE_CDP = "13582"
CHESTERFIELD_CITY = "13600"
CHILHOWEE_TOWN = "13654"
CHILLICOTHE_CITY = "13690"
CHULA_CITY = "13852"
CLARENCE_CITY = "13978"
CLARK_CITY = "14068"
CLARKSBURG_CITY = "14140"
CLARKSDALE_CITY = "14158"
CLARKSON_VALLEY_CITY = "14176"
CLARKSVILLE_CITY = "14194"
CLARKTON_CITY = "14212"
CLAYCOMO_VILLAGE = "14554"
CLAYTON_CITY = "14572"
CLEARMONT_CITY = "14662"
CLEVELAND_CITY = "14770"
CLEVER_CITY = "14788"
CLIFF_VILLAGE_VILLAGE = "14806"
CLIFTON_HILL_CITY = "14896"
CLIMAX_SPRINGS_CDP = "14914"
CLINTON_CITY = "14986"
CLYDE_VILLAGE = "15130"
COBALT_VILLAGE = "15220"
COFFEY_CITY = "15274"
COLE_CAMP_CITY = "15436"
COLLINS_VILLAGE = "15562"
COLUMBIA_CITY = "15670"
COMMERCE_VILLAGE = "15760"
CONCEPTION_CDP = "15886"
CONCEPTION_JUNCTION_TOWN = "15922"
CONCORD_CDP = "16030"
CONCORDIA_CITY = "16102"
CONEY_ISLAND_VILLAGE = "16115"
CONNELSVILLE_CDP = "16138"
CONWAY_CITY = "16192"
COOL_VALLEY_CITY = "16228"
COOTER_CITY = "16336"
CORDER_CITY = "16408"
CORNING_TOWN = "16462"
COSBY_VILLAGE = "16588"
COTTLEVILLE_CITY = "16678"
COUNTRY_CLUB_HILLS_CITY = "16822"
COUNTRY_CLUB_VILLAGE = "16802"
COUNTRY_LIFE_ACRES_VILLAGE = "16876"
COWGILL_CITY = "16984"
CRAIG_CITY = "17056"
CRANE_CITY = "17074"
CREIGHTON_CITY = "17164"
CRESTWOOD_CITY = "17218"
CREVE_COEUR_CITY = "17272"
CROCKER_CITY = "17344"
CROSS_TIMBERS_CITY = "17524"
CRYSTAL_CITY_CITY = "17632"
CRYSTAL_LAKE_PARK_CITY = "17650"
CRYSTAL_LAKES_CITY = "17660"
CUBA_CITY = "17668"
CURRYVILLE_CITY = "17902"
DADEVILLE_VILLAGE = "17992"
DALTON_TOWN = "18118"
DANVILLE_CDP = "18190"
DARDENNE_PRAIRIE_CITY = "18253"
DARLINGTON_VILLAGE = "18316"
DAWN_CDP = "18496"
DE_KALB_TOWN = "18946"
DE_SOTO_CITY = "19252"
DE_WITT_CITY = "19378"
DEARBORN_CITY = "18658"
DEEPWATER_CITY = "18730"
DEERFIELD_VILLAGE = "18802"
DEERING_CDP = "18838"
DEFIANCE_CDP = "18910"
DELLWOOD_CITY = "19018"
DELTA_CITY = "19072"
DENNIS_ACRES_VILLAGE = "19090"
DENTON_CDP = "19144"
DENVER_VILLAGE = "19162"
DES_ARC_VILLAGE = "19198"
DES_PERES_CITY = "19270"
DESLOGE_CITY = "19216"
DEXTER_CITY = "19396"
DIAMOND_TOWN = "19432"
DIEHLSTADT_VILLAGE = "19486"
DIGGINS_VILLAGE = "19504"
DIXON_CITY = "19630"
DOE_RUN_CDP = "19684"
DONIPHAN_CITY = "19792"
DOOLITTLE_CITY = "19828"
DOVER_TOWN = "19918"
DOWNING_CITY = "19990"
DREXEL_CITY = "20134"
DUDLEY_CITY = "20296"
DUENWEG_CITY = "20314"
DUQUESNE_VILLAGE = "20512"
DUTCHTOWN_CDP = "20566"
EAGLE_ROCK_CDP = "20656"
EAGLEVILLE_TOWN = "20674"
EAST_LYNNE_CITY = "20980"
EAST_PRAIRIE_CITY = "21052"
EASTON_CITY = "21034"
EDGAR_SPRINGS_CITY = "21214"
EDGERTON_CITY = "21250"
EDINA_CITY = "21322"
EDINBURG_CDP = "21340"
EDMUNDSON_CITY = "21376"
EL_DORADO_SPRINGS_CITY = "21502"
ELDON_CITY = "21484"
ELLINGTON_CITY = "21844"
ELLISVILLE_CITY = "21898"
ELLSINORE_CITY = "21916"
ELMER_CITY = "21988"
ELMIRA_VILLAGE = "22006"
ELMO_CITY = "22024"
ELSBERRY_CITY = "22114"
EMERALD_BEACH_VILLAGE = "22250"
EMINENCE_CITY = "22276"
EMMA_CITY = "22312"
EOLIA_VILLAGE = "22474"
ESSEX_CITY = "22600"
ETHEL_TOWN = "22672"
EUGENE_CDP = "22798"
EUREKA_CITY = "22834"
EVERGREEN_VILLAGE = "22951"
EVERTON_CITY = "22996"
EWING_CITY = "23032"
EXCELLO_CDP = "23050"
EXCELSIOR_ESTATES_VILLAGE = "23077"
EXCELSIOR_SPRINGS_CITY = "23086"
EXETER_CITY = "23122"
FAIR_GROVE_CITY = "23338"
FAIR_PLAY_CITY = "23428"
FAIRDEALING_CDP = "23248"
FAIRFAX_CITY = "23266"
FAIRVIEW_TOWN = "23518"
FARBER_CITY = "23662"
FARLEY_VILLAGE = "23698"
FARMINGTON_CITY = "23752"
FAUCETT_CDP = "23824"
FAYETTE_CITY = "23842"
FENTON_CITY = "23950"
FERGUSON_CITY = "23986"
FERRELVIEW_VILLAGE = "24058"
FESTUS_CITY = "24094"
FIDELITY_TOWN = "24120"
FILLMORE_CITY = "24184"
FISK_CITY = "24328"
FLEMING_CITY = "24562"
FLEMINGTON_VILLAGE = "24580"
FLINT_HILL_CITY = "24688"
FLORDELL_HILLS_CITY = "24706"
FLORIDA_VILLAGE = "24760"
FLORISSANT_CITY = "24778"
FOLEY_CITY = "24886"
FORDLAND_CITY = "25012"
FOREST_CITY_CITY = "25066"
FORISTELL_CITY = "25120"
FORSYTH_CITY = "25192"
FORT_LEONARD_WOOD_CDP = "25264"
FORTESCUE_TOWN = "25228"
FORTUNA_CDP = "25300"
FOSTER_VILLAGE = "25372"
FOUNTAIN_N_LAKES_VILLAGE = "25411"
FRANKCLAY_CDP = "25516"
FRANKFORD_CITY = "25552"
FRANKLIN_CITY = "25624"
FREDERICKTOWN_CITY = "25768"
FREEBURG_VILLAGE = "25822"
FREEMAN_CITY = "25894"
FREISTATT_VILLAGE = "25912"
FREMONT_CDP = "25948"
FREMONT_HILLS_CITY = "25957"
FRIEDENSWALD_VILLAGE = "26000"
FRISBEE_CDP = "26020"
FROHNA_CITY = "26092"
FRONTENAC_CITY = "26110"
FULTON_CITY = "26182"
GAINESVILLE_CITY = "26218"
GALENA_CITY = "26254"
GALLATIN_CITY = "26308"
GALT_CITY = "26362"
GARDEN_CITY_CITY = "26434"
GASCONADE_CITY = "26578"
GENTRY_VILLAGE = "26776"
GERALD_CITY = "26866"
GERSTER_TOWN = "26902"
GIBBS_VILLAGE = "26920"
GIDEON_CITY = "26974"
GILLIAM_CITY = "27028"
GILMAN_CITY_CITY = "27064"
GINGER_BLUE_VILLAGE = "27100"
GLADSTONE_CITY = "27190"
GLASGOW_VILLAGE_CDP = "27226"
GLASGOW_CITY = "27208"
GLEN_ALLEN_TOWN = "27280"
GLEN_ECHO_PARK_VILLAGE = "27370"
GLENAIRE_CITY = "27262"
GLENDALE_CITY = "27334"
GLENWOOD_VILLAGE = "27514"
GOLDEN_CDP = "27658"
GOLDEN_CITY_CITY = "27676"
GOODMAN_CITY = "27874"
GOOSE_CREEK_LAKE_CDP = "27924"
GORDONVILLE_VILLAGE = "27928"
GOSS_TOWN = "28000"
GOWER_CITY = "28036"
GRAHAM_TOWN = "28072"
GRAIN_VALLEY_CITY = "28090"
GRANBY_CITY = "28108"
GRAND_FALLS_PLAZA_TOWN = "28170"
GRAND_PASS_VILLAGE = "28198"
GRANDIN_CITY = "28180"
GRANDVIEW_CITY = "28324"
GRANGER_VILLAGE = "28360"
GRANT_CITY_TOWN = "28594"
GRANTWOOD_VILLAGE_TOWN = "28630"
GRAVOIS_MILLS_TOWN = "28828"
GRAY_SUMMIT_CDP = "28918"
GRAYHAWK_CDP = "28860"
GRAYRIDGE_CDP = "28864"
GRAYSON_CDP = "28882"
GREEN_CITY_CITY = "29134"
GREEN_PARK_CITY = "29324"
GREEN_RIDGE_CITY = "29332"
GREENCASTLE_CITY = "29116"
GREENDALE_CITY = "29152"
GREENFIELD_CITY = "29206"
GREENTOP_CITY = "29422"
GREENVILLE_CITY = "29476"
GREENWOOD_CITY = "29494"
GROVESPRING_CDP = "29656"
GUILFORD_TOWN = "29692"
GUNN_CITY_VILLAGE = "29764"
HALE_CITY = "29908"
HALFWAY_VILLAGE = "29962"
HALLSVILLE_CITY = "29998"
HALLTOWN_VILLAGE = "30016"
HAMILTON_CITY = "30034"
HANLEY_HILLS_VILLAGE = "30196"
HANNIBAL_CITY = "30214"
HARDIN_CITY = "30322"
HARRIS_TOWN = "30466"
HARRISBURG_TOWN = "30484"
HARRISONVILLE_CITY = "30610"
HARTSBURG_TOWN = "30718"
HARTVILLE_CITY = "30754"
HARTWELL_CDP = "30772"
HARVIELL_CDP = "30844"
HARWOOD_VILLAGE = "30862"
HAWK_POINT_CITY = "31024"
HAYTI_HEIGHTS_CITY = "31168"
HAYTI_CITY = "31132"
HAYWARD_CDP = "31186"
HAYWOOD_CITY_VILLAGE = "31204"
HAZELWOOD_CITY = "31276"
HENRIETTA_CITY = "31654"
HERCULANEUM_CITY = "31708"
HERMANN_CITY = "31762"
HERMITAGE_CITY = "31780"
HIGBEE_CITY = "31924"
HIGGINSVILLE_CITY = "31960"
HIGH_HILL_CITY = "31996"
HIGH_RIDGE_CDP = "32140"
HIGHLANDVILLE_CITY = "32068"
HILLSBORO_CITY = "32248"
HILLSDALE_VILLAGE = "32266"
HOBERG_VILLAGE = "32410"
HOLCOMB_CITY = "32536"
HOLDEN_CITY = "32572"
HOLLAND_TOWN = "32590"
HOLLIDAY_VILLAGE = "32626"
HOLLISTER_CITY = "32662"
HOLLYWOOD_CDP = "32698"
HOLT_CITY = "32752"
HOLTS_SUMMIT_CITY = "32770"
HOMESTEAD_VILLAGE = "32806"
HOMESTOWN_CITY = "32824"
HOPKINS_CITY = "33004"
HORINE_CDP = "33040"
HORNERSVILLE_CITY = "33076"
HOUSTON_LAKE_CITY = "33292"
HOUSTON_CITY = "33238"
HOUSTONIA_CITY = "33256"
HOWARDVILLE_CITY = "33364"
HUGHESVILLE_VILLAGE = "33652"
HUMANSVILLE_CITY = "33706"
HUME_TOWN = "33724"
HUMPHREYS_VILLAGE = "33742"
HUNNEWELL_CITY = "33760"
HUNTER_CDP = "33778"
HUNTLEIGH_CITY = "33850"
HUNTSDALE_TOWN = "33868"
HUNTSVILLE_CITY = "33886"
HURDLAND_CITY = "33904"
HURLEY_CITY = "33922"
IANTHA_CDP = "34192"
IATAN_VILLAGE = "34210"
IBERIA_CITY = "34228"
IMPERIAL_CDP = "34354"
INDEPENDENCE_CITY = "35000"
INDIAN_LAKE_CDP = "35180"
INDIAN_POINT_VILLAGE = "35186"
INNSBROOK_VILLAGE = "35240"
IONIA_TOWN = "35306"
IRENA_VILLAGE = "35324"
IRON_MOUNTAIN_LAKE_CITY = "35450"
IRONDALE_CITY = "35396"
IRONTON_CITY = "35468"
IRWIN_CDP = "35486"
JACKSON_CITY = "35648"
JACKSONVILLE_VILLAGE = "36224"
JAMESON_TOWN = "36314"
JAMESPORT_CITY = "36332"
JAMESTOWN_TOWN = "36368"
JANE_TOWN = "36422"
JASPER_CITY = "36512"
JEFFERSON_CITY_CITY = "37000"
JENNINGS_CITY = "37178"
JERICO_SPRINGS_VILLAGE = "37214"
JONESBURG_CITY = "37574"
JOPLIN_CITY = "37592"
JOSEPHVILLE_VILLAGE = "37700"
JUNCTION_CITY_VILLAGE = "37736"
KAHOKA_CITY = "37790"
KANSAS_CITY_CITY = "38000"
KEARNEY_CITY = "38072"
KELSO_VILLAGE = "38216"
KENNETT_CITY = "38306"
KEYTESVILLE_CITY = "38468"
KIDDER_CITY = "38522"
KIMBERLING_CITY_CITY = "38612"
KIMMSWICK_CITY = "38684"
KING_CITY_CITY = "38774"
KINGDOM_CITY_VILLAGE = "38792"
KINGSTON_CITY = "38846"
KINGSVILLE_CITY = "38918"
KINLOCH_CITY = "38972"
KIRBYVILLE_VILLAGE = "39008"
KIRKSVILLE_CITY = "39026"
KIRKWOOD_CITY = "39044"
KISSEE_MILLS_CDP = "39080"
KNOB_LICK_CDP = "39170"
KNOB_NOSTER_CITY = "39188"
KNOX_CITY_CITY = "39278"
KOSHKONONG_TOWN = "39440"
LA_BELLE_CITY = "39512"
LA_DUE_VILLAGE = "39638"
LA_GRANGE_CITY = "39764"
LA_MONTE_CITY = "40520"
LA_PLATA_CITY = "40682"
LA_RUSSELL_CITY = "40790"
LA_TOUR_CDP = "40880"
LABARQUE_CREEK_CDP = "39503"
LACLEDE_CITY = "39566"
LADDONIA_CITY = "39602"
LADUE_CITY = "39656"
LAKE_ANNETTE_CITY = "39845"
LAKE_ARROWHEAD_CDP = "39852"
LAKE_LAFAYETTE_CITY = "39952"
LAKE_LOTAWANA_CITY = "39980"
LAKE_OZARK_CITY = "40034"
LAKE_ST_CLAIR_CDP = "40039"
LAKE_ST_LOUIS_CITY = "40043"
LAKE_TAPAWINGO_CITY = "40196"
LAKE_TEKAKWITHA_VILLAGE = "40214"
LAKE_TIMBERLINE_CDP = "40222"
LAKE_VIKING_CDP = "40304"
LAKE_WAUKOMIS_CITY = "40322"
LAKE_WINNEBAGO_CITY = "40340"
LAKESHIRE_CITY = "40088"
LAKESIDE_CITY = "40142"
LAMAR_HEIGHTS_CITY = "40430"
LAMAR_CITY = "40376"
LAMBERT_VILLAGE = "40448"
LANAGAN_TOWN = "40592"
LANCASTER_CITY = "40610"
LAREDO_CITY = "40736"
LATHAM_CDP = "40808"
LATHROP_CITY = "40826"
LAURIE_CITY = "40916"
LAWSON_CITY = "40988"
LEADINGTON_CITY = "41024"
LEADWOOD_CITY = "41078"
LEASBURG_VILLAGE = "41114"
LEAWOOD_VILLAGE = "41132"
LEBANON_CITY = "41168"
LEES_SUMMIT_CITY = "41348"
LEETON_CITY = "41402"
LEISURE_LAKE_CDP = "41417"
LEMAY_CDP = "41438"
LEONARD_VILLAGE = "41546"
LESLIE_VILLAGE = "41690"
LEVASY_CITY = "41762"
LEWIS_AND_CLARK_VILLAGE_TOWN = "41834"
LEWISTOWN_TOWN = "41852"
LEXINGTON_CITY = "41870"
LIBERAL_CITY = "41906"
LIBERTY_CITY = "42032"
LICKING_CITY = "42464"
LILBOURN_CITY = "42536"
LINCOLN_CITY = "42608"
LINN_CREEK_CITY = "43274"
LINN_CITY = "43238"
LINNEUS_CITY = "43292"
LITHIUM_CDP = "43346"
LIVONIA_VILLAGE = "43454"
LOCH_LLOYD_VILLAGE = "43468"
LOCK_SPRINGS_VILLAGE = "43472"
LOCKWOOD_CITY = "43490"
LOHMAN_CITY = "43652"
LOMA_LINDA_TOWN = "43672"
LONE_JACK_CITY = "43760"
LONGTOWN_TOWN = "43940"
LOUISBURG_VILLAGE = "44156"
LOUISIANA_CITY = "44174"
LOWRY_CITY_CITY = "44282"
LUCERNE_VILLAGE = "44372"
LUDLOW_TOWN = "44390"
LUPUS_TOWN = "44498"
LURAY_VILLAGE = "44516"
MACKS_CREEK_CDP = "45218"
MACON_CITY = "45326"
MADISON_CITY = "45470"
MAITLAND_CITY = "45596"
MALDEN_CITY = "45614"
MALTA_BEND_TOWN = "45632"
MANCHESTER_CITY = "45668"
MANSFIELD_CITY = "45740"
MAPLEWOOD_CITY = "45830"
MARBLE_HILL_CITY = "45848"
MARCELINE_CITY = "45866"
MARIONVILLE_CITY = "46172"
MARLBOROUGH_VILLAGE = "46208"
MARQUAND_CITY = "46244"
MARSHALL_CITY = "46316"
MARSHFIELD_CITY = "46388"
MARSTON_CITY = "46406"
MARTHASVILLE_CITY = "46424"
MARTINSBURG_TOWN = "46460"
MARYLAND_HEIGHTS_CITY = "46586"
MARYVILLE_CITY = "46640"
MATTHEWS_CITY = "46730"
MAYSVILLE_CITY = "46946"
MAYVIEW_CITY = "46964"
MCBAINE_TOWN = "44768"
MCCORD_BEND_VILLAGE = "44829"
MCFALL_CITY = "45020"
MCKITTRICK_TOWN = "45200"
MEADVILLE_CITY = "47036"
MEDILL_CDP = "47144"
MEHLVILLE_CDP = "47180"
MEMPHIS_CITY = "47270"
MENDON_CITY = "47288"
MERCER_TOWN = "47486"
MERRIAM_WOODS_CITY = "47520"
MERWIN_VILLAGE = "47540"
META_CITY = "47594"
METZ_TOWN = "47612"
MEXICO_CITY = "47648"
MIAMI_CITY = "47684"
MIDDLE_GROVE_CDP = "47846"
MIDDLETOWN_TOWN = "47900"
MILAN_CITY = "48062"
MILFORD_VILLAGE = "48098"
MILL_SPRING_VILLAGE = "48386"
MILLARD_VILLAGE = "48134"
MILLER_CITY = "48242"
MILLERSVILLE_CDP = "48350"
MILO_VILLAGE = "48476"
MINDENMINES_CITY = "48566"
MINE_LA_MOTTE_CDP = "48602"
MINER_CITY = "48656"
MINERAL_POINT_TOWN = "48710"
MIRAMIGUOA_PARK_VILLAGE = "48880"
MISSOURI_CITY_CITY = "48980"
MOBERLY_CITY = "49034"
MOKANE_CITY = "49070"
MOLINE_ACRES_CITY = "49088"
MONETT_CITY = "49196"
MONROE_CITY_CITY = "49394"
MONTGOMERY_CITY_CITY = "49574"
MONTICELLO_VILLAGE = "49592"
MONTIER_CDP = "49610"
MONTREAL_CDP = "49646"
MONTROSE_CITY = "49664"
MOORESVILLE_VILLAGE = "49790"
MOREHOUSE_CITY = "49898"
MORLEY_CITY = "49988"
MORRISON_CITY = "50060"
MORRISVILLE_TOWN = "50078"
MOSBY_CITY = "50168"
MOSCOW_MILLS_CITY = "50204"
MOUND_CITY_CITY = "50312"
MOUNDVILLE_TOWN = "50330"
MOUNT_LEONARD_TOWN = "50510"
MOUNT_MORIAH_TOWN = "50528"
MOUNT_VERNON_CITY = "50672"
MOUNTAIN_GROVE_CITY = "50402"
MOUNTAIN_VIEW_CITY = "50438"
MURPHY_CDP = "50834"
NAPOLEON_CITY = "51140"
NAYLOR_CITY = "51302"
NECK_CITY_CITY = "51356"
NEELYVILLE_CITY = "51446"
NELSON_CITY = "51500"
NEOSHO_CITY = "51572"
NEVADA_CITY = "51644"
NEW_BLOOMFIELD_CITY = "51680"
NEW_CAMBRIA_CITY = "51734"
NEW_FLORENCE_CITY = "51770"
NEW_FRANKLIN_CITY = "51824"
NEW_HAMBURG_CDP = "51842"
NEW_HAMPTON_CITY = "51860"
NEW_HAVEN_CITY = "51914"
NEW_LONDON_CITY = "52058"
NEW_MADRID_CITY = "52076"
NEW_MARKET_CDP = "52130"
NEW_MELLE_CITY = "52148"
NEW_WELLS_CDP = "52364"
NEWARK_VILLAGE = "51662"
NEWBURG_CITY = "51716"
NEWTONIA_TOWN = "52292"
NEWTOWN_TOWN = "52328"
NIANGUA_CITY = "52418"
NIXA_CITY = "52616"
NOEL_CITY = "52742"
NORBORNE_CITY = "52760"
NORMANDY_CITY = "52796"
NORTH_KANSAS_CITY_CITY = "53102"
NORTH_LILBOURN_VILLAGE = "53138"
NORTHMOOR_CITY = "53174"
NORTHWOODS_CITY = "53408"
NORWOOD_COURT_TOWN = "53462"
NORWOOD_CITY = "53454"
NOVELTY_VILLAGE = "53516"
NOVINGER_CITY = "53534"
OFALLON_CITY = "54074"
OAK_GROVE_VILLAGE_VILLAGE = "53650"
OAK_GROVE_CITY = "53624"
OAK_RIDGE_TOWN = "53786"
OAKLAND_CITY = "53750"
OAKS_VILLAGE = "53804"
OAKVIEW_VILLAGE = "53858"
OAKVILLE_CDP = "53876"
OAKWOOD_PARK_VILLAGE = "53948"
OAKWOOD_VILLAGE = "53894"
ODESSA_CITY = "54038"
OLD_APPLETON_TOWN = "54200"
OLD_JAMESTOWN_CDP = "54352"
OLD_MONROE_CITY = "54416"
OLEAN_TOWN = "54560"
OLIVETTE_CITY = "54650"
OLYMPIAN_VILLAGE_CITY = "54686"
ORAN_CITY = "54758"
OREGON_CITY = "54848"
ORONOGO_CITY = "54920"
ORRICK_CITY = "54938"
OSAGE_BEACH_CITY = "55244"
OSBORN_CITY = "55352"
OSCEOLA_CITY = "55388"
OSGOOD_VILLAGE = "55424"
OTTERVILLE_CITY = "55478"
OVERLAND_CITY = "55550"
OWENSVILLE_CITY = "55640"
OXLY_CDP = "55694"
OZARK_CITY = "55766"
OZORA_CDP = "55892"
PACIFIC_CITY = "55910"
PAGEDALE_CITY = "55964"
PALMYRA_CITY = "56036"
PARADISE_CDP = "56126"
PARIS_CITY = "56144"
PARK_HILLS_CITY = "56272"
PARKDALE_VILLAGE = "56226"
PARKVILLE_CITY = "56288"
PARKWAY_VILLAGE = "56306"
PARMA_CITY = "56342"
PARNELL_CITY = "56360"
PASADENA_HILLS_CITY = "56396"
PASADENA_PARK_VILLAGE = "56414"
PASCOLA_VILLAGE = "56432"
PASSAIC_TOWN = "56468"
PATTONSBURG_CITY = "56558"
PAYNESVILLE_VILLAGE = "56612"
PEACEFUL_VILLAGE_VILLAGE = "56620"
PECULIAR_CITY = "56756"
PENDLETON_VILLAGE = "56882"
PENERMON_VILLAGE = "56900"
PERKINS_CDP = "57044"
PERRY_CITY = "57080"
PERRYVILLE_CITY = "57116"
PEVELY_CITY = "57278"
PHELPS_CITY_CDP = "57332"
PHILADELPHIA_CDP = "57350"
PHILLIPSBURG_VILLAGE = "57368"
PICKERING_CITY = "57404"
PIEDMONT_CITY = "57422"
PIERCE_CITY_CITY = "57494"
PIERPONT_VILLAGE = "57512"
PILOT_GROVE_CITY = "57602"
PILOT_KNOB_CITY = "57656"
PINE_LAWN_CITY = "57800"
PINEVILLE_CITY = "57818"
PINHOOK_VILLAGE = "57926"
PLATO_VILLAGE = "58088"
PLATTE_CITY_CITY = "58178"
PLATTE_WOODS_CITY = "58196"
PLATTSBURG_CITY = "58250"
PLEASANT_HILL_CITY = "58394"
PLEASANT_HOPE_CITY = "58448"
PLEASANT_VALLEY_CITY = "58520"
PLEVNA_CDP = "58574"
POCAHONTAS_TOWN = "58628"
POLLOCK_VILLAGE = "58898"
POLO_CITY = "58916"
POMONA_CDP = "58934"
PONTIAC_CDP = "59060"
POPLAR_BLUFF_CITY = "59096"
PORTAGE_DES_SIOUX_CITY = "59150"
PORTAGEVILLE_CITY = "59186"
POTOSI_CITY = "59330"
POWERSVILLE_VILLAGE = "59420"
PRAIRIE_HILL_CDP = "59708"
PRAIRIE_HOME_CITY = "59726"
PRATHERSVILLE_VILLAGE = "59816"
PRESTON_VILLAGE = "59870"
PRINCETON_CITY = "59942"
PURCELL_CITY = "60140"
PURDIN_CITY = "60158"
PURDY_CITY = "60176"
PUXICO_CITY = "60284"
QUEEN_CITY_CITY = "60356"
QUITMAN_CDP = "60410"
QULIN_CITY = "60428"
RAINTREE_PLANTATION_CDP = "60528"
RANDOLPH_VILLAGE = "60590"
RAVANNA_CDP = "60644"
RAVENWOOD_TOWN = "60716"
RAYMONDVILLE_TOWN = "60734"
RAYMORE_CITY = "60752"
RAYTOWN_CITY = "60788"
RAYVILLE_CDP = "60824"
REA_CITY = "60842"
REDINGS_MILL_VILLAGE = "60986"
REEDS_SPRING_CITY = "61112"
REEDS_TOWN = "61094"
RENICK_VILLAGE = "61166"
RENSSELAER_VILLAGE = "61184"
REPUBLIC_CITY = "61238"
REVERE_TOWN = "61292"
RHINELAND_TOWN = "61328"
RICH_HILL_CITY = "61418"
RICHARDS_TOWN = "61364"
RICHLAND_CITY = "61562"
RICHMOND_HEIGHTS_CITY = "61706"
RICHMOND_CITY = "61670"
RIDGELY_VILLAGE = "61886"
RIDGEWAY_CITY = "61904"
RISCO_CITY = "61994"
RITCHEY_TOWN = "62030"
RIVER_BEND_VILLAGE = "62056"
RIVERSIDE_CITY = "62156"
RIVERVIEW_ESTATES_VILLAGE = "62210"
RIVERVIEW_VILLAGE = "62192"
RIVES_TOWN = "62228"
ROCHEPORT_CITY = "62498"
ROCK_HILL_CITY = "62660"
ROCK_PORT_CITY = "62696"
ROCKAWAY_BEACH_CITY = "62570"
ROCKVILLE_CITY = "62786"
ROCKY_COMFORT_CDP = "62822"
ROGERSVILLE_CITY = "62894"
ROLLA_CITY = "62912"
ROSCOE_VILLAGE = "63074"
ROSEBUD_CITY = "63110"
ROSENDALE_CITY = "63200"
ROTHVILLE_VILLAGE = "63236"
RUSH_HILL_VILLAGE = "63560"
RUSHVILLE_VILLAGE = "63596"
RUSSELLVILLE_CITY = "63704"
RUTLEDGE_TOWN = "63776"
SADDLEBROOKE_VILLAGE = "63857"
SAGINAW_VILLAGE = "63902"
SALEM_CITY = "65234"
SALISBURY_CITY = "65450"
SAPPINGTON_CDP = "65954"
SARCOXIE_CITY = "65990"
SAVANNAH_CITY = "66044"
SAVERTON_CDP = "66062"
SCHELL_CITY_CITY = "66134"
SCOTSDALE_TOWN = "66337"
SCOTT_CITY_CITY = "66368"
SEDALIA_CITY = "66440"
SEDGEWICKVILLE_VILLAGE = "66476"
SELIGMAN_CITY = "66530"
SENATH_CITY = "66638"
SENECA_CITY = "66674"
SEYMOUR_CITY = "66800"
SHAKERTOWNE_CDP = "66935"
SHAWNEETOWN_CDP = "67124"
SHELBINA_CITY = "67178"
SHELBYVILLE_CITY = "67196"
SHELDON_CITY = "67214"
SHELL_KNOB_CDP = "67232"
SHERIDAN_TOWN = "67358"
SHOAL_CREEK_DRIVE_VILLAGE = "67628"
SHOAL_CREEK_ESTATES_VILLAGE = "67632"
SHREWSBURY_CITY = "67700"
SIBLEY_VILLAGE = "67718"
SIKESTON_CITY = "67790"
SILEX_CITY = "67808"
SKIDMORE_CITY = "68132"
SLATER_CITY = "68204"
SMITHTON_CITY = "68384"
SMITHVILLE_CITY = "68420"
SOUTH_FORK_CDP = "68762"
SOUTH_GIFFORD_VILLAGE = "68852"
SOUTH_GORIN_TOWN = "68870"
SOUTH_GREENFIELD_VILLAGE = "68888"
SOUTH_LINEVILLE_TOWN = "68942"
SOUTHWEST_CITY_TOWN = "69230"
SPANISH_LAKE_CDP = "69266"
SPARTA_CITY = "69302"
SPICKARD_CITY = "69464"
SPOKANE_CDP = "69518"
SPRINGFIELD_CITY = "70000"
ST_ANN_CITY = "63956"
ST_CATHARINE_CDP = "64046"
ST_CHARLES_CITY = "64082"
ST_CLAIR_CITY = "64136"
ST_CLEMENT_CDP = "64154"
ST_CLOUD_VILLAGE = "64172"
ST_ELIZABETH_VILLAGE = "64190"
ST_FRANCISVILLE_CDP = "64244"
ST_GEORGE_CDP = "64370"
ST_JAMES_CITY = "64424"
ST_JOHN_CITY = "64478"
ST_JOSEPH_CITY = "64550"
ST_LOUIS_CITY = "65000"
ST_MARTINS_CITY = "65018"
ST_MARY_CITY = "65034"
ST_PAUL_CITY = "65108"
ST_PETERS_CITY = "65126"
ST_ROBERT_CITY = "65144"
ST_THOMAS_TOWN = "65162"
STANBERRY_CITY = "70270"
STANTON_CDP = "70342"
STARK_CITY_TOWN = "70414"
STE_GENEVIEVE_CITY = "64180"
STEELE_CITY = "70558"
STEELVILLE_CITY = "70576"
STELLA_TOWN = "70648"
STEWARTSVILLE_CITY = "70738"
STOCKTON_CITY = "70828"
STOTESBURY_TOWN = "70954"
STOTTS_CITY_CITY = "70990"
STOUTLAND_CITY = "71008"
STOUTSVILLE_VILLAGE = "71026"
STOVER_CITY = "71044"
STRAFFORD_CITY = "71062"
STRASBURG_CITY = "71098"
STURGEON_CITY = "71224"
SUGAR_CREEK_CITY = "71368"
SULLIVAN_CITY = "71440"
SUMMER_SET_CDP = "71508"
SUMMERSVILLE_CITY = "71512"
SUMNER_TOWN = "71620"
SUNDOWN_CDP = "71628"
SUNRISE_BEACH_VILLAGE = "71728"
SUNSET_HILLS_CITY = "71746"
SWEET_SPRINGS_CITY = "71890"
SYCAMORE_HILLS_VILLAGE = "72034"
SYRACUSE_CITY = "72106"
TALLAPOOSA_CITY = "72196"
TANEYVILLE_VILLAGE = "72232"
TAOS_CITY = "72304"
TARKIO_CITY = "72340"
TARRANTS_VILLAGE = "72376"
TARSNEY_LAKES_CDP = "72412"
TEBBETTS_CDP = "72574"
TERRE_DU_LAC_CDP = "72772"
THAYER_CITY = "72826"
THEODOSIA_VILLAGE = "72898"
THOMASVILLE_CDP = "73006"
THREE_CREEKS_VILLAGE = "73127"
TIGHTWAD_VILLAGE = "73240"
TINA_VILLAGE = "73330"
TINDALL_TOWN = "73348"
TIPTON_CITY = "73420"
TOWN_AND_COUNTRY_CITY = "73618"
TRACY_CITY = "73690"
TRENTON_CITY = "73816"
TRIMBLE_CITY = "73852"
TRIPLETT_CITY = "73870"
TROY_CITY = "73942"
TRUESDALE_CITY = "73978"
TRUXTON_VILLAGE = "74014"
TURNEY_VILLAGE = "74176"
TUSCUMBIA_TOWN = "74194"
TWIN_OAKS_VILLAGE = "74284"
UMBER_VIEW_HEIGHTS_VILLAGE = "74473"
UNION_STAR_TOWN = "75130"
UNION_CITY = "74626"
UNIONVILLE_CITY = "75166"
UNITY_VILLAGE_VILLAGE = "75202"
UNIVERSITY_CITY_CITY = "75220"
UPLANDS_PARK_VILLAGE = "75238"
URBANA_CITY = "75310"
URICH_CITY = "75346"
UTICA_VILLAGE = "75364"
VALLEY_PARK_CITY = "75472"
VAN_BUREN_TOWN = "75580"
VANDALIA_CITY = "75688"
VANDIVER_VILLAGE = "75706"
VANDUSER_VILLAGE = "75724"
VELDA_CITY_CITY = "75796"
VELDA_VILLAGE_HILLS_CITY = "75814"
VERONA_TOWN = "75886"
VERSAILLES_CITY = "75922"
VIBBARD_CDP = "75994"
VIBURNUM_CITY = "76012"
VIENNA_CITY = "76102"
VILLA_RIDGE_CDP = "76192"
VILLAGE_OF_FOUR_SEASONS_VILLAGE = "76157"
VINITA_PARK_CITY = "76246"
VISTA_VILLAGE = "76390"
WACO_CITY = "76444"
WALKER_CITY = "76660"
WALNUT_GROVE_CITY = "76840"
WARDELL_TOWN = "76966"
WARDSVILLE_VILLAGE = "77002"
WARRENSBURG_CITY = "77092"
WARRENTON_CITY = "77128"
WARSAW_CITY = "77146"
WARSON_WOODS_CITY = "77182"
WASHBURN_CITY = "77200"
WASHINGTON_CITY = "77416"
WASOLA_CDP = "77794"
WATSON_VILLAGE = "77848"
WAVERLY_CITY = "77866"
WAYLAND_CITY = "77920"
WAYNESVILLE_CITY = "77992"
WEATHERBY_LAKE_CITY = "78046"
WEATHERBY_TOWN = "78028"
WEAUBLEAU_CITY = "78064"
WEBB_CITY_CITY = "78118"
WEBSTER_GROVES_CITY = "78154"
WEINGARTEN_CDP = "78226"
WELDON_SPRING_HEIGHTS_TOWN = "78334"
WELDON_SPRING_CITY = "78314"
WELLINGTON_CITY = "78352"
WELLSTON_CITY = "78370"
WELLSVILLE_CITY = "78406"
WENTWORTH_VILLAGE = "78424"
WENTZVILLE_CITY = "78442"
WEST_ALTON_CITY = "78514"
WEST_LINE_VILLAGE = "78838"
WEST_PLAINS_CITY = "78928"
WEST_SULLIVAN_TOWN = "79000"
WESTBORO_CITY = "78622"
WESTON_CITY = "78856"
WESTPHALIA_CITY = "78910"
WESTWOOD_VILLAGE = "79054"
WHEATLAND_CITY = "79090"
WHEATON_CITY = "79126"
WHEELING_CITY = "79180"
WHITE_BRANCH_CDP = "79288"
WHITE_OAK_CDP = "79468"
WHITEMAN_AFB_CDP = "79432"
WHITESIDE_VILLAGE = "79558"
WHITEWATER_TOWN = "79612"
WHITING_CDP = "79684"
WILBUR_PARK_VILLAGE = "79756"
WILDWOOD_CITY = "79820"
WILLARD_CITY = "79882"
WILLIAMSTOWN_CDP = "80008"
WILLIAMSVILLE_CITY = "80026"
WILLOW_SPRINGS_CITY = "80098"
WILSON_CITY_VILLAGE = "80260"
WINCHESTER_CITY = "80314"
WINDSOR_PLACE_VILLAGE = "80380"
WINDSOR_CITY = "80350"
WINFIELD_CITY = "80422"
WINIGAN_CDP = "80440"
WINONA_CITY = "80512"
WINSTON_VILLAGE = "80548"
WOOD_HEIGHTS_CITY = "80767"
WOODSON_TERRACE_CITY = "80962"
WOOLDRIDGE_VILLAGE = "81016"
WORTH_VILLAGE = "81070"
WORTHAM_CDP = "81088"
WORTHINGTON_VILLAGE = "81106"
WRIGHT_CITY_CITY = "81124"
WYACONDA_CITY = "81142"
WYATT_CITY = "81178"
ZALMA_CDP = "81430"
