# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Pennsylvania."""


AARONSBURG_CDP_CENTRE_COUNTY = "00100"
AARONSBURG_CDP_WASHINGTON_COUNTY = "00104"
ABBOTTSTOWN_BOROUGH = "00116"
ACKERMANVILLE_CDP = "00244"
ADAMSBURG_BOROUGH = "00332"
ADAMSTOWN_BOROUGH = "00364"
ADAMSVILLE_CDP = "00372"
ADDISON_BOROUGH = "00396"
AKRON_BOROUGH = "00540"
ALBA_BOROUGH = "00572"
ALBION_BOROUGH = "00628"
ALBRIGHTSVILLE_CDP = "00652"
ALBURTIS_BOROUGH = "00660"
ALDAN_BOROUGH = "00676"
ALEXANDRIA_BOROUGH = "00756"
ALFARATA_CDP = "00764"
ALIQUIPPA_CITY = "00820"
ALLEGHENYVILLE_CDP = "00924"
ALLENPORT_CDP = "00980"
ALLENPORT_BOROUGH = "00988"
ALLENSVILLE_CDP = "01004"
ALLENTOWN_CITY = "02000"
ALLENWOOD_CDP = "02016"
ALLISON_CDP = "02040"
ALLISON_PARK_CDP = "02056"
ALLPORT_CDP = "02072"
ALMEDIA_CDP = "02088"
ALSACE_MANOR_CDP = "02128"
ALTAMONT_CDP = "02144"
ALTOONA_CITY = "02184"
ALVERDA_CDP = "02216"
AMBLER_BOROUGH = "02264"
AMBRIDGE_BOROUGH = "02288"
AMITY_GARDENS_CDP = "02349"
ANCIENT_OAKS_CDP = "02416"
ANNVILLE_CDP = "02608"
APOLLO_BOROUGH = "02720"
APPLEWOLD_BOROUGH = "02752"
ARCADIA_UNIVERSITY_CDP = "02826"
ARCHBALD_BOROUGH = "02832"
ARDMORE_CDP = "02896"
ARENDTSVILLE_BOROUGH = "02928"
ARISTES_CDP = "02968"
ARLINGTON_HEIGHTS_CDP = "03008"
ARMAGH_BOROUGH = "03032"
ARNOLD_CITY_CDP = "03096"
ARNOLD_CITY = "03088"
ARNOT_CDP = "03104"
ARONA_BOROUGH = "03120"
ASHLAND_BOROUGH = "03264"
ASHLEY_BOROUGH = "03272"
ASHVILLE_BOROUGH = "03296"
ASPERS_CDP = "03312"
ASPINWALL_BOROUGH = "03320"
ATGLEN_BOROUGH = "03384"
ATHENS_BOROUGH = "03392"
ATKINSON_MILLS_CDP = "03424"
ATLANTIC_CDP = "03440"
ATLAS_CDP = "03464"
ATLASBURG_CDP = "03472"
ATWOOD_BOROUGH = "03480"
AUBURN_BOROUGH = "03488"
AUDUBON_CDP = "03544"
AUSTIN_BOROUGH = "03576"
AVALON_BOROUGH = "03608"
AVELLA_CDP = "03616"
AVIS_BOROUGH = "03632"
AVOCA_BOROUGH = "03640"
AVON_CDP = "03648"
AVONDALE_BOROUGH = "03656"
AVONIA_CDP = "03676"
AVONMORE_BOROUGH = "03688"
BADEN_BOROUGH = "03736"
BAIDLAND_CDP = "03768"
BAILEYVILLE_CDP = "03792"
BAINBRIDGE_CDP = "03800"
BAIRDFORD_CDP = "03816"
BAKERSTOWN_CDP = "03864"
BALA_CYNWYD_CDP = "03895"
BALD_EAGLE_CDP = "03904"
BALDWIN_BOROUGH = "03928"
BALLY_BOROUGH = "03984"
BANGOR_BOROUGH = "04032"
BARKEYVILLE_BOROUGH = "04136"
BARRVILLE_CDP = "04344"
BATH_BOROUGH = "04432"
BAUMSTOWN_CDP = "04488"
BEALLSVILLE_BOROUGH = "04568"
BEAR_CREEK_VILLAGE_BOROUGH = "04599"
BEAR_LAKE_BOROUGH = "04608"
BEAR_ROCKS_CDP = "04616"
BEAVER_FALLS_CITY = "04792"
BEAVER_MEADOWS_BOROUGH = "04816"
BEAVER_SPRINGS_CDP = "04824"
BEAVER_BOROUGH = "04688"
BEAVERDALE_CDP = "04768"
BEAVERTOWN_CDP = "04832"
BEAVERTOWN_BOROUGH = "04848"
BECHTELSVILLE_BOROUGH = "04896"
BEDFORD_BOROUGH = "04944"
BEECH_CREEK_BOROUGH = "04984"
BEECH_MOUNTAIN_LAKES_CDP = "05028"
BELFAST_CDP = "05152"
BELL_ACRES_BOROUGH = "05216"
BELLE_VERNON_BOROUGH = "05288"
BELLEFONTE_BOROUGH = "05256"
BELLEVILLE_CDP = "05304"
BELLEVUE_BOROUGH = "05312"
BELLWOOD_BOROUGH = "05384"
BELMONT_CDP = "05400"
BEN_AVON_HEIGHTS_BOROUGH = "05520"
BEN_AVON_BOROUGH = "05504"
BENDERSVILLE_BOROUGH = "05536"
BENSON_BOROUGH = "05648"
BENTLEYVILLE_BOROUGH = "05672"
BENTON_BOROUGH = "05680"
BERLIN_BOROUGH = "05776"
BERNVILLE_BOROUGH = "05848"
BERRYSBURG_BOROUGH = "05856"
BERWICK_BOROUGH = "05888"
BERWYN_CDP = "05904"
BESSEMER_BOROUGH = "05936"
BETHANY_BOROUGH = "05976"
BETHEL_CDP = "06000"
BETHEL_PARK_MUNICIPALITY = "06064"
BETHLEHEM_CITY = "06088"
BEURYS_LAKE_CDP = "06171"
BIG_BASS_LAKE_CDP = "06236"
BIG_BEAVER_BOROUGH = "06240"
BIG_RUN_BOROUGH = "06344"
BIGLER_CDP = "06280"
BIGLERVILLE_BOROUGH = "06296"
BIRCHWOOD_LAKES_CDP = "06490"
BIRD_IN_HAND_CDP = "06496"
BIRDSBORO_BOROUGH = "06504"
BIRMINGHAM_BOROUGH = "06560"
BLACK_LICK_CDP = "06744"
BLAIN_BOROUGH = "06824"
BLAIRSVILLE_BOROUGH = "06904"
BLAKELY_BOROUGH = "06928"
BLANCHARD_CDP = "06960"
BLANDBURG_CDP = "06976"
BLANDON_CDP = "06984"
BLAWNOX_BOROUGH = "07000"
BLOOMFIELD_BOROUGH = "07040"
BLOOMING_VALLEY_BOROUGH = "07120"
BLOOMSBURG_TOWN = "07128"
BLOSSBURG_BOROUGH = "07160"
BLUE_BALL_CDP = "07208"
BLUE_BELL_CDP = "07224"
BLUE_KNOB_CDP = "07272"
BLUE_RIDGE_SUMMIT_CDP = "07312"
BOALSBURG_CDP = "07368"
BOBTOWN_CDP = "07384"
BOILING_SPRINGS_CDP = "07472"
BOLIVAR_BOROUGH = "07480"
BONNEAUVILLE_BOROUGH = "07560"
BOOTHWYN_CDP = "07616"
BOSTON_CDP = "07688"
BOSWELL_BOROUGH = "07712"
BOWERS_CDP = "07800"
BOWMANSTOWN_BOROUGH = "07880"
BOWMANSVILLE_CDP = "07896"
BOYERTOWN_BOROUGH = "07960"
BRACKENRIDGE_BOROUGH = "07976"
BRADDOCK_HILLS_BOROUGH = "08008"
BRADDOCK_BOROUGH = "07992"
BRADENVILLE_CDP = "08024"
BRADFORD_WOODS_BOROUGH = "08064"
BRADFORD_CITY = "08040"
BRANCHDALE_CDP = "08208"
BRANDONVILLE_CDP = "08240"
BRAVE_CDP = "08312"
BREINIGSVILLE_CDP = "08392"
BRENTWOOD_BOROUGH = "08416"
BRESSLER_CDP = "08432"
BRIAR_CREEK_BOROUGH = "08472"
BRICKERVILLE_CDP = "08504"
BRIDGEPORT_BOROUGH = "08568"
BRIDGEVILLE_BOROUGH = "08624"
BRIDGEWATER_BOROUGH = "08632"
BRISBIN_BOROUGH = "08744"
BRISTOL_BOROUGH = "08760"
BRITTANY_FARMS_THE_HIGHLANDS_CDP = "08819"
BROAD_TOP_CITY_BOROUGH = "08896"
BROCKWAY_BOROUGH = "08960"
BRODHEADSVILLE_CDP = "09000"
BROOKHAVEN_BOROUGH = "09080"
BROOKS_MILL_CDP = "09196"
BROOKVILLE_BOROUGH = "09224"
BROOMALL_CDP = "09248"
BROWNSTOWN_CDP = "09416"
BROWNSTOWN_BOROUGH = "09400"
BROWNSVILLE_BOROUGH = "09432"
BROWNTOWN_CDP = "09496"
BRUIN_BOROUGH = "09528"
BRYN_ATHYN_BOROUGH = "09696"
BRYN_MAWR_CDP = "09728"
BUCK_RUN_CDP = "09896"
BUCKHORN_CDP = "09792"
BUFFINGTON_CDP = "10096"
BULGER_CDP = "10128"
BURGETTSTOWN_BOROUGH = "10224"
BURLINGTON_BOROUGH = "10240"
BURNHAM_BOROUGH = "10256"
BURNSIDE_BOROUGH = "10280"
BUTLER_CITY = "10464"
BYRNEDALE_CDP = "10600"
CAIRNBROOK_CDP = "10720"
CALIFORNIA_BOROUGH = "10768"
CALLENSBURG_BOROUGH = "10792"
CALLERY_BOROUGH = "10800"
CALLIMONT_BOROUGH = "10808"
CALN_CDP = "10816"
CALUMET_CDP = "10832"
CAMBRIDGE_SPRINGS_BOROUGH = "10912"
CAMP_HILL_BOROUGH = "11000"
CAMPBELLTOWN_CDP = "10960"
CANADOHTA_LAKE_CDP = "11072"
CANAN_STATION_CDP = "11088"
CANOE_CREEK_CDP = "11136"
CANONSBURG_BOROUGH = "11152"
CANTON_BOROUGH = "11160"
CARBONDALE_CITY = "11232"
CARLISLE_BARRACKS_CDP = "11280"
CARLISLE_BOROUGH = "11272"
CARMICHAELS_BOROUGH = "11328"
CARNEGIE_BOROUGH = "11336"
CARNOT_MOON_CDP = "11348"
CARROLL_VALLEY_BOROUGH = "11472"
CARROLLTOWN_BOROUGH = "11456"
CARSON_VALLEY_CDP = "11492"
CASANOVA_CDP = "11544"
CASHTOWN_CDP = "11576"
CASSANDRA_BOROUGH = "11616"
CASSELMAN_BOROUGH = "11624"
CASSVILLE_BOROUGH = "11632"
CASTANEA_CDP = "11648"
CASTLE_SHANNON_BOROUGH = "11680"
CATASAUQUA_BOROUGH = "11720"
CATAWISSA_BOROUGH = "11736"
CECIL_BISHOP_CDP = "11804"
CEDAR_CREST_CDP = "11836"
CEMENTON_CDP = "11976"
CENTERPORT_BOROUGH = "12104"
CENTERVILLE_BOROUGH_CRAWFORD_COUNTY = "12184"
CENTERVILLE_BOROUGH_WASHINGTON_COUNTY = "12224"
CENTRAL_CITY_BOROUGH = "12296"
CENTRALIA_BOROUGH = "12312"
CENTRE_HALL_BOROUGH = "12376"
CETRONIA_CDP = "12424"
CHADDS_FORD_CDP = "12440"
CHALFANT_BOROUGH = "12496"
CHALFONT_BOROUGH = "12504"
CHALKHILL_CDP = "12512"
CHAMBERSBURG_BOROUGH = "12536"
CHAPMAN_BOROUGH = "12656"
CHARLEROI_BOROUGH = "12704"
CHARLOTTSVILLE_CDP = "12768"
CHASE_CDP = "12864"
CHELTENHAM_VILLAGE_CDP = "12973"
CHERRY_TREE_BOROUGH = "13120"
CHERRY_VALLEY_BOROUGH = "13152"
CHERRYVILLE_CDP = "13168"
CHEST_SPRINGS_BOROUGH = "13384"
CHESTER_HEIGHTS_BOROUGH = "13232"
CHESTER_HILL_BOROUGH = "13240"
CHESTER_CITY = "13208"
CHESTERBROOK_CDP = "13216"
CHESTNUT_HILL_CDP = "13336"
CHESWICK_BOROUGH = "13392"
CHEVY_CHASE_HEIGHTS_CDP = "13400"
CHEWTON_CDP = "13408"
CHEYNEY_UNIVERSITY_CDP = "13418"
CHICORA_BOROUGH = "13440"
CHINCHILLA_CDP = "13480"
CHRISTIANA_BOROUGH = "13512"
CHURCH_HILL_CDP = "13596"
CHURCHILL_BOROUGH = "13608"
CHURCHTOWN_CDP = "13632"
CHURCHVILLE_CDP = "13648"
CLAIRTON_CITY = "13704"
CLAPPERTOWN_CDP = "13728"
CLARENCE_CDP = "13768"
CLARENDON_BOROUGH = "13776"
CLARION_BOROUGH = "13800"
CLARK_BOROUGH = "13832"
CLARKS_GREEN_BOROUGH = "13864"
CLARKS_SUMMIT_BOROUGH = "13880"
CLARKSVILLE_BOROUGH = "13896"
CLAY_CDP = "13952"
CLAYSBURG_CDP = "13992"
CLAYSVILLE_BOROUGH = "14000"
CLEARFIELD_BOROUGH = "14064"
CLEONA_BOROUGH = "14160"
CLIFTON_HEIGHTS_BOROUGH = "14264"
CLINTON_CDP = "14296"
CLINTONDALE_CDP = "14368"
CLINTONVILLE_BOROUGH = "14376"
CLYMER_BOROUGH = "14520"
COAL_CENTER_BOROUGH = "14568"
COALDALE_BOROUGH_BEDFORD_COUNTY = "14584"
COALDALE_BOROUGH_SCHUYLKILL_COUNTY = "14600"
COALMONT_BOROUGH = "14640"
COALPORT_BOROUGH = "14656"
COATESVILLE_CITY = "14712"
COBURN_CDP = "14760"
COCHRANTON_BOROUGH = "14800"
COCHRANVILLE_CDP = "14808"
COKEBURG_BOROUGH = "14896"
COLLEGEVILLE_BOROUGH = "15192"
COLLINGDALE_BOROUGH = "15232"
COLLINSBURG_CDP = "15248"
COLONIAL_PARK_CDP = "15328"
COLONY_PARK_CDP = "15368"
COLUMBIA_BOROUGH = "15384"
COLUMBUS_CDP = "15400"
COLVER_CDP = "15416"
COLWYN_BOROUGH = "15432"
COMMODORE_CDP = "15464"
CONASHAUGH_LAKES_CDP = "15479"
CONESTOGA_CDP = "15584"
CONFLUENCE_BOROUGH = "15680"
CONNEAUT_LAKE_BOROUGH = "15744"
CONNEAUT_LAKESHORE_CDP = "15755"
CONNEAUTVILLE_BOROUGH = "15760"
CONNELLSVILLE_CITY = "15776"
CONNOQUENESSING_BOROUGH = "15808"
CONSHOHOCKEN_BOROUGH = "15848"
CONTINENTAL_COURTS_CDP = "15860"
CONWAY_BOROUGH = "15872"
CONYNGHAM_BOROUGH = "15888"
COOPERSBURG_BOROUGH = "16056"
COOPERSTOWN_BOROUGH = "16080"
COPLAY_BOROUGH = "16128"
CORAL_CDP = "16136"
CORAOPOLIS_BOROUGH = "16144"
CORNWALL_BOROUGH = "16256"
CORNWELLS_HEIGHTS_CDP = "16272"
CORRY_CITY = "16296"
CORSICA_BOROUGH = "16304"
COTTON_TOWN_CDP = "16432"
COUDERSPORT_BOROUGH = "16448"
COURTDALE_BOROUGH = "16568"
COVE_FORGE_CDP = "16590"
CRABTREE_CDP = "16816"
CRAFTON_BOROUGH = "16848"
CRANESVILLE_BOROUGH = "16960"
CREEKSIDE_BOROUGH = "17024"
CRENSHAW_CDP = "17040"
CRESSON_BOROUGH = "17136"
CRESSONA_BOROUGH = "17152"
CROSS_CREEK_CDP = "17320"
CROSS_KEYS_CDP = "17368"
CROSS_ROADS_BOROUGH = "17416"
CROWN_CDP = "17440"
CROYDON_CDP = "17448"
CRUCIBLE_CDP = "17528"
CULP_CDP = "17624"
CUMBOLA_CDP = "17680"
CURRYVILLE_CDP = "17784"
CURTISVILLE_CDP = "17832"
CURWENSVILLE_BOROUGH = "17840"
DAISYTOWN_BOROUGH = "17976"
DALE_BOROUGH = "18000"
DALLAS_BOROUGH = "18048"
DALLASTOWN_BOROUGH = "18072"
DALMATIA_CDP = "18080"
DALTON_BOROUGH = "18088"
DANVILLE_BOROUGH = "18136"
DARBY_BOROUGH = "18152"
DARLINGTON_BOROUGH = "18192"
DAUBERVILLE_CDP = "18256"
DAUPHIN_BOROUGH = "18272"
DAVIDSVILLE_CDP = "18312"
DAWSON_BOROUGH = "18360"
DAYTON_BOROUGH = "18400"
DESALES_UNIVERSITY_CDP = "18998"
DEEMSTON_BOROUGH = "18496"
DEER_LAKE_CDP = "18568"
DEER_LAKE_BOROUGH = "18576"
DEFIANCE_CDP = "18608"
DELANO_CDP = "18664"
DELAWARE_WATER_GAP_BOROUGH = "18736"
DELMONT_BOROUGH = "18768"
DELTA_BOROUGH = "18800"
DENVER_BOROUGH = "18888"
DERRY_BOROUGH = "18960"
DEVON_CDP = "19040"
DEWART_CDP = "19048"
DICKSON_CITY_BOROUGH = "19160"
DILLSBURG_BOROUGH = "19208"
DILWORTHTOWN_CDP = "19232"
DIXONVILLE_CDP = "19344"
DONALDSON_CDP = "19432"
DONEGAL_BOROUGH = "19472"
DONORA_BOROUGH = "19536"
DORMONT_BOROUGH = "19576"
DORNEYVILLE_CDP = "19584"
DOUGLASSVILLE_CDP = "19680"
DOVER_BOROUGH = "19696"
DOWNINGTOWN_BOROUGH = "19752"
DOYLESTOWN_BOROUGH = "19784"
DRAVOSBURG_BOROUGH = "19856"
DREXEL_HILL_CDP = "19920"
DRIFTWOOD_BOROUGH = "19976"
DRY_TAVERN_CDP = "20080"
DRYVILLE_CDP = "20096"
DUBOIS_CITY = "20136"
DUBLIN_BOROUGH = "20104"
DUBOISTOWN_BOROUGH = "20144"
DUDLEY_BOROUGH = "20152"
DUMB_HUNDRED_CDP = "20214"
DUNBAR_BOROUGH = "20216"
DUNCANNON_BOROUGH = "20240"
DUNCANSVILLE_BOROUGH = "20248"
DUNLEVY_BOROUGH = "20328"
DUNLO_CDP = "20336"
DUNMORE_BOROUGH = "20352"
DUNNSTOWN_CDP = "20416"
DUPONT_BOROUGH = "20424"
DUQUESNE_CITY = "20432"
DURYEA_BOROUGH = "20512"
DUSHORE_BOROUGH = "20528"
EAGLE_CDP = "20600"
EAGLE_CREEK_CDP = "20604"
EAGLE_LAKE_CDP = "20634"
EAGLES_MERE_BOROUGH = "20648"
EAGLEVIEW_CDP = "20662"
EAGLEVILLE_CDP_CENTRE_COUNTY = "20664"
EAGLEVILLE_CDP_MONTGOMERY_COUNTY = "20672"
EARLSTON_CDP = "20704"
EAST_ALTOONA_CDP = "20752"
EAST_BANGOR_BOROUGH = "20776"
EAST_BERLIN_BOROUGH = "20792"
EAST_BERWICK_CDP = "20800"
EAST_BRADY_BOROUGH = "20840"
EAST_BUTLER_BOROUGH = "20904"
EAST_CONEMAUGH_BOROUGH = "20992"
EAST_EARL_CDP = "21064"
EAST_FREEDOM_CDP = "21176"
EAST_GREENVILLE_BOROUGH = "21200"
EAST_LANSDOWNE_BOROUGH = "21384"
EAST_MCKEESPORT_BOROUGH = "21444"
EAST_PETERSBURG_BOROUGH = "21688"
EAST_PITTSBURGH_BOROUGH = "21712"
EAST_PROSPECT_BOROUGH = "21728"
EAST_ROCHESTER_BOROUGH = "21752"
EAST_SALEM_CDP = "21792"
EAST_SHARPSBURG_CDP = "21808"
EAST_SIDE_BOROUGH = "21816"
EAST_STROUDSBURG_BOROUGH = "21872"
EAST_UNIONTOWN_CDP = "21960"
EAST_VANDERGRIFT_BOROUGH = "21976"
EAST_WASHINGTON_BOROUGH = "22016"
EAST_WATERFORD_CDP = "22024"
EAST_YORK_CDP = "22104"
EASTLAWN_GARDENS_CDP = "21400"
EASTON_CITY = "21648"
EASTVALE_BOROUGH = "21968"
EAU_CLAIRE_BOROUGH = "22128"
EBENSBURG_BOROUGH = "22144"
ECONOMY_BOROUGH = "22264"
EDDINGTON_CDP = "22280"
EDDYSTONE_BOROUGH = "22296"
EDENBORN_CDP = "22344"
EDENBURG_CDP = "22352"
EDGEWOOD_CDP = "22528"
EDGEWOOD_BOROUGH = "22520"
EDGEWORTH_BOROUGH = "22576"
EDIE_CDP = "22600"
EDINBORO_BOROUGH = "22608"
EDWARDSVILLE_BOROUGH = "22672"
EFFORT_CDP = "22680"
EGYPT_CDP = "22696"
EHRENFELD_BOROUGH = "22712"
EIGHTY_FOUR_CDP = "22736"
ELBERTA_CDP = "22776"
ELCO_BOROUGH = "22800"
ELDERTON_BOROUGH = "22832"
ELDORADO_CDP = "22856"
ELDRED_BOROUGH = "22888"
ELGIN_BOROUGH = "22960"
ELIM_CDP = "22976"
ELIZABETH_BOROUGH = "22992"
ELIZABETHTOWN_BOROUGH = "23016"
ELIZABETHVILLE_BOROUGH = "23024"
ELKINS_PARK_CDP = "23128"
ELKLAND_BOROUGH = "23152"
ELLPORT_BOROUGH = "23280"
ELLSWORTH_BOROUGH = "23296"
ELLWOOD_CITY_BOROUGH = "23304"
ELRAMA_CDP = "23392"
ELVERSON_BOROUGH = "23440"
ELYSBURG_CDP = "23472"
EMERALD_LAKES_CDP = "23540"
EMIGSVILLE_CDP = "23560"
EMLENTON_BOROUGH = "23568"
EMMAUS_BOROUGH = "23584"
EMPORIUM_BOROUGH = "23600"
EMSWORTH_BOROUGH = "23616"
ENGLEWOOD_CDP = "23688"
ENHAUT_CDP = "23704"
ENLOW_CDP = "23720"
ENOLA_CDP = "23744"
ENON_VALLEY_BOROUGH = "23768"
EPHRATA_BOROUGH = "23832"
ERIE_CITY = "24000"
ERNEST_BOROUGH = "24040"
ESPY_CDP = "24088"
ETNA_BOROUGH = "24160"
EVANS_CITY_BOROUGH = "24248"
EVANSBURG_CDP = "24240"
EVERETT_BOROUGH = "24304"
EVERSON_BOROUGH = "24336"
EXETER_BOROUGH = "24392"
EXPORT_BOROUGH = "24432"
EXTON_CDP = "24440"
EYERS_GROVE_CDP = "24448"
FACTORYVILLE_BOROUGH = "24488"
FAIRCHANCE_BOROUGH = "24536"
FAIRDALE_CDP = "24544"
FAIRFIELD_BOROUGH = "24560"
FAIRHOPE_CDP = "24664"
FAIRLESS_HILLS_CDP = "24712"
FAIRVIEW_CDP = "24856"
FAIRVIEW_BOROUGH = "24832"
FAIRVIEW_FERNDALE_CDP = "24948"
FALLS_CREEK_BOROUGH = "25136"
FALLSTON_BOROUGH = "25152"
FALMOUTH_CDP = "25168"
FARMERSVILLE_CDP = "25248"
FARMINGTON_CDP = "25280"
FARRELL_CITY = "25360"
FARWELL_CDP = "25376"
FAWN_GROVE_BOROUGH = "25416"
FAWN_LAKE_FOREST_CDP = "25420"
FAXON_CDP = "25424"
FAYETTE_CITY_BOROUGH = "25456"
FAYETTEVILLE_CDP = "25464"
FEASTERVILLE_CDP = "25496"
FELLSBURG_CDP = "25568"
FELTON_BOROUGH = "25584"
FERNDALE_BOROUGH = "25680"
FERNVILLE_CDP = "25744"
FINLEYVILLE_BOROUGH = "25944"
FISHERVILLE_CDP = "26036"
FIVEPOINTVILLE_CDP = "26232"
FLEETWOOD_BOROUGH = "26280"
FLEMINGTON_BOROUGH = "26296"
FLOURTOWN_CDP = "26376"
FLYING_HILLS_CDP = "26397"
FOLCROFT_BOROUGH = "26408"
FOLSOM_CDP = "26432"
FOOT_OF_TEN_CDP = "26488"
FORCE_CDP = "26504"
FORD_CITY_BOROUGH = "26512"
FORD_CLIFF_BOROUGH = "26520"
FOREST_CITY_BOROUGH = "26560"
FOREST_HILLS_BOROUGH = "26592"
FORESTVILLE_CDP = "26704"
FORKSVILLE_BOROUGH = "26760"
FORT_FETTER_CDP = "26776"
FORT_INDIANTOWN_GAP_CDP = "26812"
FORT_LOUDON_CDP = "26824"
FORT_WASHINGTON_CDP = "26872"
FORTY_FORT_BOROUGH = "26880"
FOSTER_BROOK_CDP = "26960"
FOSTORIA_CDP = "26976"
FOUNDRYVILLE_CDP = "26984"
FOUNTAIN_HILL_BOROUGH = "27008"
FOUNTAIN_SPRINGS_CDP = "27024"
FOX_CHAPEL_BOROUGH = "27120"
FOX_CHASE_CDP = "27130"
FOXBURG_BOROUGH = "27112"
FRACKVILLE_BOROUGH = "27232"
FRANKFORT_SPRINGS_BOROUGH = "27312"
FRANKLIN_FORGE_CDP = "27517"
FRANKLIN_PARK_BOROUGH = "27552"
FRANKLIN_BOROUGH = "27360"
FRANKLIN_CITY = "27456"
FRANKLINTOWN_BOROUGH = "27576"
FRANKSTOWN_CDP = "27592"
FRAZER_CDP = "27616"
FREDERICKSBURG_CDP_BLAIR_COUNTY = "27641"
FREDERICKSBURG_CDP_CRAWFORD_COUNTY = "27648"
FREDERICKSBURG_CDP_LEBANON_COUNTY = "27656"
FREDERICKTOWN_CDP = "27672"
FREDONIA_BOROUGH = "27688"
FREEBURG_BOROUGH = "27696"
FREEDOM_BOROUGH = "27712"
FREELAND_BOROUGH = "27744"
FREEMANSBURG_BOROUGH = "27760"
FREEPORT_BOROUGH = "27784"
FRIEDENS_CDP = "27928"
FRIEDENSBURG_CDP = "27936"
FRIENDSVILLE_BOROUGH = "27968"
FRIESVILLE_CDP = "27976"
FRISCO_CDP = "28000"
FRIZZLEBURG_CDP = "28014"
FRYSTOWN_CDP = "28128"
FULLERTON_CDP = "28144"
GALETON_BOROUGH = "28280"
GALLITZIN_BOROUGH = "28328"
GANISTER_CDP = "28360"
GAP_CDP = "28376"
GARDEN_VIEW_CDP = "28456"
GARDNERS_CDP = "28488"
GARRETT_BOROUGH = "28520"
GASTONVILLE_CDP = "28600"
GEESEYTOWN_CDP = "28696"
GEISTOWN_BOROUGH = "28720"
GENEVA_CDP = "28768"
GEORGETOWN_CDP_LANCASTER_COUNTY = "28828"
GEORGETOWN_CDP_LUZERNE_COUNTY = "28832"
GEORGETOWN_BOROUGH = "28824"
GETTYSBURG_BOROUGH = "28960"
GIBRALTAR_CDP = "29000"
GIBSONIA_CDP = "29040"
GILBERTON_BOROUGH = "29088"
GILBERTSVILLE_CDP = "29096"
GIRARD_BOROUGH = "29232"
GIRARDVILLE_BOROUGH = "29264"
GLASGOW_BOROUGH = "29392"
GLASSPORT_BOROUGH = "29432"
GLEN_CAMPBELL_BOROUGH = "29512"
GLEN_HOPE_BOROUGH = "29632"
GLEN_LYON_CDP = "29680"
GLEN_OSBORNE_BOROUGH = "29732"
GLEN_ROCK_BOROUGH = "29760"
GLENBURN_CDP = "29496"
GLENDON_BOROUGH = "29568"
GLENFIELD_BOROUGH = "29592"
GLENMOORE_CDP = "29704"
GLENOLDEN_BOROUGH = "29720"
GLENSHAW_CDP = "29800"
GLENSIDE_CDP = "29808"
GOLD_KEY_LAKE_CDP = "30013"
GOLDSBORO_BOROUGH = "30016"
GOODVILLE_CDP = "30096"
GORDON_BOROUGH = "30128"
GORDONVILLE_CDP = "30136"
GOUGLERSVILLE_CDP = "30192"
GOULDSBORO_CDP = "30200"
GRACETON_CDP = "30224"
GRAMPIAN_BOROUGH = "30280"
GRANTLEY_CDP = "30435"
GRANVILLE_CDP = "30472"
GRAPEVILLE_CDP = "30512"
GRASSFLAT_CDP = "30528"
GRATZ_BOROUGH = "30600"
GRAY_CDP = "30628"
GRAZIERVILLE_CDP = "30704"
GREAT_BEND_BOROUGH = "30728"
GREEN_HILLS_BOROUGH = "31082"
GREEN_LANE_BOROUGH = "31088"
GREEN_TREE_BOROUGH = "31256"
GREENCASTLE_BOROUGH = "30896"
GREENFIELDS_CDP = "31038"
GREENOCK_CDP = "31120"
GREENS_LANDING_CDP = "31208"
GREENSBORO_BOROUGH = "31192"
GREENSBURG_CITY = "31200"
GREENVILLE_BOROUGH = "31328"
GREENWOOD_CDP = "31368"
GRIER_CITY_CDP = "31536"
GRILL_CDP = "31568"
GRINDSTONE_CDP = "31592"
GROVE_CITY_BOROUGH = "31656"
GUILFORD_CDP = "31716"
GUYS_MILLS_CDP = "31840"
HALFWAY_HOUSE_CDP = "32024"
HALIFAX_BOROUGH = "32032"
HALLAM_BOROUGH = "32056"
HALLSTEAD_BOROUGH = "32080"
HAMBURG_BOROUGH = "32120"
HAMORTON_CDP = "32280"
HAMPTON_CDP = "32320"
HANNASVILLE_CDP = "32384"
HANOVER_BOROUGH = "32448"
HARLEIGH_CDP = "32600"
HARLEYSVILLE_CDP = "32616"
HARMONSBURG_CDP = "32656"
HARMONY_BOROUGH = "32688"
HARRISBURG_CITY = "32800"
HARRISON_CITY_CDP = "32864"
HARRISVILLE_BOROUGH = "32896"
HARTLETON_BOROUGH = "32936"
HARTSTOWN_CDP = "32976"
HARVEYS_LAKE_BOROUGH = "33000"
HARWICK_CDP = "33024"
HASSON_HEIGHTS_CDP = "33072"
HASTINGS_BOROUGH = "33080"
HATBORO_BOROUGH = "33088"
HATFIELD_BOROUGH = "33112"
HAVERFORD_COLLEGE_CDP = "33154"
HAWK_RUN_CDP = "33184"
HAWLEY_BOROUGH = "33200"
HAWTHORN_BOROUGH = "33216"
HAYSVILLE_BOROUGH = "33312"
HAYTI_CDP = "33328"
HAZEN_CDP = "33364"
HAZLETON_CITY = "33408"
HEBRON_CDP = "33504"
HECKSCHERVILLE_CDP = "33528"
HEGINS_CDP = "33576"
HEIDELBERG_BOROUGH = "33592"
HEIDLERSBURG_CDP = "33632"
HEILWOOD_CDP = "33672"
HELLERTOWN_BOROUGH = "33744"
HEMLOCK_FARMS_CDP = "33772"
HENDERSONVILLE_CDP = "33840"
HENRIETTA_CDP = "33888"
HEREFORD_CDP = "34008"
HERMINIE_CDP = "34048"
HERMITAGE_CITY = "34064"
HERNDON_BOROUGH = "34080"
HERSHEY_CDP = "34144"
HICKORY_CDP = "34256"
HICKORY_HILLS_CDP = "34308"
HIGHLAND_PARK_CDP = "34592"
HIGHSPIRE_BOROUGH = "34664"
HILLDALE_CDP = "34776"
HILLER_CDP = "34784"
HOKENDAUQUA_CDP = "35120"
HOLIDAY_POCONO_CDP = "35172"
HOLLIDAYSBURG_BOROUGH = "35224"
HOLTERS_CROSSING_CDP = "35336"
HOMEACRE_LYNDORA_CDP = "35364"
HOMER_CITY_BOROUGH = "35408"
HOMESTEAD_BOROUGH = "35424"
HOMETOWN_CDP = "35448"
HOMEWOOD_AT_MARTINSBURG_CDP = "35500"
HOMEWOOD_BOROUGH = "35488"
HONESDALE_BOROUGH = "35520"
HONEY_BROOK_BOROUGH = "35528"
HOOKSTOWN_BOROUGH = "35576"
HOOVERSVILLE_BOROUGH = "35608"
HOP_BOTTOM_BOROUGH = "35624"
HOPELAND_CDP = "35632"
HOPEWELL_BOROUGH = "35648"
HOPWOOD_CDP = "35728"
HORSHAM_CDP = "35800"
HOSTETTER_CDP = "35872"
HOUSERVILLE_CDP = "35888"
HOUSTON_BOROUGH = "35896"
HOUTZDALE_BOROUGH = "35928"
HOWARD_BOROUGH = "35960"
HUBLERSBURG_CDP = "36064"
HUDSON_CDP = "36096"
HUGHESTOWN_BOROUGH = "36152"
HUGHESVILLE_BOROUGH = "36160"
HULMEVILLE_BOROUGH = "36192"
HUMMELS_WHARF_CDP = "36240"
HUMMELSTOWN_BOROUGH = "36232"
HUNKER_BOROUGH = "36288"
HUNTERSTOWN_CDP = "36352"
HUNTINGDON_BOROUGH = "36368"
HYDE_CDP = "36568"
HYDE_PARK_CDP = "36576"
HYDE_PARK_BOROUGH = "36592"
HYDETOWN_BOROUGH = "36616"
HYNDMAN_BOROUGH = "36640"
IDAVILLE_CDP = "36712"
IMPERIAL_CDP = "36768"
INDIAN_LAKE_BOROUGH = "36888"
INDIAN_MOUNTAIN_LAKE_CDP = "36904"
INDIANA_BOROUGH = "36816"
INDUSTRY_BOROUGH = "36944"
INGRAM_BOROUGH = "37000"
INKERMAN_CDP = "37008"
INTERCOURSE_CDP = "37016"
IOLA_CDP = "37024"
IRONVILLE_CDP = "37136"
IRVONA_BOROUGH = "37192"
IRWIN_BOROUGH = "37208"
IVYLAND_BOROUGH = "37304"
JACKSON_CENTER_BOROUGH = "37496"
JACKSONVILLE_CDP_CENTRE_COUNTY = "37544"
JACKSONVILLE_CDP_INDIANA_COUNTY = "37552"
JACKSONWALD_CDP = "37584"
JACOBUS_BOROUGH = "37640"
JAMES_CITY_CDP = "37656"
JAMESTOWN_BOROUGH = "37696"
JAMISON_CITY_CDP = "37728"
JEANNETTE_CITY = "37784"
JEDDO_BOROUGH = "37792"
JEFFERSON_HILLS_BOROUGH = "37955"
JEFFERSON_BOROUGH_GREENE_COUNTY = "37880"
JEFFERSON_BOROUGH_YORK_COUNTY = "37944"
JENKINTOWN_BOROUGH = "38000"
JENNERSTOWN_BOROUGH = "38048"
JERMYN_BOROUGH = "38096"
JEROME_CDP = "38104"
JERSEY_SHORE_BOROUGH = "38128"
JERSEYTOWN_CDP = "38152"
JESSUP_BOROUGH = "38160"
JIM_THORPE_BOROUGH = "38200"
JOFFRE_CDP = "38240"
JOHNSONBURG_BOROUGH = "38248"
JOHNSTOWN_CITY = "38288"
JONESTOWN_CDP = "38392"
JONESTOWN_BOROUGH = "38400"
JUGTOWN_CDP = "38514"
JULIAN_CDP = "38528"
JUNIATA_GAP_CDP = "38632"
JUNIATA_TERRACE_BOROUGH = "38640"
KANE_BOROUGH = "38688"
KAPP_HEIGHTS_CDP = "38744"
KARNS_CITY_BOROUGH = "38768"
KELAYRES_CDP = "39056"
KEMPTON_CDP = "39224"
KENHORST_BOROUGH = "39256"
KENILWORTH_CDP = "39272"
KENMAR_CDP = "39280"
KENNERDELL_CDP = "39336"
KENNETT_SQUARE_BOROUGH = "39352"
KERRTOWN_CDP = "39504"
KERSEY_CDP = "39512"
KIMBERTON_CDP = "39648"
KING_OF_PRUSSIA_CDP = "39736"
KINGSTON_BOROUGH = "39784"
KIRKWOOD_CDP = "39944"
KISKIMERE_CDP = "39960"
KISTLER_BOROUGH = "40016"
KITTANNING_BOROUGH = "40040"
KLAHR_CDP = "40072"
KLINGERSTOWN_CDP = "40136"
KNOX_BOROUGH = "40272"
KNOXVILLE_BOROUGH = "40360"
KOPPEL_BOROUGH = "40400"
KRATZERVILLE_CDP = "40432"
KREAMER_CDP = "40464"
KULPMONT_BOROUGH = "40584"
KULPSVILLE_CDP = "40608"
KUTZTOWN_UNIVERSITY_CDP = "40666"
KUTZTOWN_BOROUGH = "40656"
KYLERTOWN_CDP = "40680"
LACEYVILLE_BOROUGH = "40744"
LAFLIN_BOROUGH = "40848"
LAKE_ARTHUR_ESTATES_CDP = "40948"
LAKE_CITY_BOROUGH = "40960"
LAKE_HERITAGE_CDP = "40981"
LAKE_LATONKA_CDP = "40982"
LAKE_MEADE_CDP = "40988"
LAKE_WINOLA_CDP = "41080"
LAKE_WYNONAH_CDP = "41099"
LAKEMONT_CDP = "40992"
LAMAR_CDP = "41104"
LAMPETER_CDP = "41192"
LANCASTER_CITY = "41216"
LANDINGVILLE_BOROUGH = "41264"
LANDISBURG_BOROUGH = "41272"
LANDISVILLE_CDP = "41304"
LANESBORO_BOROUGH = "41336"
LANGELOTH_CDP = "41376"
LANGHORNE_MANOR_BOROUGH = "41416"
LANGHORNE_BOROUGH = "41392"
LANSDALE_BOROUGH = "41432"
LANSDOWNE_BOROUGH = "41440"
LANSFORD_BOROUGH = "41464"
LAPORTE_BOROUGH = "41512"
LARKE_CDP = "41580"
LARKSVILLE_BOROUGH = "41608"
LATROBE_BOROUGH = "41680"
LATTIMER_CDP = "41700"
LAUREL_MOUNTAIN_BOROUGH = "41834"
LAUREL_RUN_BOROUGH = "41848"
LAURELDALE_BOROUGH = "41768"
LAURELTON_CDP = "41856"
LAURYS_STATION_CDP = "41880"
LAVELLE_CDP = "41904"
LAWNTON_CDP = "41944"
LAWRENCE_CDP = "41968"
LAWRENCE_PARK_CDP = "41992"
LAWRENCEVILLE_BOROUGH = "42016"
LAWSON_HEIGHTS_CDP = "42032"
LERAYSVILLE_BOROUGH = "42824"
LEAMERSVILLE_CDP = "42136"
LEBANON_SOUTH_CDP = "42192"
LEBANON_CITY = "42168"
LEECHBURG_BOROUGH = "42280"
LEEPER_CDP = "42328"
LEESPORT_BOROUGH = "42352"
LEETSDALE_BOROUGH = "42392"
LEHIGHTON_BOROUGH = "42472"
LEITH_HATFIELD_CDP = "42596"
LEMONT_CDP = "42632"
LEMONT_FURNACE_CDP = "42640"
LEMOYNE_BOROUGH = "42648"
LENAPE_HEIGHTS_CDP = "42672"
LENHARTSVILLE_BOROUGH = "42688"
LENKERVILLE_CDP = "42704"
LEOLA_CDP = "42776"
LEVEL_GREEN_CDP = "42912"
LEVITTOWN_CDP = "42928"
LEWIS_RUN_BOROUGH = "42984"
LEWISBERRY_BOROUGH = "42968"
LEWISBURG_BOROUGH = "42976"
LEWISTOWN_BOROUGH = "43000"
LIBERTY_BOROUGH_ALLEGHENY_COUNTY = "43064"
LIBERTY_BOROUGH_TIOGA_COUNTY = "43128"
LIGHTSTREET_CDP = "43224"
LIGONIER_BOROUGH = "43232"
LILLY_BOROUGH = "43248"
LIMA_CDP = "43272"
LIME_RIDGE_CDP = "43320"
LINCOLN_PARK_CDP = "43496"
LINCOLN_UNIVERSITY_CDP = "43544"
LINCOLN_BOROUGH = "43408"
LINCOLNVILLE_CDP = "43552"
LINDS_CROSSING_CDP = "43628"
LINESVILLE_BOROUGH = "43656"
LINGLESTOWN_CDP = "43672"
LINNTOWN_CDP = "43704"
LINWOOD_CDP = "43720"
LIONVILLE_CDP = "43744"
LITITZ_BOROUGH = "43816"
LITTLE_BRITAIN_CDP = "43828"
LITTLE_MEADOWS_BOROUGH = "43928"
LITTLESTOWN_BOROUGH = "43944"
LIVERPOOL_BOROUGH = "43968"
LOCK_HAVEN_CITY = "44128"
LOCUSTDALE_CDP = "44224"
LOGANTON_BOROUGH = "44400"
LOGANVILLE_BOROUGH = "44416"
LONG_BRANCH_BOROUGH = "44512"
LONGFELLOW_CDP = "44528"
LOOP_CDP = "44632"
LORAIN_BOROUGH = "44664"
LORANE_CDP = "44672"
LORETTO_BOROUGH = "44704"
LOWER_ALLEN_CDP = "44824"
LOWER_BURRELL_CITY = "44864"
LOYALHANNA_CDP = "45192"
LUCERNE_MINES_CDP = "45312"
LUMBER_CITY_CDP = "45452"
LUZERNE_BOROUGH = "45568"
LYKENS_BOROUGH = "45592"
LYNNWOOD_PRICEDALE_CDP = "45732"
LYONS_BOROUGH = "45752"
MACUNGIE_BOROUGH = "46392"
MADISON_BOROUGH = "46488"
MADISONBURG_CDP = "46504"
MAHAFFEY_BOROUGH = "46568"
MAHANOY_CITY_BOROUGH = "46592"
MAINVILLE_CDP = "46720"
MAITLAND_CDP = "46728"
MALVERN_BOROUGH = "46792"
MAMMOTH_CDP = "46800"
MANCHESTER_BOROUGH = "46864"
MANHEIM_BOROUGH = "46888"
MANNS_CHOICE_BOROUGH = "46944"
MANOR_BOROUGH = "47000"
MANORVILLE_BOROUGH = "47064"
MANSFIELD_BOROUGH = "47080"
MAPLE_GLEN_CDP = "47152"
MAPLETON_BOROUGH = "47248"
MAPLETOWN_CDP = "47264"
MARCUS_HOOK_BOROUGH = "47344"
MARIANNA_BOROUGH = "47400"
MARIANNE_CDP = "47404"
MARIENVILLE_CDP = "47416"
MARIETTA_BOROUGH = "47424"
MARION_CDP = "47464"
MARION_CENTER_BOROUGH = "47472"
MARION_HEIGHTS_BOROUGH = "47480"
MARKLESBURG_BOROUGH = "47544"
MARKLEYSBURG_BOROUGH = "47560"
MARLIN_CDP = "47600"
MARS_BOROUGH = "47672"
MARSHALLTON_CDP_CHESTER_COUNTY = "47728"
MARSHALLTON_CDP_NORTHUMBERLAND_COUNTY = "47736"
MARTINS_CREEK_CDP = "47896"
MARTINSBURG_JUNCTION_CDP = "47880"
MARTINSBURG_BOROUGH = "47872"
MARYSVILLE_BOROUGH = "47968"
MASONTOWN_BOROUGH = "48000"
MASTHOPE_CDP = "48032"
MATAMORAS_BOROUGH = "48048"
MATHER_CDP = "48064"
MATTAWANA_CDP = "48072"
MAXATAWNY_CDP = "48120"
MAYFIELD_BOROUGH = "48176"
MAYTOWN_CDP = "48224"
MCADOO_BOROUGH = "45824"
MCALISTERVILLE_CDP = "45848"
MCCLURE_BOROUGH = "45992"
MCCONNELLSBURG_BOROUGH = "46000"
MCCONNELLSTOWN_CDP = "46016"
MCDONALD_BOROUGH = "46072"
MCELHATTAN_CDP = "46112"
MCEWENSVILLE_BOROUGH = "46120"
MCGOVERN_CDP = "46160"
MCKEAN_BOROUGH = "46216"
MCKEANSBURG_CDP = "46232"
MCKEE_CDP = "46240"
MCKEES_ROCKS_BOROUGH = "46264"
MCKEESPORT_CITY = "46256"
MCKINLEY_CDP = "46280"
MCKNIGHTSTOWN_CDP = "46312"
MCMURRAY_CDP = "46344"
MCSHERRYSTOWN_BOROUGH = "46376"
MCVEYTOWN_BOROUGH = "46400"
MEADOWLANDS_CDP = "48320"
MEADOWOOD_CDP = "48336"
MEADVILLE_CITY = "48360"
MECHANICSBURG_BOROUGH = "48376"
MECHANICSVILLE_BOROUGH = "48448"
MEDIA_BOROUGH = "48480"
MERCER_BOROUGH = "48696"
MERCERSBURG_BOROUGH = "48704"
MERIDIAN_CDP = "48728"
MERION_STATION_CDP = "48768"
MERTZTOWN_CDP = "48824"
MESHOPPEN_BOROUGH = "48856"
MESSIAH_COLLEGE_CDP = "48868"
MEXICO_CDP = "48904"
MEYERSDALE_BOROUGH = "48912"
MIDDLEBURG_BOROUGH = "48960"
MIDDLEPORT_BOROUGH = "49048"
MIDDLETOWN_CDP = "49144"
MIDDLETOWN_BOROUGH = "49128"
MIDLAND_BOROUGH = "49184"
MIDWAY_CDP = "49224"
MIDWAY_BOROUGH = "49240"
MIFFLIN_BOROUGH = "49272"
MIFFLINBURG_BOROUGH = "49288"
MIFFLINTOWN_BOROUGH = "49304"
MIFFLINVILLE_CDP = "49312"
MILESBURG_BOROUGH = "49368"
MILFORD_SQUARE_CDP = "49440"
MILFORD_BOROUGH = "49400"
MILL_CREEK_BOROUGH = "49552"
MILL_HALL_BOROUGH = "49760"
MILL_RUN_CDP = "49848"
MILL_VILLAGE_BOROUGH = "49936"
MILLBOURNE_BOROUGH = "49504"
MILLERSBURG_BOROUGH = "49680"
MILLERSTOWN_CDP = "49704"
MILLERSTOWN_BOROUGH = "49720"
MILLERSVILLE_BOROUGH = "49728"
MILLERTON_CDP = "49736"
MILLHEIM_BOROUGH = "49768"
MILLSBORO_CDP = "49880"
MILLVALE_BOROUGH = "49920"
MILLVILLE_BOROUGH = "49944"
MILLWOOD_CDP = "49960"
MILROY_CDP = "50000"
MILTON_BOROUGH = "50016"
MINERSVILLE_BOROUGH = "50088"
MINGOVILLE_CDP = "50104"
MISERICORDIA_UNIVERSITY_CDP = "50160"
MOCANAQUA_CDP = "50208"
MODENA_BOROUGH = "50232"
MOHNTON_BOROUGH = "50272"
MOHRSVILLE_CDP = "50280"
MONACA_BOROUGH = "50320"
MONESSEN_CITY = "50344"
MONONGAHELA_CITY = "50408"
MONROE_BOROUGH = "50432"
MONROEVILLE_MUNICIPALITY = "50528"
MONT_ALTO_BOROUGH = "50544"
MONT_CLARE_CDP = "50560"
MONTANDON_CDP = "50552"
MONTGOMERY_BOROUGH = "50632"
MONTGOMERYVILLE_CDP = "50672"
MONTOURSVILLE_BOROUGH = "50720"
MONTROSE_MANOR_CDP = "50748"
MONTROSE_BOROUGH = "50736"
MONUMENT_CDP = "50760"
MOORES_MILL_CDP = "50860"
MOOSE_RUN_CDP = "50879"
MOOSIC_BOROUGH = "50880"
MOREA_CDP = "50924"
MORGAN_HILL_CDP = "51008"
MORGANTOWN_CDP = "51016"
MORRISDALE_CDP = "51120"
MORRISVILLE_CDP = "51152"
MORRISVILLE_BOROUGH = "51144"
MORTON_BOROUGH = "51176"
MOSCOW_BOROUGH = "51208"
MOSHANNON_CDP = "51240"
MOUNT_AETNA_CDP = "51320"
MOUNT_CARBON_BOROUGH = "51488"
MOUNT_CARMEL_BOROUGH = "51496"
MOUNT_COBB_CDP = "51536"
MOUNT_EAGLE_CDP = "51552"
MOUNT_GRETNA_HEIGHTS_CDP = "51576"
MOUNT_GRETNA_BOROUGH = "51568"
MOUNT_HOLLY_SPRINGS_BOROUGH = "51592"
MOUNT_JEWETT_BOROUGH = "51632"
MOUNT_JOY_BOROUGH = "51656"
MOUNT_MORRIS_CDP = "51720"
MOUNT_OLIVER_BOROUGH = "51744"
MOUNT_PENN_BOROUGH = "51760"
MOUNT_PLEASANT_MILLS_CDP = "51904"
MOUNT_PLEASANT_BOROUGH = "51880"
MOUNT_POCONO_BOROUGH = "51912"
MOUNT_UNION_BOROUGH = "51984"
MOUNT_WOLF_BOROUGH = "52056"
MOUNTAIN_TOP_CDP = "51384"
MOUNTAINHOME_CDP = "51344"
MOUNTVILLE_BOROUGH = "52016"
MUHLENBERG_PARK_CDP = "52216"
MUIR_CDP = "52224"
MUNCY_BOROUGH = "52264"
MUNDYS_CORNER_CDP = "52312"
MUNHALL_BOROUGH = "52320"
MURRYSVILLE_MUNICIPALITY = "52432"
MUSE_CDP = "52440"
MYERSTOWN_BOROUGH = "52488"
NANTICOKE_CITY = "52584"
NANTY_GLO_BOROUGH = "52616"
NAOMI_CDP = "52632"
NARBERTH_BOROUGH = "52664"
NAZARETH_BOROUGH = "52808"
NEALMONT_CDP = "52816"
NEEDMORE_CDP = "52872"
NEMACOLIN_CDP = "52968"
NESCOPECK_BOROUGH = "52984"
NESQUEHONING_BOROUGH = "53088"
NEW_ALBANY_BOROUGH = "53152"
NEW_ALEXANDRIA_BOROUGH = "53160"
NEW_BALTIMORE_BOROUGH = "53168"
NEW_BEAVER_BOROUGH = "53184"
NEW_BEDFORD_CDP = "53192"
NEW_BERLIN_BOROUGH = "53200"
NEW_BERLINVILLE_CDP = "53208"
NEW_BETHLEHEM_BOROUGH = "53248"
NEW_BOSTON_CDP = "53272"
NEW_BRIGHTON_BOROUGH = "53288"
NEW_BRITAIN_BOROUGH = "53296"
NEW_BUFFALO_BOROUGH = "53320"
NEW_CASTLE_NORTHWEST_CDP = "53392"
NEW_CASTLE_CITY = "53368"
NEW_CENTERVILLE_BOROUGH = "53416"
NEW_COLUMBIA_CDP = "53432"
NEW_COLUMBUS_BOROUGH = "53448"
NEW_CUMBERLAND_BOROUGH = "53464"
NEW_EAGLE_BOROUGH = "53496"
NEW_FLORENCE_BOROUGH = "53544"
NEW_FREEDOM_BOROUGH = "53568"
NEW_FREEPORT_CDP = "53576"
NEW_GALILEE_BOROUGH = "53592"
NEW_HOLLAND_BOROUGH = "53696"
NEW_HOPE_BOROUGH = "53712"
NEW_JERUSALEM_CDP = "53728"
NEW_KENSINGTON_CITY = "53736"
NEW_KINGSTOWN_CDP = "53752"
NEW_LEBANON_BOROUGH = "53768"
NEW_MARKET_CDP = "53872"
NEW_MILFORD_BOROUGH = "53880"
NEW_MORGAN_BOROUGH = "53916"
NEW_OXFORD_BOROUGH = "53920"
NEW_PARIS_BOROUGH = "53928"
NEW_PHILADELPHIA_BOROUGH = "53944"
NEW_RINGGOLD_BOROUGH = "54016"
NEW_SALEM_CDP = "54040"
NEW_SALEM_BOROUGH = "54056"
NEW_SCHAEFFERSTOWN_CDP = "54064"
NEW_STANTON_BOROUGH = "54104"
NEW_TRIPOLI_CDP = "54288"
NEW_WASHINGTON_BOROUGH = "54344"
NEW_WILMINGTON_BOROUGH = "54352"
NEWBURG_CDP = "53328"
NEWBURG_BOROUGH_CLEARFIELD_COUNTY = "53336"
NEWBURG_BOROUGH_CUMBERLAND_COUNTY = "53344"
NEWELL_BOROUGH = "53504"
NEWMANSTOWN_CDP = "53856"
NEWPORT_BOROUGH = "53968"
NEWRY_BOROUGH = "54024"
NEWTON_HAMILTON_BOROUGH = "54160"
NEWTOWN_CDP = "54264"
NEWTOWN_GRANT_CDP = "54268"
NEWTOWN_BOROUGH = "54184"
NEWVILLE_BOROUGH = "54320"
NICHOLSON_BOROUGH = "54400"
NITTANY_CDP = "54520"
NIXON_CDP = "54552"
NOBLESTOWN_CDP = "54568"
NORRISTOWN_BOROUGH = "54656"
NORTH_APOLLO_BOROUGH = "54728"
NORTH_BELLE_VERNON_BOROUGH = "54776"
NORTH_BEND_CDP = "54784"
NORTH_BRADDOCK_BOROUGH = "54816"
NORTH_CATASAUQUA_BOROUGH = "54872"
NORTH_CHARLEROI_BOROUGH = "54888"
NORTH_EAST_BOROUGH = "54952"
NORTH_IRWIN_BOROUGH = "55136"
NORTH_PHILIPSBURG_CDP = "55304"
NORTH_VANDERGRIFT_CDP = "55480"
NORTH_WALES_BOROUGH = "55512"
NORTH_WARREN_CDP = "55520"
NORTH_YORK_BOROUGH = "55608"
NORTHAMPTON_BOROUGH = "54696"
NORTHERN_CAMBRIA_BOROUGH = "55000"
NORTHUMBERLAND_BOROUGH = "55456"
NORTHWEST_HARBORCREEK_CDP = "55572"
NORTHWOOD_CDP = "55584"
NORVELT_CDP = "55616"
NORWOOD_BOROUGH = "55664"
NOTTINGHAM_CDP = "55704"
NOXEN_CDP = "55728"
NUANGOLA_BOROUGH = "55752"
NUMIDIA_CDP = "55792"
NUREMBERG_CDP = "55808"
OAK_HILLS_CDP = "55969"
OAKDALE_BOROUGH = "55840"
OAKLAND_CDP_CAMBRIA_COUNTY = "55996"
OAKLAND_CDP_LAWRENCE_COUNTY = "56000"
OAKLAND_BOROUGH = "56008"
OAKMONT_BOROUGH = "56088"
OAKWOOD_CDP = "56232"
OBERLIN_CDP = "56264"
OHIOPYLE_BOROUGH = "56408"
OHIOVILLE_BOROUGH = "56432"
OIL_CITY_CITY = "56456"
OKLAHOMA_CDP = "56488"
OKLAHOMA_BOROUGH = "56496"
OLD_FORGE_BOROUGH = "56576"
OLD_ORCHARD_CDP = "56624"
OLEY_CDP = "56664"
OLIVER_CDP = "56704"
OLIVIA_CDP = "56761"
OLYPHANT_BOROUGH = "56792"
ONEIDA_CDP = "56816"
ORANGEVILLE_BOROUGH = "56912"
ORBISONIA_BOROUGH = "56928"
ORCHARD_HILLS_CDP = "56960"
ORE_HILL_CDP = "57016"
ORELAND_CDP = "57024"
OREMINEA_CDP = "57040"
ORRSTOWN_BOROUGH = "57112"
ORRTANNA_CDP = "57120"
ORVISTON_CDP = "57160"
ORWIGSBURG_BOROUGH = "57184"
ORWIN_CDP = "57192"
OSCEOLA_MILLS_BOROUGH = "57232"
OSWAYO_BOROUGH = "57280"
OVAL_CDP = "57376"
OXFORD_BOROUGH = "57480"
PAINT_BOROUGH = "57544"
PALMDALE_CDP = "57648"
PALMER_HEIGHTS_CDP = "57680"
PALMERTON_BOROUGH = "57696"
PALMYRA_BOROUGH = "57720"
PALO_ALTO_BOROUGH = "57752"
PAOLI_CDP = "57816"
PARADISE_CDP = "57840"
PARDEESVILLE_CDP = "57904"
PARIS_CDP = "57928"
PARK_CREST_CDP = "57968"
PARK_FOREST_VILLAGE_CDP = "58036"
PARKER_CITY = "57976"
PARKESBURG_BOROUGH = "58032"
PARKSIDE_BOROUGH = "58176"
PARKVILLE_CDP = "58240"
PARRYVILLE_BOROUGH = "58304"
PATTERSON_HEIGHTS_BOROUGH = "58384"
PATTON_BOROUGH = "58432"
PAXTANG_BOROUGH = "58504"
PAXTONIA_CDP = "58528"
PAXTONVILLE_CDP = "58536"
PEN_ARGYL_BOROUGH = "58696"
PEN_MAR_CDP = "58776"
PENBROOK_BOROUGH = "58712"
PENN_ESTATES_CDP = "58948"
PENN_FARMS_CDP = "58950"
PENN_LAKE_PARK_BOROUGH = "59054"
PENN_STATE_BERKS_CDP = "59207"
PENN_STATE_ERIE_BEHREND_CDP = "59212"
PENN_WYNNE_CDP = "59312"
PENN_BOROUGH = "58872"
PENNDEL_BOROUGH = "58936"
PENNS_CREEK_CDP = "59160"
PENNSBURG_BOROUGH = "59120"
PENNSBURY_VILLAGE_BOROUGH = "59152"
PENNSIDE_CDP = "59176"
PENNVILLE_CDP = "59296"
PENNWYN_CDP = "59304"
PENRYN_CDP = "59344"
PERKASIE_BOROUGH = "59384"
PERRYOPOLIS_BOROUGH = "59520"
PERU_CDP = "59580"
PETERSBURG_BOROUGH = "59616"
PETROLIA_BOROUGH = "59672"
PHILADELPHIA_CITY = "60000"
PHILIPSBURG_BOROUGH = "60008"
PHOENIXVILLE_BOROUGH = "60120"
PICTURE_ROCKS_BOROUGH = "60136"
PIKES_CREEK_CDP = "60224"
PILLOW_BOROUGH = "60264"
PINE_GLEN_CDP = "60432"
PINE_GROVE_MILLS_CDP = "60496"
PINE_GROVE_BOROUGH = "60456"
PINE_RIDGE_CDP = "60547"
PINECROFT_CDP = "60384"
PITCAIRN_BOROUGH = "60712"
PITTSBURGH_CITY = "61000"
PITTSTON_CITY = "61048"
PLAINFIELD_CDP = "61080"
PLAINS_CDP = "61112"
PLATEA_BOROUGH = "61168"
PLEASANT_GAP_CDP = "61232"
PLEASANT_HILL_CDP = "61312"
PLEASANT_HILLS_BOROUGH = "61328"
PLEASANT_VIEW_CDP = "61432"
PLEASANTVILLE_BOROUGH_BEDFORD_COUNTY = "61496"
PLEASANTVILLE_BOROUGH_VENANGO_COUNTY = "61512"
PLEASUREVILLE_CDP = "61520"
PLUM_BOROUGH = "61536"
PLUMSTEADVILLE_CDP = "61624"
PLUMVILLE_BOROUGH = "61632"
PLYMOUTH_MEETING_CDP = "61688"
PLYMOUTH_BOROUGH = "61648"
PLYMPTONVILLE_CDP = "61704"
POCONO_MOUNTAIN_LAKE_ESTATES_CDP = "61756"
POCONO_PINES_CDP = "61768"
POCONO_RANCH_LANDS_CDP = "61773"
POCONO_SPRINGS_CDP = "61774"
POCONO_WOODLAND_LAKES_CDP = "61788"
POINT_MARION_BOROUGH = "61864"
POINT_VIEW_CDP = "61888"
POLK_BOROUGH = "61936"
POMEROY_CDP = "61968"
PORT_ALLEGANY_BOROUGH = "62088"
PORT_CARBON_BOROUGH = "62128"
PORT_CLINTON_BOROUGH = "62136"
PORT_MATILDA_BOROUGH = "62280"
PORT_ROYAL_BOROUGH = "62304"
PORT_TREVORTON_CDP = "62312"
PORT_VUE_BOROUGH = "62320"
PORTAGE_BOROUGH = "62048"
PORTERSVILLE_BOROUGH = "62224"
PORTLAND_BOROUGH = "62264"
POTLICKER_FLATS_CDP = "62340"
POTTERS_MILLS_CDP = "62384"
POTTSGROVE_CDP = "62396"
POTTSTOWN_BOROUGH = "62416"
POTTSVILLE_CITY = "62432"
PRINGLE_BOROUGH = "62712"
PROGRESS_CDP = "62736"
PROMPTON_BOROUGH = "62744"
PROSPECT_PARK_CDP = "62784"
PROSPECT_PARK_BOROUGH = "62792"
PROSPECT_BOROUGH = "62752"
PUGHTOWN_CDP = "62872"
PUNXSUTAWNEY_BOROUGH = "62920"
PUZZLETOWN_CDP = "62984"
PYMATUNING_CENTRAL_CDP = "63009"
PYMATUNING_NORTH_CDP = "63011"
PYMATUNING_SOUTH_CDP = "63013"
QUAKERTOWN_BOROUGH = "63048"
QUARRYVILLE_BOROUGH = "63064"
QUEENS_GATE_CDP = "63116"
QUENTIN_CDP = "63160"
RAILROAD_BOROUGH = "63288"
RAINSBURG_BOROUGH = "63312"
RAMBLEWOOD_CDP = "63349"
RAMEY_BOROUGH = "63360"
RANKIN_BOROUGH = "63408"
RANSHAW_CDP = "63416"
RAUBSVILLE_CDP = "63488"
RAUCHTOWN_CDP = "63496"
RAVINE_CDP = "63536"
READING_CITY = "63624"
REAMSTOWN_CDP = "63664"
REBERSBURG_CDP = "63688"
RED_HILL_CDP = "63800"
RED_HILL_BOROUGH = "63808"
RED_LION_BOROUGH = "63840"
REEDSVILLE_CDP = "63976"
REESE_CDP = "64000"
REFTON_CDP = "64032"
REHRERSBURG_CDP = "64056"
REIFFTON_CDP = "64072"
REIGHTOWN_CDP = "64080"
REINERTON_CDP = "64104"
REINHOLDS_CDP = "64112"
RENNERDALE_CDP = "64184"
RENNINGERS_CDP = "64188"
RENOVO_BOROUGH = "64200"
REPUBLIC_CDP = "64224"
RESERVOIR_CDP = "64256"
REVLOC_CDP = "64288"
REW_CDP = "64296"
REYNOLDS_HEIGHTS_CDP = "64368"
REYNOLDSVILLE_BOROUGH = "64376"
RHEEMS_CDP = "64392"
RICES_LANDING_BOROUGH = "64432"
RICEVILLE_CDP = "64440"
RICHBORO_CDP = "64464"
RICHFIELD_CDP = "64488"
RICHLAND_BOROUGH = "64560"
RICHLANDTOWN_BOROUGH = "64584"
RIDGWAY_BOROUGH = "64784"
RIDLEY_PARK_BOROUGH = "64832"
RIEGELSVILLE_BOROUGH = "64856"
RIMERSBURG_BOROUGH = "64904"
RINGTOWN_BOROUGH = "65000"
RIVERSIDE_CDP = "65088"
RIVERSIDE_BOROUGH = "65112"
RIVERVIEW_PARK_CDP = "65192"
ROARING_SPRING_BOROUGH = "65256"
ROBESON_EXTENSION_CDP = "65328"
ROBESONIA_BOROUGH = "65336"
ROBINSON_CDP = "65360"
ROCHESTER_BOROUGH = "65392"
ROCKHILL_BOROUGH = "65496"
ROCKLEDGE_BOROUGH = "65568"
ROCKWOOD_BOROUGH = "65736"
ROGERSVILLE_CDP = "65848"
ROHRSBURG_CDP = "65872"
ROME_BOROUGH = "65944"
RONCO_CDP = "65976"
RONKS_CDP = "65984"
ROOTS_CDP = "66004"
ROSCOE_BOROUGH = "66016"
ROSE_VALLEY_BOROUGH = "66192"
ROSEMONT_CDP = "66144"
ROSETO_BOROUGH = "66168"
ROSEVILLE_BOROUGH = "66232"
ROSLYN_CDP = "66256"
ROSSITER_CDP = "66304"
ROSSLYN_FARMS_BOROUGH = "66320"
ROTE_CDP = "66384"
ROTHSVILLE_CDP = "66392"
ROULETTE_CDP = "66408"
ROUSEVILLE_BOROUGH = "66440"
ROUZERVILLE_CDP = "66448"
ROWES_RUN_CDP = "66472"
ROYALTON_BOROUGH = "66560"
ROYER_CDP = "66568"
ROYERSFORD_BOROUGH = "66576"
RUNVILLE_CDP = "66688"
RUPERT_CDP = "66696"
RURAL_VALLEY_BOROUGH = "66720"
RUSSELL_CDP = "66808"
RUSSELLTON_CDP = "66832"
RUTHERFORD_CDP = "66864"
RUTLEDGE_BOROUGH = "66928"
SNPJ_BOROUGH = "71620"
SADSBURYVILLE_CDP = "67104"
SAEGERTOWN_BOROUGH = "67120"
SALISBURY_BOROUGH = "67584"
SALIX_CDP = "67608"
SALLADASBURG_BOROUGH = "67616"
SALONA_CDP = "67624"
SALTILLO_BOROUGH = "67632"
SALTSBURG_BOROUGH = "67648"
SALUNGA_CDP = "67656"
SANATOGA_CDP = "67712"
SAND_HILL_CDP = "67744"
SANDY_CDP = "67784"
SANDY_LAKE_BOROUGH = "67848"
SANDY_RIDGE_CDP = "67872"
SANKERTOWN_BOROUGH = "67920"
SAW_CREEK_CDP = "68036"
SAXONBURG_BOROUGH = "68056"
SAXTON_BOROUGH = "68072"
SAYLORSBURG_CDP = "68088"
SAYRE_BOROUGH = "68096"
SCALP_LEVEL_BOROUGH = "68104"
SCHAEFFERSTOWN_CDP = "68144"
SCHELLSBURG_BOROUGH = "68152"
SCHLUSSER_CDP = "68188"
SCHNECKSVILLE_CDP = "68192"
SCHOENECK_CDP = "68200"
SCHUBERT_CDP = "68248"
SCHUYLKILL_HAVEN_BOROUGH = "68312"
SCHWENKSVILLE_BOROUGH = "68328"
SCOTLAND_CDP = "68376"
SCOTTDALE_BOROUGH = "68432"
SCRANTON_CITY = "69000"
SELINSGROVE_BOROUGH = "69216"
SELLERSVILLE_BOROUGH = "69248"
SELTZER_CDP = "69256"
SENECA_CDP = "69272"
SEVEN_FIELDS_BOROUGH = "69309"
SEVEN_SPRINGS_BOROUGH = "69336"
SEVEN_VALLEYS_BOROUGH = "69360"
SEWARD_BOROUGH = "69368"
SEWICKLEY_HEIGHTS_BOROUGH = "69400"
SEWICKLEY_HILLS_BOROUGH = "69416"
SEWICKLEY_BOROUGH = "69376"
SHADE_GAP_BOROUGH = "69456"
SHAMOKIN_DAM_BOROUGH = "69616"
SHAMOKIN_CITY = "69600"
SHANKSVILLE_BOROUGH = "69680"
SHANOR_NORTHVUE_CDP = "69715"
SHARON_HILL_BOROUGH = "69752"
SHARON_CITY = "69720"
SHARPSBURG_BOROUGH = "69776"
SHARPSVILLE_BOROUGH = "69800"
SHARTLESVILLE_CDP = "69816"
SHAVERTOWN_CDP = "69832"
SHEAKLEYVILLE_BOROUGH = "69936"
SHEATOWN_CDP = "69952"
SHEFFIELD_CDP = "69984"
SHELLTOWN_CDP = "70020"
SHELLYTOWN_CDP = "70032"
SHELOCTA_BOROUGH = "70040"
SHENANDOAH_HEIGHTS_CDP = "70064"
SHENANDOAH_BOROUGH = "70056"
SHEPPTON_CDP = "70128"
SHICKSHINNY_BOROUGH = "70224"
SHILLINGTON_BOROUGH = "70248"
SHILOH_CDP = "70256"
SHINGLEHOUSE_BOROUGH = "70304"
SHIPPENSBURG_UNIVERSITY_CDP = "70362"
SHIPPENSBURG_BOROUGH = "70352"
SHIPPENVILLE_BOROUGH = "70368"
SHIPPINGPORT_BOROUGH = "70376"
SHIREMANSTOWN_BOROUGH = "70384"
SHIRLEYSBURG_BOROUGH = "70408"
SHOEMAKERSVILLE_BOROUGH = "70464"
SHREWSBURY_BOROUGH = "70568"
SICKLES_CORNER_CDP = "70608"
SIDMAN_CDP = "70640"
SIERRA_VIEW_CDP = "70652"
SIGLERVILLE_CDP = "70664"
SILKWORTH_CDP = "70704"
SILVERDALE_BOROUGH = "70744"
SIMPSON_CDP = "70840"
SINKING_SPRING_BOROUGH = "70880"
SKELP_CDP = "70984"
SKI_GAP_CDP = "70996"
SKIPPACK_CDP = "71008"
SKYLINE_VIEW_CDP = "71032"
SLABTOWN_CDP = "71056"
SLATEDALE_CDP = "71080"
SLATINGTON_BOROUGH = "71144"
SLICKVILLE_CDP = "71160"
SLIGO_BOROUGH = "71176"
SLIPPERY_ROCK_UNIVERSITY_CDP = "71210"
SLIPPERY_ROCK_BOROUGH = "71184"
SLOVAN_CDP = "71232"
SMETHPORT_BOROUGH = "71248"
SMICKSBURG_BOROUGH = "71256"
SMITH_CORNER_CDP = "71298"
SMITHFIELD_BOROUGH = "71320"
SMITHTON_BOROUGH = "71424"
SMOCK_CDP = "71456"
SMOKETOWN_CDP = "71504"
SNOW_SHOE_BOROUGH = "71600"
SNYDERTOWN_CDP = "71672"
SNYDERTOWN_BOROUGH = "71688"
SOMERSET_BOROUGH = "71776"
SOUDERSBURG_CDP = "71848"
SOUDERTON_BOROUGH = "71856"
SOUTH_BETHLEHEM_BOROUGH = "71976"
SOUTH_COATESVILLE_BOROUGH = "72072"
SOUTH_CONNELLSVILLE_BOROUGH = "72080"
SOUTH_FORK_BOROUGH = "72168"
SOUTH_GREENSBURG_BOROUGH = "72192"
SOUTH_HEIGHTS_BOROUGH = "72216"
SOUTH_NEW_CASTLE_BOROUGH = "72376"
SOUTH_PHILIPSBURG_CDP = "72416"
SOUTH_POTTSTOWN_CDP = "72432"
SOUTH_RENOVO_BOROUGH = "72448"
SOUTH_TEMPLE_CDP = "72520"
SOUTH_UNIONTOWN_CDP = "72552"
SOUTH_WAVERLY_BOROUGH = "72592"
SOUTH_WILLIAMSPORT_BOROUGH = "72648"
SOUTHMONT_BOROUGH = "72344"
SOUTHVIEW_CDP = "72576"
SOUTHWEST_GREENSBURG_BOROUGH = "72616"
SPARTANSBURG_BOROUGH = "72704"
SPEERS_BOROUGH = "72736"
SPINNERSTOWN_CDP = "72768"
SPRING_CITY_BOROUGH = "72920"
SPRING_DRIVE_MOBILE_HOME_PARK_CDP = "72988"
SPRING_GROVE_BOROUGH = "73192"
SPRING_HILL_CDP = "73224"
SPRING_HOUSE_CDP = "73264"
SPRING_MILLS_CDP = "73288"
SPRING_MOUNT_CDP = "73312"
SPRING_RIDGE_CDP = "73318"
SPRINGBORO_BOROUGH = "72872"
SPRINGDALE_BOROUGH = "72960"
SPRINGMONT_CDP = "73296"
SPROUL_CDP = "73456"
SPRY_CDP = "73528"
ST_CLAIR_CDP = "67220"
ST_CLAIR_BOROUGH = "67224"
ST_CLAIRSVILLE_BOROUGH = "67256"
ST_DAVIDS_CDP = "67264"
ST_LAWRENCE_BOROUGH = "67304"
ST_MARYS_CITY = "67344"
ST_MICHAEL_CDP = "67352"
ST_PETERSBURG_BOROUGH = "67384"
ST_VINCENT_COLLEGE_CDP = "67416"
STAR_JUNCTION_CDP = "73720"
STARBRICK_CDP = "73704"
STARRUCCA_BOROUGH = "73784"
STATE_COLLEGE_BOROUGH = "73808"
STATE_LINE_CDP = "73848"
STEELTON_BOROUGH = "73888"
STEVENS_CDP = "74040"
STEWARTSTOWN_BOROUGH = "74104"
STILES_CDP = "74160"
STILLWATER_BOROUGH = "74184"
STOCKDALE_BOROUGH = "74224"
STOCKERTOWN_BOROUGH = "74232"
STONEBORO_BOROUGH = "74288"
STONERSTOWN_CDP = "74360"
STONY_CREEK_MILLS_CDP = "74448"
STONYBROOK_CDP = "74416"
STORMSTOWN_CDP = "74544"
STOUCHSBURG_CDP = "74568"
STOWE_CDP = "74660"
STOYSTOWN_BOROUGH = "74672"
STRASBURG_BOROUGH = "74712"
STRATTANVILLE_BOROUGH = "74728"
STRAUSSTOWN_CDP = "74744"
STRODES_MILLS_CDP = "74848"
STRONG_CDP = "74864"
STROUDSBURG_BOROUGH = "74888"
STURGEON_CDP = "74944"
SUGAR_GROVE_BOROUGH = "75024"
SUGAR_NOTCH_BOROUGH = "75072"
SUGARCREEK_BOROUGH = "75000"
SUMMERHILL_BOROUGH = "75136"
SUMMERVILLE_BOROUGH = "75168"
SUMMIT_HILL_BOROUGH = "75248"
SUMMIT_STATION_CDP = "75272"
SUN_VALLEY_CDP = "75432"
SUNBROOK_CDP = "75296"
SUNBURY_CITY = "75304"
SUNRISE_LAKE_CDP = "75381"
SUSQUEHANNA_DEPOT_BOROUGH = "75568"
SUSQUEHANNA_TRAILS_CDP = "75574"
SUTERSVILLE_BOROUGH = "75584"
SWARTHMORE_BOROUGH = "75648"
SWARTZVILLE_CDP = "75664"
SWEDELAND_CDP = "75712"
SWEDEN_VALLEY_CDP = "75728"
SWISSVALE_BOROUGH = "75816"
SWOYERSVILLE_BOROUGH = "75832"
SYKESVILLE_BOROUGH = "75888"
SYLVAN_HILLS_CDP = "75936"
SYLVANIA_BOROUGH = "75944"
TABLE_ROCK_CDP = "75968"
TAMAQUA_BOROUGH = "76032"
TARENTUM_BOROUGH = "76104"
TATAMY_BOROUGH = "76144"
TAYLOR_BOROUGH = "76184"
TAYLORSTOWN_CDP = "76232"
TELFORD_BOROUGH = "76304"
TEMPLE_CDP = "76320"
TEMPLETON_CDP = "76336"
TERRE_HILL_BOROUGH = "76400"
THARPTOWN_UNIONTOWN_CDP = "76432"
THE_HIDEOUT_CDP = "76440"
THOMPSON_BOROUGH = "76496"
THOMPSONTOWN_BOROUGH = "76536"
THOMPSONVILLE_CDP = "76552"
THORNBURG_BOROUGH = "76560"
THORNDALE_CDP = "76584"
THREE_SPRINGS_BOROUGH = "76632"
THROOP_BOROUGH = "76648"
TIDIOUTE_BOROUGH = "76696"
TIMBER_HILLS_CDP = "76724"
TIMBLIN_BOROUGH = "76744"
TIOGA_BOROUGH = "76808"
TIONESTA_BOROUGH = "76848"
TIPTON_CDP = "76880"
TITUSVILLE_CITY = "76904"
TOFTREES_CDP = "77016"
TOPTON_BOROUGH = "77104"
TOUGHKENAMON_CDP = "77144"
TOWAMENSING_TRAILS_CDP = "77163"
TOWANDA_BOROUGH = "77168"
TOWER_CITY_BOROUGH = "77184"
TOWNVILLE_BOROUGH = "77232"
TRAFFORD_BOROUGH = "77272"
TRAINER_BOROUGH = "77288"
TRAPPE_BOROUGH = "77304"
TREASURE_LAKE_CDP = "77335"
TREMONT_BOROUGH = "77392"
TRESCKOW_CDP = "77424"
TREVORTON_CDP = "77448"
TREVOSE_CDP = "77456"
TREXLERTOWN_CDP = "77488"
TROOPER_CDP = "77520"
TROUTVILLE_BOROUGH = "77568"
TROXELVILLE_CDP = "77576"
TROY_BOROUGH = "77584"
TRUCKSVILLE_CDP = "77656"
TRUMBAUERSVILLE_BOROUGH = "77704"
TULLYTOWN_BOROUGH = "77744"
TUNKHANNOCK_BOROUGH = "77784"
TUNNELHILL_BOROUGH = "77808"
TURBOTVILLE_BOROUGH = "77832"
TURTLE_CREEK_BOROUGH = "77912"
TUSCARORA_CDP = "77968"
TWILIGHT_BOROUGH = "78008"
TYLER_RUN_CDP = "78115"
TYLERSBURG_CDP = "78120"
TYLERSVILLE_CDP = "78144"
TYRONE_FORGE_CDP = "78186"
TYRONE_BOROUGH = "78168"
ULYSSES_BOROUGH = "78240"
UNION_CITY_BOROUGH = "78448"
UNION_DALE_BOROUGH = "78456"
UNION_DEPOSIT_CDP = "78472"
UNIONTOWN_CITY = "78528"
UNIONVILLE_CDP_BUTLER_COUNTY = "78608"
UNIONVILLE_CDP_CHESTER_COUNTY = "78624"
UNIONVILLE_BOROUGH = "78616"
UNIVERSITY_OF_PITTSBURGH_BRADFORD_CDP = "78698"
UNIVERSITY_OF_PITTSBURGH_JOHNSTOWN_CDP = "78700"
UPLAND_BOROUGH = "78712"
UPPER_EXETER_CDP = "79016"
URSINA_BOROUGH = "79424"
UTICA_BOROUGH = "79472"
VAIL_CDP = "79496"
VALENCIA_BOROUGH = "79504"
VALLEY_GREEN_CDP = "79640"
VALLEY_VIEW_CDP_SCHUYLKILL_COUNTY = "79680"
VALLEY_VIEW_CDP_YORK_COUNTY = "79682"
VALLEY_HI_BOROUGH = "79644"
VAN_VOORHIS_CDP = "79872"
VANDERBILT_BOROUGH = "79768"
VANDERGRIFT_BOROUGH = "79776"
VANDLING_BOROUGH = "79792"
VENANGO_BOROUGH = "79912"
VERONA_BOROUGH = "80032"
VERSAILLES_BOROUGH = "80040"
VICKSBURG_CDP_BLAIR_COUNTY = "80136"
VICKSBURG_CDP_UNION_COUNTY = "80144"
VILLAGE_GREEN_GREEN_RIDGE_CDP = "80218"
VILLAGE_SHIRES_CDP = "80229"
VILLANOVA_CDP = "80248"
VINCO_CDP = "80264"
VINTONDALE_BOROUGH = "80288"
VIRGINVILLE_CDP = "80336"
VOLANT_BOROUGH = "80368"
VOWINCKEL_CDP = "80384"
WAGNER_CDP = "80432"
WAKEFIELD_CDP = "80480"
WALL_BOROUGH = "80600"
WALLACETON_BOROUGH = "80640"
WALLENPAUPACK_LAKE_ESTATES_CDP = "80652"
WALLER_CDP = "80656"
WALNUTPORT_BOROUGH = "80800"
WALNUTTOWN_CDP = "80808"
WAMPUM_BOROUGH = "80880"
WANAMIE_CDP = "80896"
WARMINSTER_HEIGHTS_CDP = "80962"
WARREN_CITY = "81000"
WARRIOR_RUN_BOROUGH = "81080"
WASHINGTON_BORO_CDP = "81360"
WASHINGTON_CITY = "81328"
WASHINGTONVILLE_BOROUGH = "81424"
WATERFORD_BOROUGH = "81456"
WATSONTOWN_BOROUGH = "81616"
WATTSBURG_BOROUGH = "81648"
WAVERLY_CDP = "81664"
WAYMART_BOROUGH = "81712"
WAYNE_CDP = "81752"
WAYNE_HEIGHTS_CDP = "81808"
WAYNESBORO_BOROUGH = "81824"
WAYNESBURG_BOROUGH = "81832"
WEATHERLY_BOROUGH = "81856"
WEBSTER_CDP = "81936"
WEEDVILLE_CDP = "81960"
WEIGELSTOWN_CDP = "82008"
WEISSPORT_EAST_CDP = "82088"
WEISSPORT_BOROUGH = "82080"
WELLERSBURG_BOROUGH = "82128"
WELLSBORO_BOROUGH = "82160"
WELLSVILLE_BOROUGH = "82200"
WERNERSVILLE_BOROUGH = "82296"
WESCOSVILLE_CDP = "82320"
WESLEYVILLE_BOROUGH = "82344"
WEST_ALEXANDER_CDP = "82376"
WEST_BROWNSVILLE_BOROUGH = "82616"
WEST_CHESTER_BOROUGH = "82704"
WEST_CONSHOHOCKEN_BOROUGH = "82736"
WEST_DECATUR_CDP = "82792"
WEST_EASTON_BOROUGH = "82832"
WEST_ELIZABETH_BOROUGH = "82848"
WEST_FAIRVIEW_CDP = "82920"
WEST_FALLS_CDP = "82952"
WEST_GROVE_BOROUGH = "83104"
WEST_HAMBURG_CDP = "83120"
WEST_HAZLETON_BOROUGH = "83136"
WEST_HILLS_CDP = "83172"
WEST_HOMESTEAD_BOROUGH = "83200"
WEST_KITTANNING_BOROUGH = "83248"
WEST_LAWN_CDP = "83280"
WEST_LEECHBURG_BOROUGH = "83328"
WEST_LIBERTY_BOROUGH = "83376"
WEST_MAYFIELD_BOROUGH = "83472"
WEST_MIDDLESEX_BOROUGH = "83496"
WEST_MIDDLETOWN_BOROUGH = "83504"
WEST_MIFFLIN_BOROUGH = "83512"
WEST_MILTON_CDP = "83520"
WEST_NANTICOKE_CDP = "83656"
WEST_NEWTON_BOROUGH = "83680"
WEST_PITTSBURG_CDP = "83848"
WEST_PITTSTON_BOROUGH = "83856"
WEST_READING_BOROUGH = "83928"
WEST_SUNBURY_BOROUGH = "84064"
WEST_VIEW_BOROUGH = "84144"
WEST_WAYNESBURG_CDP = "84176"
WEST_WYOMING_BOROUGH = "84272"
WEST_WYOMISSING_CDP = "84280"
WEST_YORK_BOROUGH = "84288"
WESTFIELD_BOROUGH = "82968"
WESTLAND_CDP = "83272"
WESTMONT_BOROUGH = "83584"
WESTON_CDP = "83720"
WESTOVER_BOROUGH = "83736"
WESTWOOD_CDP_CAMBRIA_COUNTY = "84240"
WESTWOOD_CDP_CHESTER_COUNTY = "84248"
WHEATLAND_BOROUGH = "84376"
WHITAKER_BOROUGH = "84440"
WHITE_HAVEN_BOROUGH = "84552"
WHITE_MILLS_CDP = "84696"
WHITE_OAK_BOROUGH = "84704"
WHITEHALL_BOROUGH = "84512"
WHITFIELD_CDP = "84856"
WICKERHAM_MANOR_FISHER_CDP = "84931"
WICONSICO_CDP = "84968"
WILBURTON_NUMBER_ONE_CDP = "85076"
WILBURTON_NUMBER_TWO_CDP = "85078"
WILCOX_CDP = "85088"
WILKES_BARRE_CITY = "85152"
WILKINSBURG_BOROUGH = "85188"
WILLIAMSBURG_BOROUGH = "85272"
WILLIAMSPORT_CITY = "85312"
WILLIAMSTOWN_BOROUGH = "85320"
WILLOW_GROVE_CDP = "85408"
WILLOW_STREET_CDP = "85464"
WILMERDING_BOROUGH = "85496"
WILMORE_BOROUGH = "85528"
WILSON_BOROUGH = "85592"
WIND_GAP_BOROUGH = "85664"
WIND_RIDGE_CDP = "85712"
WINDBER_BOROUGH = "85632"
WINDSOR_BOROUGH = "85728"
WINFIELD_CDP = "85792"
WINTERSTOWN_BOROUGH = "85872"
WITMER_CDP = "85968"
WOLFDALE_CDP = "86000"
WOMELSDORF_BOROUGH = "86056"
WOODBOURNE_CDP = "86112"
WOODBURY_BOROUGH = "86128"
WOODCOCK_BOROUGH = "86160"
WOODLAND_HEIGHTS_CDP = "86224"
WOODLYN_CDP = "86288"
WOODSIDE_CDP = "86352"
WOODWARD_CDP = "86432"
WOOLRICH_CDP = "86472"
WOPSONONOCK_CDP = "86480"
WORMLEYSBURG_BOROUGH = "86528"
WORTHINGTON_BOROUGH = "86560"
WORTHVILLE_BOROUGH = "86568"
WOXALL_CDP = "86576"
WRIGHTSVILLE_BOROUGH = "86640"
WYALUSING_BOROUGH = "86656"
WYANO_CDP = "86672"
WYLANDVILLE_CDP = "86712"
WYNCOTE_CDP = "86744"
WYNDMOOR_CDP = "86776"
WYOMING_BOROUGH = "86856"
WYOMISSING_BOROUGH = "86880"
YARDLEY_BOROUGH = "86920"
YARNELL_CDP = "86936"
YATESVILLE_BOROUGH = "86952"
YEADON_BOROUGH = "86968"
YEAGERTOWN_CDP = "86976"
YELLOW_SPRINGS_CDP = "87006"
YOE_BOROUGH = "87040"
YORK_HAVEN_BOROUGH = "87080"
YORK_SPRINGS_BOROUGH = "87136"
YORK_CITY = "87048"
YORKANA_BOROUGH = "87064"
YORKLYN_CDP = "87088"
YOUNGSTOWN_BOROUGH = "87208"
YOUNGSVILLE_BOROUGH = "87224"
YOUNGWOOD_BOROUGH = "87232"
YUKON_CDP = "87240"
ZELIENOPLE_BOROUGH = "87272"
ZION_CDP = "87320"
