# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Delaware."""


ARDEN_VILLAGE = "01400"
ARDENCROFT_VILLAGE = "01530"
ARDENTOWN_VILLAGE = "01660"
BEAR_CDP = "04130"
BELLEFONTE_TOWN = "04650"
BETHANY_BEACH_TOWN = "05690"
BETHEL_TOWN = "05820"
BLADES_TOWN = "06730"
BOWERS_TOWN = "07250"
BRIDGEVILLE_TOWN = "08680"
BROOKSIDE_CDP = "09850"
CAMDEN_TOWN = "10760"
CHESWOLD_TOWN = "14660"
CLAYMONT_CDP = "15310"
CLAYTON_TOWN = "15440"
DAGSBORO_TOWN = "18950"
DELAWARE_CITY_CITY = "19730"
DELMAR_TOWN = "20380"
DEWEY_BEACH_TOWN = "20900"
DOVER_BASE_HOUSING_CDP = "21387"
DOVER_CITY = "21200"
EDGEMOOR_CDP = "23240"
ELLENDALE_TOWN = "24020"
ELSMERE_TOWN = "24540"
FARMINGTON_TOWN = "25840"
FELTON_TOWN = "26620"
FENWICK_ISLAND_TOWN = "26880"
FRANKFORD_TOWN = "28310"
FREDERICA_TOWN = "28440"
GEORGETOWN_TOWN = "29090"
GLASGOW_CDP = "29350"
GREENVILLE_CDP = "31430"
GREENWOOD_TOWN = "31560"
HARRINGTON_CITY = "33120"
HARTLY_TOWN = "33250"
HENLOPEN_ACRES_TOWN = "33900"
HIGHLAND_ACRES_CDP = "34810"
HOCKESSIN_CDP = "35850"
HOUSTON_TOWN = "36760"
KENT_ACRES_CDP = "38710"
KENTON_TOWN = "39100"
LAUREL_TOWN = "41310"
LEIPSIC_TOWN = "41700"
LEWES_CITY = "41830"
LINCOLN_CDP = "42480"
LITTLE_CREEK_TOWN = "42870"
LONG_NECK_CDP = "43245"
MAGNOLIA_TOWN = "44430"
MIDDLETOWN_TOWN = "47030"
MILFORD_CITY = "47420"
MILLSBORO_TOWN = "47940"
MILLVILLE_TOWN = "48200"
MILTON_TOWN = "48330"
NEW_CASTLE_CITY = "50800"
NEWARK_CITY = "50670"
NEWPORT_TOWN = "51190"
NORTH_STAR_CDP = "52490"
OCEAN_VIEW_TOWN = "53920"
ODESSA_TOWN = "54050"
PIKE_CREEK_CDP = "56490"
PIKE_CREEK_VALLEY_CDP = "56500"
PORT_PENN_CDP = "58600"
REHOBOTH_BEACH_CITY = "60290"
RISING_SUN_LEBANON_CDP = "61265"
RIVERVIEW_CDP = "61480"
RODNEY_VILLAGE_CDP = "61720"
SEAFORD_CITY = "64320"
SELBYVILLE_TOWN = "64840"
SLAUGHTER_BEACH_TOWN = "67050"
SMYRNA_TOWN = "67310"
SOUTH_BETHANY_TOWN = "67700"
ST_GEORGES_CDP = "63800"
TOWNSEND_TOWN = "72510"
VIOLA_TOWN = "74330"
WILMINGTON_MANOR_CDP = "77840"
WILMINGTON_CITY = "77580"
WOODSIDE_EAST_CDP = "80895"
WOODSIDE_TOWN = "80830"
WYOMING_TOWN = "81350"
