# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Montana."""


ABSAROKEE_CDP = "00175"
ACTON_CDP = "00400"
ALBERTON_TOWN = "00700"
ALDER_CDP = "00850"
ALZADA_CDP = "01300"
AMSTERDAM_CDP = "01525"
ANACONDA_DEER_LODGE_COUNTY = "01675"
ANTELOPE_CDP = "02050"
ARGENTA_CDP = "02350"
ARLEE_CDP = "02425"
ASHLAND_CDP = "02800"
AUGUSTA_CDP = "03025"
AVON_CDP = "03175"
AYERS_RANCH_COLONY_CDP = "03196"
AZURE_CDP = "03212"
BABB_CDP = "03250"
BAINVILLE_TOWN = "03400"
BAKER_CITY = "03475"
BALLANTINE_CDP = "03625"
BASIN_CDP = "04150"
BATAVIA_CDP = "04230"
BEAR_DANCE_CDP = "04410"
BEARCREEK_TOWN = "04300"
BEAVER_CREEK_CDP = "04575"
BELFRY_CDP = "04900"
BELGRADE_CITY = "04975"
BELKNAP_CDP = "05050"
BELT_TOWN = "05275"
BIDDLE_CDP = "05650"
BIG_ARM_CDP = "05800"
BIG_SANDY_TOWN = "06250"
BIG_SKY_CDP = "06325"
BIG_SKY_COLONY_CDP = "06410"
BIG_STONE_COLONY_CDP = "06440"
BIG_TIMBER_CITY = "06475"
BIGFORK_CDP = "05875"
BILLINGS_CITY = "06550"
BIRCH_CREEK_COLONY_CDP = "06815"
BIRNEY_CDP = "06925"
BLACK_EAGLE_CDP = "07150"
BLACKFOOT_CDP = "07300"
BLOOMFIELD_CDP = "07675"
BONEAU_CDP = "08162"
BONNER_WEST_RIVERSIDE_CDP = "08462"
BOULDER_CITY = "08575"
BOX_ELDER_CDP = "08725"
BOYD_CDP = "08800"
BOZEMAN_CITY = "08950"
BRADY_CDP = "09250"
BRANDON_CDP = "09400"
BRIDGER_CDP = "09500"
BRIDGER_TOWN = "09475"
BROADUS_TOWN = "09700"
BROADVIEW_TOWN = "09775"
BROCKTON_CDP = "10000"
BROCKWAY_CDP = "10075"
BROOKS_CDP = "10150"
BROWNING_TOWN = "10375"
BULL_LAKE_CDP = "10935"
BUSBY_CDP = "11200"
BUTTE_SILVER_BOW_BALANCE = "11397"
BYNUM_CDP = "11500"
CAMAS_CDP = "11800"
CAMP_THREE_CDP = "11995"
CAMROSE_COLONY_CDP = "11999"
CANYON_CREEK_CDP = "12025"
CARDWELL_CDP = "12400"
CARLTON_CDP = "12435"
CARTER_CDP = "12625"
CASCADE_COLONY_CDP = "12783"
CASCADE_TOWN = "12775"
CENTERVILLE_CDP = "13375"
CHARLO_CDP = "13900"
CHARLOS_HEIGHTS_CDP = "13975"
CHESTER_TOWN = "14200"
CHINOOK_CITY = "14575"
CHOTEAU_CITY = "14650"
CHURCHILL_CDP = "14875"
CIRCLE_TOWN = "14950"
CLANCY_CDP = "15100"
CLINTON_CDP = "15475"
CLYDE_PARK_TOWN = "15550"
COFFEE_CREEK_CDP = "16000"
COLSTRIP_CITY = "16525"
COLUMBIA_FALLS_CITY = "16600"
COLUMBUS_TOWN = "16825"
CONDON_CDP = "17050"
CONNER_CDP = "17200"
CONRAD_CITY = "17275"
COOKE_CITY_CDP = "17350"
CORAM_CDP = "17500"
CORVALLIS_CDP = "17725"
CORWIN_SPRINGS_CDP = "17800"
CRAIG_CDP = "18025"
CRANE_CDP = "18100"
CROW_AGENCY_CDP = "18250"
CULBERTSON_TOWN = "18475"
CUSTER_CDP = "18700"
CUT_BANK_CITY = "18775"
CYR_CDP = "18850"
DANVERS_CDP = "19225"
DARBY_TOWN = "19300"
DAYTON_CDP = "19525"
DE_BORGIA_CDP = "19675"
DEER_LODGE_CITY = "19825"
DEERFIELD_COLONY_CDP = "19800"
DELL_CDP = "20050"
DENTON_TOWN = "20425"
DEWEY_CDP = "20725"
DILLON_CITY = "20800"
DIXON_CDP = "20950"
DODSON_TOWN = "21025"
DRUMMOND_TOWN = "21850"
DUNCAN_RANCH_COLONY_CDP = "22130"
DUPUYER_CDP = "22450"
DUTTON_TOWN = "22600"
EAGLE_CREEK_COLONY_CDP = "22655"
EAST_END_COLONY_CDP = "22943"
EAST_GLACIER_PARK_VILLAGE_CDP = "22985"
EAST_HELENA_CITY = "23125"
EAST_MALTA_COLONY_CDP = "23168"
EAST_MISSOULA_CDP = "23200"
EDGAR_CDP = "23500"
EKALAKA_TOWN = "23650"
ELKHORN_CDP = "23865"
ELLISTON_CDP = "23950"
ELMO_CDP = "24100"
EMIGRANT_CDP = "24325"
ENNIS_TOWN = "24475"
ESSEX_CDP = "24700"
EUREKA_TOWN = "24850"
EVARO_CDP = "25000"
EVERGREEN_CDP = "25075"
FAIR_HAVEN_COLONY_CDP = "25245"
FAIRFIELD_TOWN = "25225"
FAIRVIEW_TOWN = "25300"
FALLON_CDP = "25375"
FINLEY_POINT_CDP = "26226"
FISHTAIL_CDP = "26575"
FLAT_WILLOW_COLONY_CDP = "26733"
FLAXVILLE_TOWN = "26800"
FLORENCE_CDP = "26950"
FLOWEREE_CDP = "27025"
FORDS_CREEK_COLONY_CDP = "27360"
FOREST_HILL_VILLAGE_CDP = "27595"
FORSYTH_CITY = "27700"
FORT_BELKNAP_AGENCY_CDP = "27850"
FORT_BENTON_CITY = "28000"
FORT_PECK_TOWN = "28450"
FORT_SHAW_CDP = "28600"
FORT_SMITH_CDP = "28650"
FORTINE_CDP = "28150"
FORTY_MILE_COLONY_CDP = "28725"
FOUR_CORNERS_CDP = "28862"
FOX_CDP = "29050"
FOX_LAKE_CDP = "29087"
FRAZER_CDP = "29275"
FRENCHTOWN_CDP = "29350"
FROID_TOWN = "29500"
FROMBERG_TOWN = "29575"
GALLATIN_GATEWAY_CDP = "29875"
GALLATIN_RIVER_RANCH_CDP = "29885"
GARDINER_CDP = "29950"
GARRISON_CDP = "30175"
GERALDINE_TOWN = "30400"
GEYSER_CDP = "30550"
GIBSON_FLATS_CDP = "30625"
GILDFORD_CDP = "30700"
GILDFORD_COLONY_CDP = "30704"
GILMAN_CDP = "30750"
GLACIER_COLONY_CDP = "30925"
GLASGOW_CITY = "31075"
GLEN_CDP = "31375"
GLENDALE_COLONY_CDP = "31418"
GLENDIVE_CITY = "31450"
GOLDCREEK_CDP = "31825"
GOLDEN_VALLEY_COLONY_CDP = "31991"
GRANT_CDP = "32350"
GRASS_RANGE_TOWN = "32575"
GREAT_FALLS_CITY = "32800"
GREYCLIFF_CDP = "33250"
HALL_CDP = "33625"
HAMILTON_CITY = "33775"
HAPPYS_INN_CDP = "34110"
HARDIN_CITY = "34225"
HARDY_CDP = "34300"
HARLEM_CITY = "34375"
HARLOWTON_CITY = "34450"
HARRISON_CDP = "34525"
HARTLAND_COLONY_CDP = "34584"
HAUGAN_CDP = "34825"
HAVRE_NORTH_CDP = "35125"
HAVRE_CITY = "35050"
HAYS_CDP = "35275"
HEART_BUTTE_CDP = "35350"
HEBGEN_LAKE_ESTATES_CDP = "35435"
HELENA_FLATS_CDP = "35622"
HELENA_VALLEY_NORTHEAST_CDP = "35628"
HELENA_VALLEY_NORTHWEST_CDP = "35631"
HELENA_VALLEY_SOUTHEAST_CDP = "35634"
HELENA_VALLEY_WEST_CENTRAL_CDP = "35637"
HELENA_WEST_SIDE_CDP = "35640"
HELENA_CITY = "35600"
HELMVILLE_CDP = "35725"
HERON_CDP = "35875"
HERRON_CDP = "35912"
HIDDEN_LAKE_COLONY_CDP = "36055"
HIGHWOOD_CDP = "36250"
HILGER_CDP = "36325"
HILLDALE_COLONY_CDP = "36333"
HILLSIDE_COLONY_CDP = "36385"
HINGHAM_TOWN = "36400"
HINSDALE_CDP = "36475"
HOBSON_CITY = "36700"
HOGELAND_CDP = "36925"
HOMESTEAD_CDP = "37450"
HORIZON_COLONY_CDP = "37710"
HOT_SPRINGS_TOWN = "37825"
HUNGRY_HORSE_CDP = "38125"
HUNTLEY_CDP = "38200"
HUSON_CDP = "38275"
HYSHAM_TOWN = "38350"
INDIAN_SPRINGS_CDP = "38480"
INVERNESS_CDP = "38725"
ISMAY_TOWN = "38950"
JACKSON_CDP = "39025"
JARDINE_CDP = "39175"
JEFFERS_CDP = "39325"
JEFFERSON_CITY_CDP = "39400"
JETTE_CDP = "39627"
JOLIET_TOWN = "39700"
JOPLIN_CDP = "39775"
JORDAN_TOWN = "39925"
JUDITH_GAP_CITY = "40000"
KALISPELL_CITY = "40075"
KERR_CDP = "40355"
KEVIN_TOWN = "40525"
KICKING_HORSE_CDP = "40580"
KILA_CDP = "40675"
KILBY_BUTTE_COLONY_CDP = "40680"
KING_ARTHUR_PARK_CDP = "40685"
KING_RANCH_COLONY_CDP = "40718"
KINGS_POINT_CDP = "40725"
KINGSBURY_COLONY_CDP = "40720"
KLEIN_CDP = "41050"
KREMLIN_CDP = "41725"
LAKE_MARY_RONAN_CDP = "41910"
LAKESIDE_CDP = "41950"
LAKEVIEW_CDP = "42100"
LAME_DEER_CDP = "42250"
LANDUSKY_CDP = "42325"
LAREDO_CDP = "42475"
LAUREL_CITY = "42700"
LAVINA_TOWN = "42850"
LEWISTOWN_HEIGHTS_CDP = "43400"
LEWISTOWN_CITY = "43375"
LIBBY_CITY = "43450"
LIMA_TOWN = "43525"
LINCOLN_CDP = "43675"
LINDISFARNE_CDP = "43710"
LINDSAY_CDP = "43750"
LITTLE_BITTERROOT_LAKE_CDP = "43830"
LITTLE_BROWNING_CDP = "43835"
LIVINGSTON_CITY = "43975"
LOCKWOOD_CDP = "44200"
LODGE_GRASS_TOWN = "44275"
LODGE_POLE_CDP = "44350"
LOGAN_CDP = "44500"
LOLO_CDP = "44650"
LOMA_CDP = "44800"
LONEPINE_CDP = "44950"
LORING_COLONY_CDP = "45179"
LUTHER_CDP = "46150"
MALMSTROM_AFB_CDP = "47275"
MALTA_CITY = "47425"
MAMMOTH_CDP = "47460"
MANHATTAN_TOWN = "47575"
MARION_CDP = "47875"
MARTIN_CITY_CDP = "48100"
MARTINSDALE_CDP = "48175"
MARTINSDALE_COLONY_CDP = "48190"
MARYSVILLE_CDP = "48250"
MAVERICK_MOUNTAIN_CDP = "48585"
MAXVILLE_CDP = "48625"
MCALLISTER_CDP = "46225"
MEDICINE_LAKE_TOWN = "48775"
MELSTONE_TOWN = "49000"
MIDWAY_COLONY_CDP = "49418"
MILES_CITY_CITY = "49525"
MILFORD_COLONY_CDP = "49600"
MILLER_COLONY_CDP = "49750"
MISSOULA_CITY = "50200"
MOCCASIN_CDP = "50575"
MONARCH_CDP = "50950"
MONTANA_CITY_CDP = "51175"
MONTAQUA_CDP = "51475"
MOORE_TOWN = "51550"
MOUNTAIN_VIEW_COLONY_CDP = "52185"
MUDDY_CDP = "52315"
MUSSELSHELL_CDP = "52600"
NASHUA_TOWN = "52900"
NEIHART_TOWN = "53200"
NEW_MIAMI_COLONY_CDP = "53476"
NEW_ROCKPORT_COLONY_CDP = "53500"
NIARADA_CDP = "53725"
NIBBE_CDP = "53800"
NORRIS_CDP = "54475"
NORTH_BROWNING_CDP = "54510"
NORTH_HARLEM_COLONY_CDP = "54684"
NOXON_CDP = "54925"
NYE_CDP = "55075"
OLD_AGENCY_CDP = "55260"
OLNEY_CDP = "55450"
OPHEIM_TOWN = "55525"
ORCHARD_HOMES_CDP = "55675"
OUTLOOK_TOWN = "56050"
OVANDO_CDP = "56125"
PABLO_CDP = "56350"
PARADISE_CDP = "56425"
PARK_CITY_CDP = "56575"
PARKER_SCHOOL_CDP = "56650"
PEERLESS_CDP = "56800"
PENDROY_CDP = "56875"
PHILIPSBURG_TOWN = "57175"
PILTZVILLE_CDP = "57475"
PINE_CREEK_CDP = "57550"
PINESDALE_TOWN = "57700"
PINNACLE_CDP = "57775"
PIONEER_JUNCTION_CDP = "57950"
PLAINS_TOWN = "58150"
PLEASANT_VALLEY_COLONY_CDP = "58310"
PLENTYWOOD_CITY = "58375"
PLEVNA_TOWN = "58450"
POLEBRIDGE_CDP = "58675"
POLSON_CITY = "58750"
POMPEYS_PILLAR_CDP = "58825"
PONDERA_COLONY_CDP = "58834"
PONDEROSA_PINES_CDP = "58840"
PONY_CDP = "58900"
POPLAR_CITY = "58975"
POTOMAC_CDP = "59350"
POWER_CDP = "59500"
PRAIRIE_ELK_COLONY_CDP = "59650"
PRAY_CDP = "59725"
PRYOR_CDP = "59950"
RACETRACK_CDP = "60400"
RADER_CREEK_CDP = "60450"
RADERSBURG_CDP = "60475"
RAPELJE_CDP = "60850"
RAVALLI_CDP = "61075"
RAYNESFORD_CDP = "61300"
RED_LODGE_CITY = "61525"
REDSTONE_CDP = "61675"
REED_POINT_CDP = "61900"
RESERVE_CDP = "62125"
REXFORD_TOWN = "62200"
RHODES_CDP = "62230"
RICEVILLE_CDP = "62245"
RICHEY_TOWN = "62275"
RIMINI_CDP = "62650"
RIMROCK_COLONY_CDP = "62825"
RIVERBEND_CDP = "63042"
RIVERVIEW_COLONY_CDP = "63266"
ROBERTS_CDP = "63400"
ROCKPORT_COLONY_CDP = "63590"
ROCKVALE_CDP = "63700"
ROCKY_BOY_WEST_CDP = "63928"
ROCKY_BOYS_AGENCY_CDP = "63900"
ROCKY_POINT_CDP = "63940"
ROLLINS_CDP = "64075"
RONAN_CITY = "64150"
ROSCOE_CDP = "64300"
ROSEBUD_CDP = "64375"
ROUNDUP_CITY = "64525"
ROY_CDP = "64675"
RUDYARD_CDP = "64900"
RYEGATE_TOWN = "64975"
SACO_TOWN = "65050"
SADDLE_BUTTE_CDP = "65065"
SAGE_CREEK_COLONY_CDP = "65160"
SALTESE_CDP = "65875"
SAND_COULEE_CDP = "65950"
SANGREY_CDP = "66212"
SANTA_RITA_CDP = "66250"
SAPPHIRE_RIDGE_CDP = "66317"
SAVAGE_CDP = "66550"
SCOBEY_CITY = "66925"
SEDAN_CDP = "67075"
SEELEY_LAKE_CDP = "67150"
SEVILLE_COLONY_CDP = "67192"
SHAWMUT_CDP = "67225"
SHELBY_CITY = "67450"
SHEPHERD_CDP = "67525"
SHERIDAN_TOWN = "67600"
SIDNEY_CITY = "67900"
SILESIA_CDP = "68050"
SILVER_GATE_CDP = "68425"
SILVER_STAR_CDP = "68500"
SIMMS_CDP = "68575"
SLEEPING_BUFFALO_CDP = "68985"
SNOWSLIP_CDP = "69345"
SOMERS_CDP = "69475"
SOUTH_BROWNING_CDP = "69680"
SOUTH_GLASTONBURY_CDP = "69713"
SOUTH_HILLS_CDP = "69725"
SPOKANE_CREEK_CDP = "69900"
SPRING_CREEK_COLONY_CDP = "70000"
SPRINGDALE_CDP = "70150"
SPRINGDALE_COLONY_CDP = "70225"
SPRINGHILL_CDP = "70375"
SPRINGWATER_COLONY_CDP = "70434"
SQUARE_BUTTE_CDP = "70600"
ST_IGNATIUS_TOWN = "65275"
ST_MARIE_CDP = "65400"
ST_MARY_CDP = "65425"
ST_PIERRE_CDP = "65537"
ST_REGIS_CDP = "65575"
ST_XAVIER_CDP = "65650"
STANFORD_TOWN = "70675"
STARR_SCHOOL_CDP = "70825"
STEVENSVILLE_TOWN = "71200"
STOCKETT_CDP = "71350"
STRYKER_CDP = "71575"
SULA_CDP = "71800"
SUN_PRAIRIE_CDP = "72380"
SUN_RIVER_CDP = "72475"
SUNBURST_TOWN = "72175"
SUNNYBROOK_COLONY_CDP = "72305"
SUPERIOR_TOWN = "72625"
SURPRISE_CREEK_COLONY_CDP = "72660"
SWAN_LAKE_CDP = "72850"
SWEET_GRASS_CDP = "73075"
SYLVANITE_CDP = "73165"
TERRY_TOWN = "73675"
THE_SILOS_CDP = "73760"
THOMPSON_FALLS_CITY = "73825"
THREE_FORKS_CITY = "73975"
TOSTON_CDP = "74500"
TOWNSEND_CITY = "74575"
TRACY_CDP = "74650"
TREGO_CDP = "74725"
TROUT_CREEK_CDP = "74950"
TROY_CITY = "75025"
TURAH_CDP = "75175"
TURNER_CDP = "75250"
TURNER_COLONY_CDP = "75258"
TURTLE_LAKE_CDP = "75287"
TWIN_BRIDGES_TOWN = "75475"
TWIN_CREEKS_CDP = "75550"
TWIN_HILLS_COLONY_CDP = "75590"
TWODOT_CDP = "75700"
ULM_CDP = "75775"
UNIONVILLE_CDP = "75905"
UTICA_CDP = "76075"
VALIER_TOWN = "76225"
VAUGHN_CDP = "76675"
VICTOR_CDP = "76900"
VIDA_CDP = "76975"
VIRGINIA_CITY_TOWN = "77125"
WALKERVILLE_TOWN = "77650"
WARM_SPRING_CREEK_CDP = "78143"
WEEKSVILLE_CDP = "78775"
WEST_GLACIER_CDP = "79075"
WEST_GLENDIVE_CDP = "79086"
WEST_HAVRE_CDP = "79098"
WEST_KOOTENAI_CDP = "79105"
WEST_YELLOWSTONE_TOWN = "79525"
WESTBY_TOWN = "78925"
WHEATLAND_CDP = "79695"
WHITE_HAVEN_CDP = "79935"
WHITE_SULPHUR_SPRINGS_CITY = "80050"
WHITEFISH_CITY = "79825"
WHITEHALL_TOWN = "79900"
WHITETAIL_CDP = "80125"
WHITEWATER_CDP = "80200"
WHITLASH_CDP = "80275"
WIBAUX_TOWN = "80350"
WILLOW_CREEK_CDP = "80800"
WILSALL_CDP = "80875"
WINDHAM_CDP = "80950"
WINEGLASS_CDP = "80975"
WINIFRED_TOWN = "81025"
WINNETT_TOWN = "81100"
WINSTON_CDP = "81175"
WISDOM_CDP = "81250"
WISE_RIVER_CDP = "81325"
WOLF_CREEK_CDP = "81400"
WOLF_POINT_CITY = "81475"
WOODS_BAY_CDP = "81700"
WORDEN_CDP = "81925"
WYE_CDP = "81980"
WYOLA_CDP = "82075"
YAAK_CDP = "82130"
YORK_CDP = "82525"
ZENITH_COLONY_CDP = "82635"
ZORTMAN_CDP = "82675"
ZURICH_CDP = "82750"
