# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Iowa."""


ADAIR = "001"
ADAMS = "003"
ALLAMAKEE = "005"
APPANOOSE = "007"
AUDUBON = "009"
BENTON = "011"
BLACK_HAWK = "013"
BOONE = "015"
BREMER = "017"
BUCHANAN = "019"
BUENA_VISTA = "021"
BUTLER = "023"
CALHOUN = "025"
CARROLL = "027"
CASS = "029"
CEDAR = "031"
CERRO_GORDO = "033"
CHEROKEE = "035"
CHICKASAW = "037"
CLARKE = "039"
CLAY = "041"
CLAYTON = "043"
CLINTON = "045"
CRAWFORD = "047"
DALLAS = "049"
DAVIS = "051"
DECATUR = "053"
DELAWARE = "055"
DES_MOINES = "057"
DICKINSON = "059"
DUBUQUE = "061"
EMMET = "063"
FAYETTE = "065"
FLOYD = "067"
FRANKLIN = "069"
FREMONT = "071"
GREENE = "073"
GRUNDY = "075"
GUTHRIE = "077"
HAMILTON = "079"
HANCOCK = "081"
HARDIN = "083"
HARRISON = "085"
HENRY = "087"
HOWARD = "089"
HUMBOLDT = "091"
IDA = "093"
IOWA = "095"
JACKSON = "097"
JASPER = "099"
JEFFERSON = "101"
JOHNSON = "103"
JONES = "105"
KEOKUK = "107"
KOSSUTH = "109"
LEE = "111"
LINN = "113"
LOUISA = "115"
LUCAS = "117"
LYON = "119"
MADISON = "121"
MAHASKA = "123"
MARION = "125"
MARSHALL = "127"
MILLS = "129"
MITCHELL = "131"
MONONA = "133"
MONROE = "135"
MONTGOMERY = "137"
MUSCATINE = "139"
OBRIEN = "141"
OSCEOLA = "143"
PAGE = "145"
PALO_ALTO = "147"
PLYMOUTH = "149"
POCAHONTAS = "151"
POLK = "153"
POTTAWATTAMIE = "155"
POWESHIEK = "157"
RINGGOLD = "159"
SAC = "161"
SCOTT = "163"
SHELBY = "165"
SIOUX = "167"
STORY = "169"
TAMA = "171"
TAYLOR = "173"
UNION = "175"
VAN_BUREN = "177"
WAPELLO = "179"
WARREN = "181"
WASHINGTON = "183"
WAYNE = "185"
WEBSTER = "187"
WINNEBAGO = "189"
WINNESHIEK = "191"
WOODBURY = "193"
WORTH = "195"
WRIGHT = "197"
