# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Tennessee."""


ADAMS_CITY = "00200"
ADAMSVILLE_TOWN = "00240"
ALAMO_TOWN = "00440"
ALCOA_CITY = "00540"
ALEXANDRIA_TOWN = "00620"
ALGOOD_CITY = "00640"
ALLARDT_CITY = "00660"
ALTAMONT_TOWN = "00940"
ANDERSONVILLE_CDP = "01220"
APISON_CDP = "01480"
ARDMORE_CITY = "01640"
ARLINGTON_TOWN = "01740"
ASHLAND_CITY_TOWN = "02180"
ATHENS_CITY = "02320"
ATOKA_TOWN = "02340"
ATWOOD_TOWN = "02380"
AUBURNTOWN_TOWN = "02400"
BAILEYTON_TOWN = "02780"
BANEBERRY_CITY = "03078"
BANNER_HILL_CDP = "03120"
BARTLETT_CITY = "03440"
BAXTER_TOWN = "03680"
BEAN_STATION_CITY = "03760"
BEECH_BLUFF_CDP = "04000"
BEERSHEBA_SPRINGS_TOWN = "04240"
BELL_BUCKLE_TOWN = "04460"
BELLE_MEADE_CITY = "04620"
BELLS_CITY = "04720"
BELVIDERE_CDP = "04920"
BENTON_TOWN = "05040"
BERRY_HILL_CITY = "05140"
BETHEL_SPRINGS_TOWN = "05380"
BETHPAGE_CDP = "05500"
BIG_ROCK_CDP = "05840"
BIG_SANDY_TOWN = "05860"
BILTMORE_CDP = "06020"
BLAINE_CITY = "06340"
BLANCHE_CDP = "06440"
BLOOMINGDALE_CDP = "06640"
BLOUNTVILLE_CDP = "06740"
BLUFF_CITY_CITY = "06960"
BOGOTA_CDP = "07120"
BOLIVAR_CITY = "07180"
BON_AIR_CDP = "07240"
BON_AQUA_JUNCTION_CDP = "07280"
BOWMAN_CDP = "07620"
BRADEN_TOWN = "07840"
BRADFORD_TOWN = "07860"
BRANSFORD_CDP = "08080"
BRENTWOOD_CITY = "08280"
BRICEVILLE_CDP = "08400"
BRIGHTON_TOWN = "08500"
BRISTOL_CITY = "08540"
BROWNSVILLE_CITY = "08920"
BRUCETON_TOWN = "08960"
BUCHANAN_CDP = "09200"
BULLS_GAP_TOWN = "09560"
BURLISON_TOWN = "09860"
BURNS_TOWN = "09880"
BUTLER_CDP = "10080"
BYRDSTOWN_TOWN = "10180"
CALHOUN_TOWN = "10440"
CAMDEN_CITY = "10560"
CARTHAGE_TOWN = "11280"
CARYVILLE_TOWN = "11360"
CASTALIAN_SPRINGS_CDP = "11440"
CEDAR_HILL_CITY = "11980"
CELINA_CITY = "12100"
CENTERTOWN_TOWN = "12380"
CENTERVILLE_TOWN = "12420"
CENTRAL_CDP = "12460"
CHAPEL_HILL_TOWN = "12880"
CHARLESTON_CITY = "13020"
CHARLOTTE_TOWN = "13080"
CHATTANOOGA_CITY = "14000"
CHESTERFIELD_CDP = "14220"
CHEWALLA_CDP = "14520"
CHILDERS_HILL_CDP = "14620"
CHRISTIANA_CDP = "14860"
CHURCH_HILL_CITY = "14980"
CLARKRANGE_CDP = "15120"
CLARKSBURG_TOWN = "15140"
CLARKSVILLE_CITY = "15160"
CLEVELAND_CITY = "15400"
CLIFTON_CITY = "15480"
CLINTON_CITY = "15580"
COALFIELD_CDP = "15880"
COALMONT_CITY = "15920"
COKER_CREEK_CDP = "16060"
COLLEGEDALE_CITY = "16300"
COLLIERVILLE_TOWN = "16420"
COLLINWOOD_CITY = "16480"
COLONIAL_HEIGHTS_CDP = "16500"
COLUMBIA_CITY = "16540"
CONASAUGA_CDP = "16740"
COOKEVILLE_CITY = "16920"
COOPERTOWN_TOWN = "16980"
COPPERHILL_CITY = "17000"
CORNERSVILLE_TOWN = "17180"
COSBY_CDP = "17300"
COTTAGE_GROVE_TOWN = "17340"
COTTONTOWN_CDP = "17420"
COUNCE_CDP = "17520"
COVINGTON_CITY = "17680"
COWAN_CITY = "17700"
CRAB_ORCHARD_CITY = "17840"
CROSS_PLAINS_CITY = "18420"
CROSSVILLE_CITY = "18540"
CRUMP_CITY = "18620"
CUMBERLAND_CITY_TOWN = "18820"
CUMBERLAND_GAP_TOWN = "18880"
DANCYVILLE_CDP = "19360"
DANDRIDGE_TOWN = "19380"
DARDEN_CDP = "19500"
DAYTON_CITY = "19700"
DECATUR_TOWN = "19880"
DECATURVILLE_TOWN = "19900"
DECHERD_CITY = "19920"
DELANO_CDP = "20080"
DELLROSE_CDP = "20120"
DICKSON_CITY = "20620"
DODSON_BRANCH_CDP = "20930"
DOVER_CITY = "21400"
DOWELLTOWN_TOWN = "21420"
DOYLE_TOWN = "21500"
DRESDEN_TOWN = "21540"
DUCKTOWN_CITY = "21740"
DUKEDOM_CDP = "21860"
DUNLAP_CITY = "22000"
DYER_CITY = "22180"
DYERSBURG_CITY = "22200"
EAGLETON_VILLAGE_CDP = "22340"
EAGLEVILLE_CITY = "22360"
EAST_CLEVELAND_CDP = "22500"
EAST_RIDGE_CITY = "22720"
EASTVIEW_TOWN = "22920"
ELGIN_CDP = "23440"
ELIZABETHTON_CITY = "23500"
ELKTON_CITY = "23660"
EMBREEVILLE_CDP = "23880"
ENGLEWOOD_TOWN = "24040"
ENVILLE_TOWN = "24240"
ERIN_CITY = "24320"
ERWIN_TOWN = "24360"
ESSARY_SPRINGS_CDP = "24400"
ESTILL_SPRINGS_TOWN = "24440"
ETHRIDGE_TOWN = "24460"
ETOWAH_CITY = "24480"
EVA_CDP = "24640"
FAIRFIELD_CDP = "24960"
FAIRFIELD_GLADE_CDP = "24980"
FAIRGARDEN_CDP = "24990"
FAIRMOUNT_CDP = "25080"
FAIRVIEW_CITY = "25440"
FALL_BRANCH_CDP = "25540"
FALLING_WATER_CDP = "25560"
FARNER_CDP = "25740"
FARRAGUT_TOWN = "25760"
FAYETTEVILLE_CITY = "25920"
FINCASTLE_CDP = "26120"
FINGER_CITY = "26160"
FINLEY_CDP = "26180"
FLAT_TOP_MOUNTAIN_CDP = "26490"
FLINTVILLE_CDP = "26580"
FOREST_HILLS_CITY = "27020"
FOWLKES_CDP = "27640"
FRANKEWING_CDP = "27700"
FRANKLIN_CITY = "27740"
FRIENDSHIP_CITY = "27960"
FRIENDSVILLE_CITY = "28060"
GADSDEN_TOWN = "28380"
GAINESBORO_TOWN = "28420"
GALLATIN_CITY = "28540"
GALLAWAY_CITY = "28560"
GARLAND_TOWN = "28680"
GATES_TOWN = "28740"
GATLINBURG_CITY = "28800"
GERMANTOWN_CITY = "28960"
GIBSON_TOWN = "29020"
GILT_EDGE_CITY = "29160"
GLADEVILLE_CDP = "29260"
GLEASON_TOWN = "29300"
GOODLETTSVILLE_CITY = "29920"
GORDONSVILLE_TOWN = "30120"
GRABALL_CDP = "30220"
GRAND_JUNCTION_CITY = "30280"
GRAY_CDP = "30700"
GRAYSVILLE_TOWN = "30760"
GREEN_HILL_CDP = "31100"
GREENBACK_CITY = "30880"
GREENBRIER_TOWN = "30960"
GREENEVILLE_TOWN = "30980"
GREENFIELD_CITY = "31000"
GREENVALE_CDP = "31220"
GRIFFITH_CREEK_CDP = "31400"
GRIMSLEY_CDP = "31420"
GRUETLI_LAAGER_CITY = "31490"
GUYS_TOWN = "31680"
HALLS_CDP = "31810"
HALLS_TOWN = "31820"
HAMPTON_CDP = "32040"
HARRIMAN_CITY = "32520"
HARRISON_CDP = "32600"
HARROGATE_CITY = "32640"
HARTSVILLE_TROUSDALE_COUNTY = "32742"
HELENWOOD_CDP = "33120"
HENDERSON_CITY = "33260"
HENDERSONVILLE_CITY = "33280"
HENNING_TOWN = "33360"
HENRY_TOWN = "33400"
HICKMAN_CDP = "33680"
HICKORY_VALLEY_TOWN = "33920"
HILHAM_CDP = "34580"
HILLSBORO_CDP = "34700"
HOHENWALD_CITY = "35160"
HOLLADAY_CDP = "35220"
HOLLOW_ROCK_TOWN = "35280"
HOPEWELL_CDP = "35880"
HORNBEAK_TOWN = "36000"
HORNSBY_TOWN = "36080"
HUMBOLDT_CITY = "36460"
HUNTER_CDP = "36500"
HUNTINGDON_TOWN = "36580"
HUNTLAND_TOWN = "36600"
HUNTSVILLE_TOWN = "36640"
HURON_CDP = "36700"
IRON_CITY_CDP = "37360"
JACKS_CREEK_CDP = "37620"
JACKSBORO_TOWN = "37600"
JACKSON_CITY = "37640"
JAMESTOWN_CITY = "37780"
JASPER_TOWN = "37820"
JEFFERSON_CITY_CITY = "37960"
JELLICO_CITY = "38020"
JOHN_SEVIER_CDP = "38300"
JOHNSON_CITY_CITY = "38320"
JONESBOROUGH_TOWN = "38540"
KAHITE_CDP = "38765"
KARNS_CDP = "38800"
KENTON_TOWN = "39140"
KIMBALL_TOWN = "39400"
KINGSPORT_CITY = "39560"
KINGSTON_SPRINGS_TOWN = "39660"
KINGSTON_CITY = "39620"
KNOXVILLE_CITY = "40000"
LA_FOLLETTE_CITY = "40180"
LA_GRANGE_TOWN = "40200"
LA_VERGNE_CITY = "41200"
LAFAYETTE_CITY = "40160"
LAKE_TANSI_CDP = "40560"
LAKELAND_CITY = "40350"
LAKESITE_CITY = "40540"
LAKEWOOD_PARK_CDP = "40732"
LAVINIA_CDP = "41240"
LAWRENCEBURG_CITY = "41340"
LEBANON_CITY = "41520"
LENOIR_CITY_CITY = "41760"
LENOX_CDP = "41780"
LEOMA_CDP = "41800"
LEWISBURG_CITY = "41860"
LEXINGTON_CITY = "41980"
LIBERTY_TOWN = "42040"
LINDEN_TOWN = "42720"
LIVINGSTON_TOWN = "43140"
LOBELVILLE_CITY = "43160"
LONE_OAK_CDP = "43420"
LOOKOUT_MOUNTAIN_TOWN = "43640"
LORETTO_CITY = "43700"
LOUDON_CITY = "43780"
LOUISVILLE_CITY = "43820"
LURAY_CDP = "44200"
LUTTRELL_TOWN = "44300"
LYLES_CDP = "44360"
LYNCHBURG = "44382"
LYNNVILLE_TOWN = "44420"
MADISONVILLE_CITY = "45320"
MANCHESTER_CITY = "45500"
MARTIN_CITY = "46240"
MARYVILLE_CITY = "46380"
MASCOT_CDP = "46400"
MASON_TOWN = "46420"
MAURY_CITY_TOWN = "46540"
MAYLAND_CDP = "46680"
MAYNARDVILLE_CITY = "46700"
MCDONALD_CDP = "44700"
MCEWEN_CITY = "44840"
MCKENZIE_CITY = "44940"
MCLEMORESVILLE_TOWN = "45000"
MCMINNVILLE_CITY = "45100"
MEDINA_CITY = "47000"
MEDON_CITY = "47020"
MEMPHIS_CITY = "48000"
MERCER_CDP = "48120"
MICHIE_TOWN = "48180"
MIDDLE_VALLEY_CDP = "48360"
MIDDLETON_CITY = "48340"
MIDTOWN_CDP = "48460"
MILAN_CITY = "48660"
MILLEDGEVILLE_TOWN = "48920"
MILLERSVILLE_CITY = "48980"
MILLINGTON_CITY = "49060"
MINOR_HILL_CITY = "49360"
MISTON_CDP = "49420"
MITCHELLVILLE_CITY = "49460"
MONTEAGLE_TOWN = "49740"
MONTEREY_TOWN = "49760"
MOORESBURG_CDP = "49940"
MORRIS_CHAPEL_CDP = "50200"
MORRISON_TOWN = "50220"
MORRISTOWN_CITY = "50280"
MOSCOW_CITY = "50300"
MOSHEIM_TOWN = "50320"
MOUNT_CARMEL_TOWN = "50580"
MOUNT_JULIET_CITY = "50780"
MOUNT_PLEASANT_CITY = "51080"
MOUNTAIN_CITY_TOWN = "50400"
MOWBRAY_MOUNTAIN_CDP = "51402"
MUNFORD_CITY = "51540"
MURFREESBORO_CITY = "51560"
NASHVILLE_DAVIDSON_METROPOLITAN_GOVERNMENT_BALANCE = "52006"
NEW_DEAL_CDP = "52520"
NEW_HOPE_CITY = "52780"
NEW_JOHNSONVILLE_CITY = "52820"
NEW_MARKET_TOWN = "52940"
NEW_TAZEWELL_TOWN = "53140"
NEW_UNION_CDP = "53240"
NEWBERN_TOWN = "52400"
NEWPORT_CITY = "53000"
NIOTA_CITY = "53380"
NIXON_CDP = "53400"
NOLENSVILLE_TOWN = "53460"
NORENE_CDP = "53520"
NORMANDY_TOWN = "53580"
NORRIS_CITY = "53600"
OAK_GROVE_CDP_SUMNER_COUNTY = "54640"
OAK_GROVE_CDP_WASHINGTON_COUNTY = "54700"
OAK_HILL_CITY = "54780"
OAK_RIDGE_CITY = "55120"
OAKDALE_TOWN = "54280"
OAKLAND_TOWN = "54920"
OBION_TOWN = "55240"
OCOEE_CDP = "55280"
OLIVER_SPRINGS_TOWN = "55800"
OLIVET_CDP = "55820"
ONEIDA_TOWN = "55860"
OOLTEWAH_CDP = "55900"
OREBANK_CDP = "55980"
ORLINDA_CITY = "56020"
ORME_TOWN = "56040"
PALMER_TOWN = "56560"
PALMERSVILLE_CDP = "56580"
PARIS_CITY = "56720"
PARK_CITY_CDP = "56800"
PARKERS_CROSSROADS_CITY = "56870"
PARROTTSVILLE_TOWN = "57040"
PARSONS_CITY = "57080"
PEGRAM_TOWN = "57480"
PELHAM_CDP = "57500"
PETERSBURG_TOWN = "57740"
PETROS_CDP = "57780"
PHILADELPHIA_CITY = "57900"
PIGEON_FORGE_CITY = "58080"
PIKEVILLE_CITY = "58120"
PINE_CREST_CDP = "58240"
PINSON_CDP = "58780"
PIPERTON_CITY = "58840"
PITTMAN_CENTER_TOWN = "58940"
PLAINVIEW_CITY = "59020"
PLEASANT_HILL_TOWN = "59240"
PLEASANT_VIEW_CITY = "59560"
POCAHONTAS_CDP = "59640"
PORTLAND_CITY = "60280"
POWELL_CDP = "60480"
POWELLS_CROSSROADS_TOWN = "60500"
PROSPECT_CDP = "60800"
PULASKI_CITY = "61040"
PURYEAR_CITY = "61160"
RAMER_CITY = "61520"
RANDOLPH_CDP = "61560"
RARITY_BAY_CDP = "61635"
RED_BANK_CITY = "61960"
RED_BOILING_SPRINGS_CITY = "62000"
RICEVILLE_CDP = "62580"
RIDGELY_TOWN = "63060"
RIDGESIDE_CITY = "63080"
RIDGETOP_CITY = "63140"
RIPLEY_CITY = "63340"
RIVES_TOWN = "63800"
ROAN_MOUNTAIN_CDP = "63840"
ROBBINS_CDP = "63920"
ROCKFORD_CITY = "64160"
ROCKVALE_CDP = "64400"
ROCKWOOD_CITY = "64440"
ROCKY_TOP_CITY = "64668"
ROGERSVILLE_TOWN = "64820"
ROSSVILLE_TOWN = "65240"
RURAL_HILL_CDP = "65642"
RUSSELLVILLE_CDP = "65740"
RUTHERFORD_TOWN = "65760"
RUTLEDGE_TOWN = "65820"
SALE_CREEK_CDP = "66220"
SALTILLO_TOWN = "66340"
SAMBURG_TOWN = "66360"
SARDIS_TOWN = "66660"
SAULSBURY_TOWN = "66680"
SAVANNAH_CITY = "66720"
SCOTTS_HILL_TOWN = "66880"
SELMER_TOWN = "66940"
SEQUATCHIE_CDP = "66960"
SEVIERVILLE_CITY = "67120"
SEWANEE_CDP = "67140"
SEYMOUR_CDP = "67200"
SHACKLE_ISLAND_CDP = "67230"
SHARON_TOWN = "67540"
SHELBYVILLE_CITY = "67760"
SHERWOOD_CDP = "67920"
SHILOH_CDP = "68040"
SIGNAL_MOUNTAIN_TOWN = "68540"
SILERTON_TOWN = "68560"
SLAYDEN_TOWN = "69080"
SMITHVILLE_CITY = "69320"
SMYRNA_TOWN = "69420"
SNEEDVILLE_TOWN = "69460"
SODDY_DAISY_CITY = "69560"
SOMERVILLE_TOWN = "69620"
SOUTH_CARTHAGE_TOWN = "69680"
SOUTH_CLEVELAND_CDP = "69740"
SOUTH_FULTON_CITY = "69900"
SOUTH_PITTSBURG_CITY = "70060"
SPARTA_CITY = "70180"
SPENCER_TOWN = "70240"
SPRING_CITY_TOWN = "70400"
SPRING_HILL_CITY = "70580"
SPRINGFIELD_CITY = "70500"
SPURGEON_CDP = "70680"
ST_JOSEPH_CITY = "66160"
STANTON_TOWN = "70820"
STANTONVILLE_TOWN = "70840"
STATESVILLE_CDP = "70900"
STRAWBERRY_PLAINS_CDP = "71500"
SULLIVAN_GARDENS_CDP = "71800"
SUMMERTOWN_CDP = "72040"
SUNBRIGHT_CITY = "72140"
SURGOINSVILLE_TOWN = "72380"
SWEETWATER_CITY = "72540"
TAFT_CDP = "72780"
TAZEWELL_TOWN = "73120"
TELFORD_CDP = "73220"
TELLICO_PLAINS_TOWN = "73260"
TELLICO_VILLAGE_CDP = "73270"
TENNESSEE_RIDGE_TOWN = "73460"
THOMPSONS_STATION_TOWN = "73900"
THREE_WAY_CITY = "74100"
TIPTONVILLE_TOWN = "74540"
TOONE_TOWN = "74640"
TOWNSEND_CITY = "74860"
TRACY_CITY_TOWN = "74880"
TRENTON_CITY = "75000"
TREZEVANT_TOWN = "75100"
TRIMBLE_TOWN = "75160"
TROY_TOWN = "75240"
TUCKERS_CROSSROADS_CDP = "75300"
TULLAHOMA_CITY = "75320"
TUSCULUM_CITY = "75560"
UNICOI_TOWN = "75820"
UNION_CITY_CITY = "75940"
UNIONVILLE_CDP = "76180"
VALLEY_FORGE_CDP = "76660"
VANLEER_TOWN = "76860"
VIOLA_TOWN = "77400"
VONORE_TOWN = "77480"
WALDEN_TOWN = "77540"
WALLAND_CDP = "77700"
WALNUT_GROVE_CDP_HARDIN_COUNTY = "77760"
WALNUT_GROVE_CDP_SUMNER_COUNTY = "77820"
WALNUT_HILL_CDP = "77900"
WALTERHILL_CDP = "77980"
WARTBURG_CITY = "78100"
WARTRACE_TOWN = "78120"
WATAUGA_CITY = "78240"
WATERTOWN_CITY = "78320"
WAVERLY_CITY = "78560"
WAYNESBORO_CITY = "78600"
WESTMORELAND_TOWN = "79420"
WESTPOINT_CDP = "79500"
WHITE_BLUFF_TOWN = "79980"
WHITE_HOUSE_CITY = "80200"
WHITE_PINE_TOWN = "80360"
WHITESIDE_CDP = "80500"
WHITEVILLE_TOWN = "80540"
WHITLOCK_CDP = "80580"
WHITWELL_CITY = "80620"
WILDERSVILLE_CDP = "80720"
WILDWOOD_CDP = "80740"
WILDWOOD_LAKE_CDP = "80760"
WILLISTON_CITY = "81020"
WINCHESTER_CITY = "81080"
WINFIELD_TOWN = "81280"
WOODBURY_TOWN = "81560"
WOODLAND_MILLS_CITY = "81700"
WRIGLEY_CDP = "82120"
WYNNBURG_CDP = "82200"
YORKVILLE_CITY = "82360"
YUMA_CDP = "82440"
