# Copyright (c) 2023 Darren Erik Vengroff
"""Divisions."""


EAST_NORTH_CENTRAL_DIVISION = "3"
EAST_SOUTH_CENTRAL_DIVISION = "6"
MIDDLE_ATLANTIC_DIVISION = "2"
MOUNTAIN_DIVISION = "8"
NEW_ENGLAND_DIVISION = "1"
PACIFIC_DIVISION = "9"
SOUTH_ATLANTIC_DIVISION = "5"
WEST_NORTH_CENTRAL_DIVISION = "4"
WEST_SOUTH_CENTRAL_DIVISION = "7"
