# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Puerto Rico."""


ADJUNTAS = "001"
AGUADA = "003"
AGUADILLA = "005"
AGUAS_BUENAS = "007"
AIBONITO = "009"
ARECIBO = "013"
ARROYO = "015"
ANASCO = "011"
BARCELONETA = "017"
BARRANQUITAS = "019"
BAYAMON = "021"
CABO_ROJO = "023"
CAGUAS = "025"
CAMUY = "027"
CANOVANAS = "029"
CAROLINA = "031"
CATANO = "033"
CAYEY = "035"
CEIBA = "037"
CIALES = "039"
CIDRA = "041"
COAMO = "043"
COMERIO = "045"
COROZAL = "047"
CULEBRA = "049"
DORADO = "051"
FAJARDO = "053"
FLORIDA = "054"
GUAYAMA = "057"
GUAYANILLA = "059"
GUAYNABO = "061"
GURABO = "063"
GUANICA = "055"
HATILLO = "065"
HORMIGUEROS = "067"
HUMACAO = "069"
ISABELA = "071"
JAYUYA = "073"
JUANA_DIAZ = "075"
JUNCOS = "077"
LAJAS = "079"
LARES = "081"
LAS_MARIAS = "083"
LAS_PIEDRAS = "085"
LOIZA = "087"
LUQUILLO = "089"
MANATI = "091"
MARICAO = "093"
MAUNABO = "095"
MAYAGUEZ = "097"
MOCA = "099"
MOROVIS = "101"
NAGUABO = "103"
NARANJITO = "105"
OROCOVIS = "107"
PATILLAS = "109"
PENUELAS = "111"
PONCE = "113"
QUEBRADILLAS = "115"
RINCON = "117"
RIO_GRANDE = "119"
SABANA_GRANDE = "121"
SALINAS = "123"
SAN_GERMAN = "125"
SAN_JUAN = "127"
SAN_LORENZO = "129"
SAN_SEBASTIAN = "131"
SANTA_ISABEL = "133"
TOA_ALTA = "135"
TOA_BAJA = "137"
TRUJILLO_ALTO = "139"
UTUADO = "141"
VEGA_ALTA = "143"
VEGA_BAJA = "145"
VIEQUES = "147"
VILLALBA = "149"
YABUCOA = "151"
YAUCO = "153"
