# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in New Mexico."""


BERNALILLO = "001"
CATRON = "003"
CHAVES = "005"
CIBOLA = "006"
COLFAX = "007"
CURRY = "009"
DE_BACA = "011"
DONA_ANA = "013"
EDDY = "015"
GRANT = "017"
GUADALUPE = "019"
HARDING = "021"
HIDALGO = "023"
LEA = "025"
LINCOLN = "027"
LOS_ALAMOS = "028"
LUNA = "029"
MCKINLEY = "031"
MORA = "033"
OTERO = "035"
QUAY = "037"
RIO_ARRIBA = "039"
ROOSEVELT = "041"
SAN_JUAN = "045"
SAN_MIGUEL = "047"
SANDOVAL = "043"
SANTA_FE = "049"
SIERRA = "051"
SOCORRO = "053"
TAOS = "055"
TORRANCE = "057"
UNION = "059"
VALENCIA = "061"
