# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Wisconsin."""


ADAMS = "001"
ASHLAND = "003"
BARRON = "005"
BAYFIELD = "007"
BROWN = "009"
BUFFALO = "011"
BURNETT = "013"
CALUMET = "015"
CHIPPEWA = "017"
CLARK = "019"
COLUMBIA = "021"
CRAWFORD = "023"
DANE = "025"
DODGE = "027"
DOOR = "029"
DOUGLAS = "031"
DUNN = "033"
EAU_CLAIRE = "035"
FLORENCE = "037"
FOND_DU_LAC = "039"
FOREST = "041"
GRANT = "043"
GREEN = "045"
GREEN_LAKE = "047"
IOWA = "049"
IRON = "051"
JACKSON = "053"
JEFFERSON = "055"
JUNEAU = "057"
KENOSHA = "059"
KEWAUNEE = "061"
LA_CROSSE = "063"
LAFAYETTE = "065"
LANGLADE = "067"
LINCOLN = "069"
MANITOWOC = "071"
MARATHON = "073"
MARINETTE = "075"
MARQUETTE = "077"
MENOMINEE = "078"
MILWAUKEE = "079"
MONROE = "081"
OCONTO = "083"
ONEIDA = "085"
OUTAGAMIE = "087"
OZAUKEE = "089"
PEPIN = "091"
PIERCE = "093"
POLK = "095"
PORTAGE = "097"
PRICE = "099"
RACINE = "101"
RICHLAND = "103"
ROCK = "105"
RUSK = "107"
SAUK = "111"
SAWYER = "113"
SHAWANO = "115"
SHEBOYGAN = "117"
ST_CROIX = "109"
TAYLOR = "119"
TREMPEALEAU = "121"
VERNON = "123"
VILAS = "125"
WALWORTH = "127"
WASHBURN = "129"
WASHINGTON = "131"
WAUKESHA = "133"
WAUPACA = "135"
WAUSHARA = "137"
WINNEBAGO = "139"
WOOD = "141"
