# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in North Dakota."""


ADAMS = "001"
BARNES = "003"
BENSON = "005"
BILLINGS = "007"
BOTTINEAU = "009"
BOWMAN = "011"
BURKE = "013"
BURLEIGH = "015"
CASS = "017"
CAVALIER = "019"
DICKEY = "021"
DIVIDE = "023"
DUNN = "025"
EDDY = "027"
EMMONS = "029"
FOSTER = "031"
GOLDEN_VALLEY = "033"
GRAND_FORKS = "035"
GRANT = "037"
GRIGGS = "039"
HETTINGER = "041"
KIDDER = "043"
LAMOURE = "045"
LOGAN = "047"
MCHENRY = "049"
MCINTOSH = "051"
MCKENZIE = "053"
MCLEAN = "055"
MERCER = "057"
MORTON = "059"
MOUNTRAIL = "061"
NELSON = "063"
OLIVER = "065"
PEMBINA = "067"
PIERCE = "069"
RAMSEY = "071"
RANSOM = "073"
RENVILLE = "075"
RICHLAND = "077"
ROLETTE = "079"
SARGENT = "081"
SHERIDAN = "083"
SIOUX = "085"
SLOPE = "087"
STARK = "089"
STEELE = "091"
STUTSMAN = "093"
TOWNER = "095"
TRAILL = "097"
WALSH = "099"
WARD = "101"
WELLS = "103"
WILLIAMS = "105"
