# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Arkansas."""


ARKANSAS = "001"
ASHLEY = "003"
BAXTER = "005"
BENTON = "007"
BOONE = "009"
BRADLEY = "011"
CALHOUN = "013"
CARROLL = "015"
CHICOT = "017"
CLARK = "019"
CLAY = "021"
CLEBURNE = "023"
CLEVELAND = "025"
COLUMBIA = "027"
CONWAY = "029"
CRAIGHEAD = "031"
CRAWFORD = "033"
CRITTENDEN = "035"
CROSS = "037"
DALLAS = "039"
DESHA = "041"
DREW = "043"
FAULKNER = "045"
FRANKLIN = "047"
FULTON = "049"
GARLAND = "051"
GRANT = "053"
GREENE = "055"
HEMPSTEAD = "057"
HOT_SPRING = "059"
HOWARD = "061"
INDEPENDENCE = "063"
IZARD = "065"
JACKSON = "067"
JEFFERSON = "069"
JOHNSON = "071"
LAFAYETTE = "073"
LAWRENCE = "075"
LEE = "077"
LINCOLN = "079"
LITTLE_RIVER = "081"
LOGAN = "083"
LONOKE = "085"
MADISON = "087"
MARION = "089"
MILLER = "091"
MISSISSIPPI = "093"
MONROE = "095"
MONTGOMERY = "097"
NEVADA = "099"
NEWTON = "101"
OUACHITA = "103"
PERRY = "105"
PHILLIPS = "107"
PIKE = "109"
POINSETT = "111"
POLK = "113"
POPE = "115"
PRAIRIE = "117"
PULASKI = "119"
RANDOLPH = "121"
SALINE = "125"
SCOTT = "127"
SEARCY = "129"
SEBASTIAN = "131"
SEVIER = "133"
SHARP = "135"
ST_FRANCIS = "123"
STONE = "137"
UNION = "139"
VAN_BUREN = "141"
WASHINGTON = "143"
WHITE = "145"
WOODRUFF = "147"
YELL = "149"
