# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Kansas."""


ALLEN = "001"
ANDERSON = "003"
ATCHISON = "005"
BARBER = "007"
BARTON = "009"
BOURBON = "011"
BROWN = "013"
BUTLER = "015"
CHASE = "017"
CHAUTAUQUA = "019"
CHEROKEE = "021"
CHEYENNE = "023"
CLARK = "025"
CLAY = "027"
CLOUD = "029"
COFFEY = "031"
COMANCHE = "033"
COWLEY = "035"
CRAWFORD = "037"
DECATUR = "039"
DICKINSON = "041"
DONIPHAN = "043"
DOUGLAS = "045"
EDWARDS = "047"
ELK = "049"
ELLIS = "051"
ELLSWORTH = "053"
FINNEY = "055"
FORD = "057"
FRANKLIN = "059"
GEARY = "061"
GOVE = "063"
GRAHAM = "065"
GRANT = "067"
GRAY = "069"
GREELEY = "071"
GREENWOOD = "073"
HAMILTON = "075"
HARPER = "077"
HARVEY = "079"
HASKELL = "081"
HODGEMAN = "083"
JACKSON = "085"
JEFFERSON = "087"
JEWELL = "089"
JOHNSON = "091"
KEARNY = "093"
KINGMAN = "095"
KIOWA = "097"
LABETTE = "099"
LANE = "101"
LEAVENWORTH = "103"
LINCOLN = "105"
LINN = "107"
LOGAN = "109"
LYON = "111"
MARION = "115"
MARSHALL = "117"
MCPHERSON = "113"
MEADE = "119"
MIAMI = "121"
MITCHELL = "123"
MONTGOMERY = "125"
MORRIS = "127"
MORTON = "129"
NEMAHA = "131"
NEOSHO = "133"
NESS = "135"
NORTON = "137"
OSAGE = "139"
OSBORNE = "141"
OTTAWA = "143"
PAWNEE = "145"
PHILLIPS = "147"
POTTAWATOMIE = "149"
PRATT = "151"
RAWLINS = "153"
RENO = "155"
REPUBLIC = "157"
RICE = "159"
RILEY = "161"
ROOKS = "163"
RUSH = "165"
RUSSELL = "167"
SALINE = "169"
SCOTT = "171"
SEDGWICK = "173"
SEWARD = "175"
SHAWNEE = "177"
SHERIDAN = "179"
SHERMAN = "181"
SMITH = "183"
STAFFORD = "185"
STANTON = "187"
STEVENS = "189"
SUMNER = "191"
THOMAS = "193"
TREGO = "195"
WABAUNSEE = "197"
WALLACE = "199"
WASHINGTON = "201"
WICHITA = "203"
WILSON = "205"
WOODSON = "207"
WYANDOTTE = "209"
