# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Wyoming."""


AFTON_TOWN = "00245"
ALBANY_CDP = "00680"
ALBIN_TOWN = "00825"
ALCOVA_CDP = "01115"
ALPINE_NORTHEAST_CDP = "01888"
ALPINE_NORTHWEST_CDP = "01936"
ALPINE_TOWN = "01695"
ALTA_CDP = "01985"
ANTELOPE_HILLS_CDP = "02877"
ARAPAHOE_CDP = "03000"
ARLINGTON_CDP = "03245"
ARROWHEAD_SPRINGS_CDP = "03652"
ARVADA_CDP = "03725"
ATLANTIC_CITY_CDP = "04015"
AUBURN_CDP = "04160"
BAGGS_TOWN = "04740"
BAIROIL_TOWN = "04885"
BAR_NUNN_TOWN = "05245"
BASIN_TOWN = "05320"
BEAR_RIVER_TOWN = "05625"
BEDFORD_CDP = "06045"
BESSEMER_BEND_CDP = "06407"
BEULAH_CDP = "06480"
BIG_HORN_CDP = "06770"
BIG_PINEY_TOWN = "07060"
BONDURANT_CDP = "08365"
BOULDER_CDP = "09235"
BOULDER_FLATS_CDP = "09307"
BROOKHURST_CDP = "10175"
BUFFALO_CITY = "10685"
BURLINGTON_TOWN = "11120"
BURNS_TOWN = "11265"
BYRON_TOWN = "11700"
CARPENTER_CDP = "12860"
CARTER_CDP = "13005"
CASPER_MOUNTAIN_CDP = "13222"
CASPER_CITY = "13150"
CENTENNIAL_CDP = "13440"
CHEYENNE_CITY = "13900"
CHUGCREEK_CDP = "14097"
CHUGWATER_TOWN = "14165"
CLEARMONT_TOWN = "15325"
CLEARVIEW_ACRES_CDP = "15400"
CODY_CITY = "15760"
COKEVILLE_TOWN = "15905"
CORA_CDP = "17210"
COWLEY_TOWN = "17645"
CROWHEART_CDP = "18225"
DANIEL_CDP = "18950"
DAYTON_TOWN = "19385"
DEAVER_TOWN = "19530"
DIAMONDVILLE_TOWN = "20110"
DIXON_TOWN = "20690"
DOUGLAS_CITY = "21125"
DUBOIS_TOWN = "21415"
EAST_THERMOPOLIS_TOWN = "22720"
EDEN_CDP = "23010"
EDGERTON_TOWN = "23155"
EL_RANCHO_CDP = "24350"
ELK_MOUNTAIN_TOWN = "24025"
ENCAMPMENT_TOWN = "24750"
ESTERBROOK_CDP = "25185"
ETHETE_CDP = "25330"
ETNA_CDP = "25475"
EVANSTON_CITY = "25620"
EVANSVILLE_TOWN = "25765"
FAIRVIEW_CDP = "25910"
FARSON_CDP = "26055"
FONTENELLE_CDP = "27650"
FORT_BRIDGER_CDP = "27940"
FORT_LARAMIE_TOWN = "28230"
FORT_WASHAKIE_CDP = "28665"
FOX_FARM_COLLEGE_CDP = "29300"
FOX_PARK_CDP = "29400"
FRANNIE_TOWN = "29825"
FREEDOM_CDP = "30115"
GARLAND_CDP = "30985"
GILLETTE_CITY = "31855"
GLENDO_TOWN = "32290"
GLENROCK_TOWN = "32435"
GRANGER_TOWN = "32870"
GREEN_RIVER_CITY = "33740"
GREYBULL_TOWN = "33885"
GROVER_CDP = "34030"
GUERNSEY_TOWN = "34320"
HANNA_TOWN = "35335"
HARTRANDT_CDP = "35552"
HARTVILLE_TOWN = "35625"
HAWK_SPRINGS_CDP = "36060"
HILL_VIEW_HEIGHTS_CDP = "37727"
HILLSDALE_CDP = "37510"
HOBACK_CDP = "37945"
HOMA_HILLS_CDP = "38307"
HUDSON_TOWN = "38960"
HULETT_TOWN = "39105"
HUNTLEY_CDP = "39250"
HYATTVILLE_CDP = "39395"
JACKSON_TOWN = "40120"
JAMES_TOWN_CDP = "40265"
JEFFREY_CITY_CDP = "40555"
JOHNSTOWN_CDP = "40945"
KAYCEE_TOWN = "41353"
KELLY_CDP = "41860"
KEMMERER_CITY = "42005"
KIRBY_TOWN = "42730"
LA_BARGE_TOWN = "43455"
LAGRANGE_TOWN = "43745"
LAKEVIEW_NORTH_CDP = "44252"
LANCE_CREEK_CDP = "44615"
LANDER_CITY = "44760"
LARAMIE_CITY = "45050"
LINGLE_TOWN = "46790"
LITTLE_AMERICA_CDP = "46935"
LONETREE_CDP = "47370"
LOST_SPRINGS_TOWN = "47805"
LOVELL_TOWN = "47950"
LUCERNE_CDP = "48240"
LUSK_TOWN = "48530"
LYMAN_TOWN = "48675"
MAMMOTH_CDP = "49775"
MANDERSON_TOWN = "49980"
MANVILLE_TOWN = "50270"
MARBLETON_TOWN = "50415"
MCKINNON_CDP = "49400"
MEADOW_ACRES_CDP = "51285"
MEDICINE_BOW_TOWN = "51575"
MEETEETSE_TOWN = "51720"
MIDWEST_TOWN = "52445"
MILLS_TOWN = "53460"
MOORCROFT_TOWN = "54185"
MOOSE_WILSON_ROAD_CDP = "54402"
MOUNTAIN_VIEW_CDP = "55200"
MOUNTAIN_VIEW_TOWN = "55345"
NEWCASTLE_CITY = "56215"
NORDIC_CDP = "56520"
NORTH_ROCK_SPRINGS_CDP = "56700"
OAKLEY_CDP = "57375"
OPAL_TOWN = "57810"
ORIN_CDP = "58100"
OSAGE_CDP = "58680"
OSMOND_CDP = "58970"
OWL_CREEK_CDP = "59332"
PARKMAN_CDP = "59985"
PAVILLION_TOWN = "60130"
PINE_BLUFFS_TOWN = "61435"
PINE_HAVEN_TOWN = "61610"
PINEDALE_TOWN = "61580"
POINT_OF_ROCKS_CDP = "62160"
POWDER_HORN_CDP = "62269"
POWDER_RIVER_CDP = "62305"
POWELL_CITY = "62450"
PURPLE_SAGE_CDP = "62812"
RAFTER_J_RANCH_CDP = "63100"
RALSTON_CDP = "63465"
RANCHESTER_TOWN = "63755"
RANCHETTES_CDP = "63800"
RAWLINS_CITY = "63900"
RED_BUTTE_CDP = "64400"
RELIANCE_CDP = "65060"
RIVERSIDE_TOWN = "66075"
RIVERTON_CITY = "66220"
ROBERTSON_CDP = "66655"
ROCK_RIVER_TOWN = "67090"
ROCK_SPRINGS_CITY = "67235"
ROLLING_HILLS_TOWN = "67440"
RYAN_PARK_CDP = "67670"
SARATOGA_TOWN = "68685"
SHELL_CDP = "69700"
SHERIDAN_CITY = "69845"
SHOSHONI_TOWN = "70570"
SINCLAIR_TOWN = "71150"
SLATER_CDP = "71295"
SLEEPY_HOLLOW_CDP = "71350"
SMOOT_CDP = "71440"
SOUTH_GREELEY_CDP = "71800"
SOUTH_PARK_CDP = "71947"
STAR_VALLEY_RANCH_TOWN = "73180"
STORY_CDP = "73615"
SUNDANCE_TOWN = "74195"
SUPERIOR_TOWN = "74775"
TABLE_ROCK_CDP = "75355"
TAYLOR_CDP = "75572"
TEN_SLEEP_TOWN = "75790"
TETON_VILLAGE_CDP = "75935"
THAYNE_TOWN = "76370"
THERMOPOLIS_TOWN = "76515"
TORRINGTON_CITY = "77530"
TURNERVILLE_CDP = "78400"
UPTON_TOWN = "79125"
URIE_CDP = "79270"
VAN_TASSELL_TOWN = "79705"
VETERAN_CDP = "80285"
VISTA_WEST_CDP = "80575"
WAMSUTTER_TOWN = "81300"
WARREN_AFB_CDP = "81640"
WASHAM_CDP = "81703"
WESTVIEW_CIRCLE_CDP = "82967"
WHEATLAND_TOWN = "83040"
WHITING_CDP = "83100"
WILSON_CDP = "83765"
WOODS_LANDING_JELM_CDP = "84852"
WORLAND_CITY = "84925"
WRIGHT_TOWN = "85015"
Y_O_RANCH_CDP = "86737"
YODER_TOWN = "86665"
