# Copyright (c) 2023 Darren Erik Vengroff
"""Places in South Dakota."""


ABERDEEN_CITY = "00100"
AGAR_TOWN = "00460"
AGENCY_VILLAGE_CDP = "00520"
AKASKA_TOWN = "00540"
ALBEE_TOWN = "00620"
ALCESTER_CITY = "00700"
ALEXANDRIA_CITY = "00820"
ALLEN_CDP = "00900"
ALPENA_TOWN = "01020"
ALTAMONT_TOWN = "01140"
ANDERSON_CDP = "01450"
ANDOVER_TOWN = "01500"
ANGOSTURA_CDP = "01560"
ANTELOPE_CDP = "01740"
ARDMORE_CDP = "01980"
ARLINGTON_CITY = "02180"
ARMOUR_CITY = "02260"
ARTAS_TOWN = "02340"
ARTESIAN_TOWN = "02380"
ASHLAND_HEIGHTS_CDP = "02530"
ASHTON_CITY = "02540"
ASTORIA_TOWN = "02580"
AURORA_CENTER_CDP = "02860"
AURORA_TOWN = "02780"
AVON_CITY = "02900"
BADGER_TOWN = "03060"
BALTIC_CITY = "03380"
BANCROFT_TOWN = "03420"
BATESLAND_TOWN = "03860"
BATH_CDP = "03900"
BATH_CORNER_CDP = "03960"
BELLE_FOURCHE_CITY = "04380"
BELVIDERE_TOWN = "04620"
BERESFORD_CITY = "04980"
BIG_STONE_CITY_CITY = "05540"
BIJOU_HILLS_CDP = "05580"
BISON_TOWN = "05620"
BLACKHAWK_CDP = "05780"
BLUCKSBERG_MOUNTAIN_CDP = "06120"
BLUMENGARD_COLONY_CDP = "06140"
BLUNT_CITY = "06180"
BON_HOMME_COLONY_CDP = "06300"
BONESTEEL_CITY = "06220"
BOULDER_CANYON_CDP = "06440"
BOWDLE_CITY = "06540"
BOX_ELDER_CITY = "06620"
BRADLEY_TOWN = "06660"
BRANDON_CITY = "06840"
BRANDT_TOWN = "06940"
BRANT_LAKE_SOUTH_CDP = "07044"
BRANT_LAKE_CITY = "07040"
BRENTFORD_TOWN = "07060"
BRENTWOOD_COLONY_CDP = "07068"
BRIDGER_CDP = "07140"
BRIDGEWATER_CITY = "07180"
BRISTOL_CITY = "07300"
BRITTON_CITY = "07380"
BROADLAND_TOWN = "07420"
BROOKINGS_CITY = "07580"
BRUCE_CITY = "07740"
BRYANT_CITY = "08060"
BUFFALO_CHIP_TOWN = "08330"
BUFFALO_GAP_TOWN = "08340"
BUFFALO_TOWN = "08140"
BULLHEAD_CDP = "08460"
BURBANK_CDP = "08500"
BURKE_CITY = "08700"
BUSHNELL_TOWN = "08820"
BUTLER_TOWN = "08860"
CAMERON_COLONY_CDP = "09204"
CAMP_CROOK_TOWN = "09260"
CAMROSE_COLONY_CDP = "09278"
CANISTOTA_CITY = "09300"
CANOVA_TOWN = "09420"
CANTON_CITY = "09500"
CAPUTA_CDP = "09780"
CARTHAGE_CITY = "10220"
CASTLEWOOD_CITY = "10500"
CAVOUR_TOWN = "10620"
CEDAR_GROVE_COLONY_CDP = "10835"
CENTERVILLE_CITY = "11060"
CENTRAL_CITY_CITY = "11140"
CHAMBERLAIN_CITY = "11220"
CHANCELLOR_TOWN = "11380"
CHELSEA_TOWN = "11500"
CHERRY_CREEK_CDP = "11540"
CHESTER_CDP = "11660"
CLAIRE_CITY_TOWN = "12020"
CLAREMONT_COLONY_CDP = "12148"
CLAREMONT_TOWN = "12100"
CLARK_COLONY_CDP = "12340"
CLARK_CITY = "12180"
CLEAR_LAKE_CDP = "12640"
CLEAR_LAKE_CITY = "12540"
CLEARFIELD_COLONY_CDP = "12508"
CLOVERLEAF_COLONY_CDP = "13010"
COLLINS_COLONY_CDP = "13188"
COLMAN_CITY = "13220"
COLOME_CITY = "13300"
COLONIAL_PINE_HILLS_CDP = "13355"
COLTON_CITY = "13380"
COLUMBIA_CITY = "13420"
CONDE_CITY = "13700"
CORN_CREEK_CDP = "13840"
CORONA_TOWN = "13940"
CORSICA_CITY = "13980"
COTTONWOOD_TOWN = "14220"
COW_CREEK_CDP = "14320"
CRESBARD_TOWN = "14580"
CROCKER_CDP = "14660"
CROOK_CITY_CDP = "14680"
CROOKS_CITY = "14740"
CUSTER_CITY = "15140"
DAKOTA_DUNES_CDP = "15256"
DALLAS_TOWN = "15300"
DANTE_TOWN = "15420"
DAVIS_TOWN = "15540"
DE_SMET_CITY = "16260"
DEADWOOD_CITY = "15700"
DEERFIELD_COLONY_CDP = "15774"
DELL_RAPIDS_CITY = "15980"
DELMONT_CITY = "16060"
DIMOCK_TOWN = "16620"
DOLAND_CITY = "16820"
DOLTON_TOWN = "16860"
DRAPER_TOWN = "17020"
DUDLEY_CDP = "17215"
DUPREE_CITY = "17420"
EAGLE_BUTTE_CITY = "17620"
EDEN_TOWN = "18180"
EDGEMONT_CITY = "18300"
EGAN_CITY = "18460"
ELK_POINT_CITY = "18620"
ELKTON_CITY = "18700"
EMERY_CITY = "19420"
ENEMY_SWIM_CDP = "19556"
ERWIN_TOWN = "19860"
ESTELLINE_CITY = "19980"
ETHAN_TOWN = "20060"
EUREKA_CITY = "20180"
EVERGREEN_COLONY_CDP = "20208"
FAIRBURN_TOWN = "20340"
FAIRFAX_TOWN = "20380"
FAIRVIEW_TOWN = "20780"
FAITH_CITY = "20980"
FARMER_TOWN = "21060"
FAULKTON_CITY = "21260"
FEDORA_CDP = "21340"
FERNEY_CDP = "21380"
FLANDREAU_CITY = "21540"
FLORENCE_TOWN = "21820"
FORDHAM_COLONY_CDP = "22070"
FORESTBURG_CDP = "22100"
FORT_PIERRE_CITY = "22260"
FORT_THOMPSON_CDP = "22340"
FRANKFORT_CITY = "22580"
FREDERICK_TOWN = "22860"
FREEMAN_CITY = "23020"
FRUITDALE_TOWN = "23140"
FULTON_TOWN = "23220"
GANN_VALLEY_CDP = "23421"
GARDEN_CITY_TOWN = "23460"
GARRETSON_CITY = "23820"
GARY_CITY = "23860"
GAYVILLE_TOWN = "23900"
GEDDES_CITY = "23980"
GETTYSBURG_CITY = "24260"
GLENDALE_COLONY_CDP = "24540"
GLENHAM_TOWN = "24620"
GOLDEN_VIEW_COLONY_CDP = "24760"
GOODWIN_TOWN = "24820"
GRACEVILLE_COLONY_CDP = "25020"
GRASS_RANCH_COLONY_CDP = "25743"
GRASSLAND_COLONY_CDP = "25741"
GREEN_GRASS_CDP = "25900"
GREEN_VALLEY_CDP = "26035"
GREENWOOD_COLONY_CDP = "26150"
GREGORY_CITY = "26180"
GRENVILLE_TOWN = "26220"
GROTON_CITY = "26340"
HAMILL_CDP = "26660"
HARRISBURG_CITY = "27260"
HARRISON_CDP = "27300"
HARROLD_TOWN = "27420"
HARTFORD_CITY = "27540"
HAYTI_TOWN = "27820"
HAZEL_TOWN = "27940"
HECLA_CITY = "27980"
HENRY_TOWN = "28140"
HERMOSA_TOWN = "28300"
HERREID_CITY = "28340"
HERRICK_TOWN = "28420"
HETLAND_TOWN = "28460"
HIGHMORE_CITY = "28980"
HILL_CITY_CITY = "29100"
HILLCREST_COLONY_CDP = "29116"
HILLSIDE_COLONY_CDP = "29300"
HILLSVIEW_TOWN = "29340"
HITCHCOCK_TOWN = "29500"
HORSE_CREEK_CDP = "30056"
HOSMER_CITY = "30140"
HOT_SPRINGS_CITY = "30220"
HOVEN_TOWN = "30300"
HOWARD_CITY = "30460"
HUDSON_TOWN = "30740"
HUMBOLDT_TOWN = "30900"
HURLEY_CITY = "30980"
HURON_COLONY_CDP = "31140"
HURON_CITY = "31060"
HUTTERVILLE_COLONY_CDP = "31196"
IDEAL_CDP = "31220"
INTERIOR_TOWN = "31620"
IPSWICH_CITY = "31860"
IRENE_CITY = "31940"
IROQUOIS_CITY = "32020"
ISABEL_TOWN = "32140"
JAMESVILLE_COLONY_CDP = "32388"
JAVA_TOWN = "32460"
JEFFERSON_CITY = "32700"
JOHNSON_SIDING_CDP = "32820"
KADOKA_CITY = "33180"
KAYLOR_CDP = "33380"
KENEL_CDP = "33540"
KENNEBEC_TOWN = "33580"
KEYSTONE_TOWN = "33820"
KIDDER_CDP = "33900"
KIMBALL_CITY = "33980"
KRANZBURG_TOWN = "34340"
KYLE_CDP = "34460"
LA_BOLT_TOWN = "34540"
LA_PLANT_CDP = "35940"
LAKE_ANDES_CITY = "35100"
LAKE_CITY_TOWN = "35220"
LAKE_MADISON_CDP = "35430"
LAKE_NORDEN_CITY = "35460"
LAKE_POINSETT_CDP = "35480"
LAKE_PRESTON_CITY = "35500"
LAKEVIEW_COLONY_CDP = "35671"
LANE_TOWN = "35780"
LANGFORD_TOWN = "35820"
LANTRY_CDP = "35900"
LEAD_CITY = "36220"
LEBANON_TOWN = "36260"
LEMMON_CITY = "36340"
LENNOX_CITY = "36380"
LEOLA_CITY = "36460"
LESTERVILLE_TOWN = "36540"
LETCHER_TOWN = "36620"
LITTLE_EAGLE_CDP = "37900"
LONG_HOLLOW_CDP = "38760"
LONG_LAKE_COLONY_CDP = "38900"
LONG_LAKE_TOWN = "38860"
LOOMIS_CDP = "39020"
LOWER_BRULE_CDP = "39180"
LOWRY_TOWN = "39260"
LYONS_CDP = "39740"
MADISON_CITY = "40220"
MANDERSON_WHITE_HORSE_CREEK_CDP = "40550"
MANSFIELD_CDP = "40580"
MARION_CITY = "40860"
MARTIN_CITY = "41100"
MARTY_CDP = "41180"
MARVIN_TOWN = "41220"
MAVERICK_JUNCTION_CDP = "41398"
MAXWELL_COLONY_CDP = "41420"
MAYFIELD_COLONY_CDP = "41548"
MCINTOSH_CITY = "39940"
MCLAUGHLIN_CITY = "40020"
MEADOW_VIEW_ADDITION_CDP = "41680"
MECKLING_CDP = "41700"
MELLETTE_CITY = "41860"
MENNO_CITY = "41980"
MIDLAND_TOWN = "42140"
MILBANK_CITY = "42260"
MILLBROOK_COLONY_CDP = "42440"
MILLER_CITY = "42460"
MILLERDALE_COLONY_CDP = "42579"
MILLTOWN_CDP = "42620"
MINA_CDP = "42700"
MISSION_HILL_TOWN = "42980"
MISSION_CITY = "42940"
MITCHELL_CITY = "43100"
MOBRIDGE_CITY = "43180"
MONROE_TOWN = "43380"
MONTROSE_CITY = "43500"
MORNINGSIDE_CDP = "43780"
MORRISTOWN_TOWN = "43860"
MOUND_CITY_TOWN = "44020"
MOUNT_VERNON_CITY = "44100"
MOUNTAIN_PLAINS_CDP = "44032"
MURDO_CITY = "44260"
NAPLES_TOWN = "44620"
NEW_EFFINGTON_TOWN = "44820"
NEW_ELM_SPRING_COLONY_CDP = "44900"
NEW_HOLLAND_CDP = "44940"
NEW_UNDERWOOD_CITY = "45060"
NEW_WITTEN_TOWN = "45100"
NEWDALE_COLONY_CDP = "44800"
NEWELL_CITY = "44860"
NEWPORT_COLONY_CDP = "45024"
NISLAND_TOWN = "45180"
NORFELD_COLONY_CDP = "45390"
NORRIS_CDP = "45420"
NORTH_EAGLE_BUTTE_CDP = "45548"
NORTH_SIOUX_CITY_CITY = "45700"
NORTH_SPEARFISH_CDP = "45715"
NORTHVILLE_TOWN = "45740"
NUNDA_TOWN = "46060"
OACOMA_TOWN = "46180"
OAHE_ACRES_CDP = "46240"
OAK_LANE_COLONY_CDP = "46388"
OELRICHS_TOWN = "46500"
OGLALA_CDP = "46540"
OKATON_CDP = "46620"
OKREEK_CDP = "46660"
OLA_CDP = "46700"
OLD_ELM_SPRING_COLONY_CDP = "46770"
OLDHAM_CITY = "46780"
OLIVET_TOWN = "46900"
ONAKA_TOWN = "46980"
ONIDA_CITY = "47180"
ORAL_CDP = "47340"
ORIENT_TOWN = "47460"
ORLAND_COLONY_CDP = "47588"
ORTLEY_TOWN = "47660"
PARKER_CITY = "48380"
PARKSTON_CITY = "48460"
PARMELEE_CDP = "48500"
PEARL_CREEK_COLONY_CDP = "48820"
PEEVER_FLATS_CDP = "48948"
PEEVER_TOWN = "48940"
PEMBROOK_COLONY_CDP = "49028"
PHILIP_CITY = "49300"
PICKSTOWN_TOWN = "49460"
PIEDMONT_CITY = "49500"
PIERPONT_TOWN = "49540"
PIERRE_CITY = "49600"
PINE_LAKES_ADDITION_CDP = "49640"
PINE_RIDGE_CDP = "49660"
PLAINVIEW_COLONY_CDP = "49980"
PLANKINTON_CITY = "50020"
PLATTE_COLONY_CDP = "50310"
PLATTE_CITY = "50260"
PLEASANT_VALLEY_COLONY_CDP = "50988"
POINSETT_COLONY_CDP = "51220"
POLLOCK_TOWN = "51260"
PORCUPINE_CDP = "51340"
PRAIRIE_CITY_CDP = "51660"
PRAIRIEWOOD_VILLAGE_CDP = "51724"
PRESHO_CITY = "51820"
PRINGLE_TOWN = "51940"
PROVO_CDP = "52140"
PUKWANA_TOWN = "52220"
QUINN_TOWN = "52500"
RAMONA_TOWN = "52860"
RAPID_CITY_CITY = "52980"
RAPID_VALLEY_CDP = "53007"
RAVINIA_TOWN = "53220"
RAYMOND_TOWN = "53260"
REDFIELD_CITY = "53460"
REE_HEIGHTS_TOWN = "53940"
RELIANCE_TOWN = "54020"
RENNER_CORNER_CDP = "54145"
REVILLO_TOWN = "54220"
RICHLAND_CDP = "54750"
RIVERSIDE_COLONY_CDP = "55220"
ROCKHAM_TOWN = "55540"
ROCKPORT_COLONY_CDP = "55620"
ROLLAND_COLONY_CDP = "55684"
ROSCOE_CITY = "55820"
ROSEBUD_CDP = "55940"
ROSEDALE_COLONY_CDP = "56140"
ROSHOLT_TOWN = "56340"
ROSLYN_TOWN = "56380"
ROSWELL_CDP = "56420"
ROWENA_CDP = "56580"
RUNNING_WATER_CDP = "56820"
RUSTIC_ACRES_COLONY_CDP = "56964"
SALEM_CITY = "57340"
SCOTLAND_CITY = "57940"
SELBY_CITY = "58140"
SENECA_TOWN = "58180"
SHAMROCK_COLONY_CDP = "58310"
SHANNON_COLONY_CDP = "58332"
SHERMAN_TOWN = "58580"
SHINDLER_CDP = "58590"
SICANGU_VILLAGE_CDP = "58680"
SILVER_LAKE_COLONY_CDP = "58868"
SINAI_TOWN = "58900"
SIOUX_FALLS_CITY = "59020"
SISSETON_CITY = "59260"
SMITHWICK_CDP = "59620"
SOLDIER_CREEK_CDP = "59700"
SOUTH_SHORE_TOWN = "59940"
SPEARFISH_CITY = "60020"
SPENCER_CITY = "60060"
SPINK_COLONY_CDP = "60180"
SPRING_CREEK_CDP = "60500"
SPRING_CREEK_COLONY_CDP = "60540"
SPRING_LAKE_COLONY_CDP = "60958"
SPRING_VALLEY_COLONY_CDP = "61180"
SPRINGFIELD_CITY = "60660"
ST_CHARLES_CDP = "57060"
ST_FRANCIS_TOWN = "57140"
ST_LAWRENCE_TOWN = "57180"
ST_ONGE_CDP = "57260"
STEPHAN_CDP = "61580"
STICKNEY_TOWN = "61700"
STOCKHOLM_TOWN = "61740"
STORLA_CDP = "61940"
STRANDBURG_TOWN = "61980"
STRATFORD_TOWN = "62020"
STURGIS_CITY = "62100"
SUMMERSET_CITY = "62155"
SUMMIT_TOWN = "62220"
SUNSET_COLONY_CDP = "62434"
SWIFT_BIRD_CDP = "62716"
TABOR_TOWN = "62820"
TEA_CITY = "63100"
THUNDERBIRD_COLONY_CDP = "63452"
TIMBER_LAKE_CITY = "63620"
TOLSTOY_TOWN = "63700"
TORONTO_TOWN = "63740"
TRENT_TOWN = "63940"
TRIPP_CITY = "64020"
TSCHETTER_COLONY_CDP = "64260"
TULARE_TOWN = "64300"
TURTON_TOWN = "64540"
TWIN_BROOKS_TOWN = "64700"
TWO_STRIKE_CDP = "64840"
TYNDALL_CITY = "64860"
UPLAND_COLONY_CDP = "65628"
UTICA_TOWN = "65780"
VALE_CDP = "65900"
VALLEY_SPRINGS_CITY = "66260"
VEBLEN_CITY = "66540"
VERDON_TOWN = "66660"
VERMILLION_CITY = "66700"
VIBORG_CITY = "67020"
VIENNA_TOWN = "67220"
VILAS_TOWN = "67340"
VIRGIL_TOWN = "67500"
VIVIAN_CDP = "67620"
VOLGA_CITY = "67700"
VOLIN_TOWN = "67780"
WAGNER_CITY = "68020"
WAKONDA_TOWN = "68100"
WAKPALA_CDP = "68140"
WALL_TOWN = "68380"
WALLACE_TOWN = "68420"
WANBLEE_CDP = "68580"
WARD_TOWN = "68660"
WARNER_TOWN = "68740"
WASTA_TOWN = "69140"
WATERTOWN_CITY = "69300"
WAUBAY_CITY = "69340"
WAVERLY_CDP = "69420"
WEBSTER_CITY = "69780"
WENTWORTH_VILLAGE = "70020"
WESSINGTON_SPRINGS_CITY = "70220"
WESSINGTON_CITY = "70140"
WEST_BRULE_CDP = "70284"
WESTPORT_TOWN = "70540"
WESTWOOD_COLONY_CDP = "70646"
WETONKA_TOWN = "70740"
WHITE_HORSE_CDP = "71150"
WHITE_LAKE_CITY = "71180"
WHITE_RIVER_CITY = "71340"
WHITE_ROCK_COLONY_CDP = "71440"
WHITE_ROCK_TOWN = "71380"
WHITE_CITY = "70940"
WHITEHORSE_CDP = "71140"
WHITEWOOD_CITY = "71580"
WILLOW_LAKE_CITY = "71940"
WILMOT_CITY = "71980"
WINFRED_CDP = "72100"
WINNER_CITY = "72180"
WOLF_CREEK_COLONY_CDP = "72500"
WOLSEY_TOWN = "72540"
WONDERLAND_HOMES_CDP = "72590"
WOOD_TOWN = "72620"
WOONSOCKET_CITY = "72700"
WORTHING_CITY = "72820"
WOUNDED_KNEE_CDP = "72900"
YALE_TOWN = "73020"
YANKTON_CITY = "73060"
