# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Indiana."""


ABERDEEN_CDP = "00140"
ABINGTON_CDP = "00154"
ADAMS_CDP = "00352"
ADAMS_LAKE_CDP = "00532"
ADVANCE_TOWN = "00640"
AKRON_TOWN = "00748"
ALAMO_TOWN = "00784"
ALBANY_TOWN = "00802"
ALBION_TOWN = "00820"
ALEXANDRIA_CITY = "00910"
ALFORD_CDP = "00946"
ALFORDSVILLE_TOWN = "00964"
ALTON_TOWN = "01270"
ALTONA_TOWN = "01288"
AMBIA_TOWN = "01342"
AMBOY_TOWN = "01360"
AMERICUS_CDP = "01396"
AMITY_CDP = "01432"
AMO_TOWN = "01450"
ANDERSON_CITY = "01468"
ANDERSONVILLE_CDP = "01594"
ANDREWS_TOWN = "01612"
ANGOLA_CITY = "01666"
ANOKA_CDP = "01738"
ANTIOCH_CDP = "01810"
ARCADIA_TOWN = "01954"
ARCOLA_CDP = "01990"
ARDMORE_CDP = "02026"
ARGOS_TOWN = "02044"
ARLINGTON_CDP = "02116"
ARTHUR_CDP = "02296"
ASHLEY_TOWN = "02458"
ATLANTA_TOWN = "02602"
ATTICA_CITY = "02620"
AUBURN_CITY = "02674"
AURORA_CITY = "02782"
AUSTIN_CITY = "02800"
AVILLA_TOWN = "02872"
AVOCA_CDP = "02890"
AVON_TOWN = "02908"
AZALIA_CDP = "03052"
BAINBRIDGE_TOWN = "03142"
BARBEE_CDP = "03358"
BARGERSVILLE_TOWN = "03394"
BASS_LAKE_CDP = "03610"
BATESVILLE_CITY = "03664"
BATTLE_GROUND_TOWN = "03718"
BEAR_LAKE_CDP = "03898"
BEAVER_DAM_CDP = "04032"
BEDFORD_CITY = "04114"
BEECH_GROVE_CITY = "04204"
BELLEVILLE_CDP = "04456"
BENNETTS_SWITCH_CDP = "04726"
BENTON_CDP = "04780"
BERNE_CITY = "04888"
BETHANY_TOWN = "04978"
BETHEL_VILLAGE_CDP = "05050"
BEVERLY_SHORES_TOWN = "05158"
BICKNELL_CITY = "05176"
BIG_LAKE_CDP = "05230"
BILLTOWN_CDP = "05284"
BIPPUS_CDP = "05338"
BIRDSEYE_TOWN = "05374"
BLAIRSVILLE_CDP = "05644"
BLANFORD_CDP = "05662"
BLOCHER_CDP = "05680"
BLOOMFIELD_TOWN = "05716"
BLOOMING_GROVE_CDP = "05806"
BLOOMINGDALE_TOWN = "05788"
BLOOMINGTON_CITY = "05860"
BLOUNTSVILLE_TOWN = "05896"
BLUE_RIDGE_CDP = "06022"
BLUFFTON_CITY = "06220"
BOGGSTOWN_CDP = "06292"
BOONE_GROVE_CDP = "06598"
BOONVILLE_CITY = "06616"
BORDEN_TOWN = "06634"
BOSTON_TOWN = "06652"
BOSWELL_TOWN = "06706"
BOURBON_TOWN = "06760"
BOWLING_GREEN_CDP = "06832"
BOXLEY_CDP = "06904"
BRAZIL_CITY = "07174"
BREMEN_TOWN = "07318"
BRETZVILLE_CDP = "07426"
BRIDGETON_CDP = "07570"
BRIGHT_CDP = "07624"
BRIMFIELD_CDP = "07678"
BRINGHURST_CDP = "07714"
BRISTOL_TOWN = "07750"
BROOK_TOWN = "07966"
BROOKLYN_TOWN = "08038"
BROOKSBURG_TOWN = "08092"
BROOKSTON_TOWN = "08146"
BROOKVILLE_TOWN = "08182"
BROWNS_CROSSING_CDP = "08434"
BROWNSBURG_TOWN = "08416"
BROWNSTOWN_TOWN = "08470"
BROWNSVILLE_CDP = "08524"
BRUCEVILLE_TOWN = "08578"
BRYANT_TOWN = "08704"
BUCK_CREEK_CDP = "08812"
BUCKSKIN_CDP = "08848"
BUFFALO_CDP = "08992"
BUNKER_HILL_TOWN = "09136"
BURKET_TOWN = "09226"
BURLINGTON_TOWN = "09244"
BURNETT_CDP = "09298"
BURNETTSVILLE_TOWN = "09316"
BURNEY_CDP = "09334"
BURNS_CITY_CDP = "09352"
BURNS_HARBOR_TOWN = "09370"
BURROWS_CDP = "09460"
BUTLER_CITY = "09532"
BUTLERVILLE_CDP = "09622"
CADIZ_TOWN = "09712"
CAMBRIDGE_CITY_TOWN = "09874"
CAMDEN_TOWN = "09910"
CAMPBELLSBURG_TOWN = "10000"
CANAAN_CDP = "10036"
CANNELBURG_TOWN = "10090"
CANNELTON_CITY = "10108"
CANTON_CDP = "10144"
CARBON_TOWN = "10198"
CARLISLE_TOWN = "10270"
CARMEL_CITY = "10342"
CARROLLTON_CDP = "10558"
CARTERSBURG_CDP = "10594"
CARTHAGE_TOWN = "10612"
CASS_CDP = "10774"
CASSVILLE_CDP = "10828"
CATES_CDP = "10900"
CAYUGA_TOWN = "10954"
CEDAR_GROVE_TOWN = "11044"
CEDAR_LAKE_TOWN = "11062"
CELESTINE_CDP = "11134"
CENTENARY_CDP = "11188"
CENTER_CDP = "11404"
CENTER_POINT_TOWN = "11746"
CENTERTON_CDP = "11782"
CENTERVILLE_TOWN = "11836"
CHAIN_O_LAKES_CDP = "11926"
CHALMERS_TOWN = "11944"
CHANDLER_TOWN = "12034"
CHARLESTOWN_CITY = "12124"
CHARLOTTESVILLE_CDP = "12196"
CHESTERFIELD_TOWN = "12376"
CHESTERTON_TOWN = "12412"
CHILI_CDP = "12502"
CHRISNEY_TOWN = "12574"
CHURUBUSCO_TOWN = "12610"
CICERO_TOWN = "12628"
CLARKS_HILL_TOWN = "12898"
CLARKSBURG_CDP = "12880"
CLARKSVILLE_TOWN = "12934"
CLAY_CITY_TOWN = "13276"
CLAYPOOL_TOWN = "13312"
CLAYTON_TOWN = "13366"
CLEAR_LAKE_TOWN = "13438"
CLERMONT_TOWN = "13492"
CLIFFORD_TOWN = "13582"
CLINTON_CITY = "13780"
CLOVERDALE_TOWN = "13852"
CLOVERLAND_CDP = "13888"
COAL_CITY_CDP = "13978"
COALMONT_CDP = "14032"
COATESVILLE_TOWN = "14050"
COESSE_CDP = "14104"
COLBURN_CDP = "14176"
COLFAX_TOWN = "14284"
COLUMBIA_CITY_CITY = "14716"
COLUMBUS_CITY = "14734"
COMMISKEY_CDP = "14788"
CONNERSVILLE_CITY = "14932"
CONVERSE_TOWN = "14986"
CORDRY_SWEETWATER_LAKES_CDP = "15115"
CORTLAND_CDP = "15202"
CORUNNA_TOWN = "15220"
CORY_CDP = "15238"
CORYDON_TOWN = "15256"
COUNTRY_CLUB_HEIGHTS_TOWN = "15364"
COUNTRY_SQUIRE_LAKES_CDP = "15409"
COVINGTON_CITY = "15490"
COWAN_CDP = "15526"
CRAIGVILLE_CDP = "15616"
CRANDALL_TOWN = "15634"
CRANE_TOWN = "15652"
CRAWFORDSVILLE_CITY = "15742"
CREE_LAKE_CDP = "15778"
CROMWELL_TOWN = "15994"
CROSS_PLAINS_CDP = "16030"
CROTHERSVILLE_TOWN = "16084"
CROWN_POINT_CITY = "16138"
CROWS_NEST_TOWN = "16156"
CULVER_TOWN = "16300"
CUMBERLAND_TOWN = "16336"
CUTLER_CDP = "16480"
CYNTHIANA_TOWN = "16534"
DALE_TOWN = "16624"
DALEVILLE_TOWN = "16642"
DANA_TOWN = "16732"
DANVILLE_TOWN = "16804"
DARLINGTON_TOWN = "16840"
DARMSTADT_TOWN = "16858"
DAYTON_TOWN = "17002"
DE_MOTTE_TOWN = "17722"
DECATUR_CITY = "17074"
DECKER_TOWN = "17110"
DEER_CREEK_CDP = "17245"
DELAWARE_CDP = "17506"
DELPHI_CITY = "17614"
DENVER_TOWN = "17776"
DEPAUW_CDP = "17794"
DEPUTY_CDP = "17812"
DILLSBORO_TOWN = "18190"
DONALDSON_CDP = "18388"
DOVER_HILL_CDP = "18550"
DRESSER_CDP = "18658"
DUBLIN_TOWN = "18766"
DUBOIS_CDP = "18784"
DUGGER_TOWN = "18892"
DUNE_ACRES_TOWN = "18982"
DUNELAND_BEACH_CDP = "19000"
DUNKIRK_CITY = "19054"
DUNLAP_CDP = "19072"
DUNREITH_TOWN = "19162"
DUPONT_TOWN = "19180"
DYER_TOWN = "19270"
EARL_PARK_TOWN = "19450"
EAST_CHICAGO_CITY = "19486"
EAST_ENTERPRISE_CDP = "19576"
EAST_GERMANTOWN_TOWN = "19756"
EAST_OOLITIC_CDP = "19936"
EATON_TOWN = "20080"
ECKERTY_CDP = "20134"
ECONOMY_TOWN = "20152"
EDEN_CDP = "20188"
EDGEWOOD_TOWN = "20332"
EDINBURGH_TOWN = "20404"
EDWARDSPORT_TOWN = "20458"
ELBERFELD_TOWN = "20638"
ELIZABETH_TOWN = "20674"
ELIZABETHTOWN_TOWN = "20692"
ELIZAVILLE_CDP = "20710"
ELKHART_CITY = "20728"
ELLETTSVILLE_TOWN = "20800"
ELNORA_TOWN = "20998"
ELROD_CDP = "21034"
ELWOOD_CITY = "21070"
EMINENCE_CDP = "21106"
EMISON_CDP = "21124"
ENCHANTED_HILLS_CDP = "21178"
ENGLISH_TOWN = "21214"
ETNA_GREEN_TOWN = "21502"
EUGENE_CDP = "21538"
EVANSVILLE_CITY = "22000"
EVERTON_CDP = "22072"
FAIR_OAKS_CDP = "22468"
FAIRBANKS_CDP = "22180"
FAIRLAND_TOWN = "22396"
FAIRMOUNT_TOWN = "22432"
FAIRVIEW_CDP = "22540"
FAIRVIEW_PARK_TOWN = "22576"
FARMERSBURG_TOWN = "22738"
FARMLAND_TOWN = "22792"
FERDINAND_TOWN = "22990"
FILLMORE_TOWN = "23188"
FISH_LAKE_CDP = "23386"
FISHERS_CITY = "23278"
FISHERSBURG_CDP = "23296"
FLAT_ROCK_CDP = "23566"
FLORA_TOWN = "23692"
FLORENCE_CDP = "23728"
FLOYDS_KNOBS_CDP = "23800"
FOLSOMVILLE_CDP = "23836"
FONTANET_CDP = "23854"
FOREST_CDP = "23926"
FORT_BRANCH_TOWN = "24250"
FORT_WAYNE_CITY = "25000"
FORTVILLE_TOWN = "24286"
FOSTER_CDP = "25054"
FOUNTAIN_CITY_TOWN = "25090"
FOUNTAINTOWN_CDP = "25162"
FOWLER_TOWN = "25180"
FOWLERTON_TOWN = "25198"
FOXCLIFF_ESTATES_CDP = "25212"
FRANCESVILLE_TOWN = "25288"
FRANCISCO_TOWN = "25306"
FRANKFORT_CITY = "25324"
FRANKLIN_CITY = "25450"
FRANKTON_TOWN = "25702"
FREDERICKSBURG_CDP = "25720"
FREELANDVILLE_CDP = "25810"
FREETOWN_CDP = "25864"
FREMONT_TOWN = "25882"
FRENCH_LICK_TOWN = "25972"
FULTON_TOWN = "26152"
GALENA_CDP = "26206"
GALVESTON_TOWN = "26242"
GARRETT_CITY = "26386"
GARY_CITY = "27000"
GAS_CITY_CITY = "27054"
GASTON_TOWN = "27072"
GENEVA_CDP = "27252"
GENEVA_TOWN = "27216"
GENTRYVILLE_TOWN = "27270"
GEORGETOWN_TOWN = "27324"
GILMER_PARK_CDP = "27720"
GLENWOOD_TOWN = "28062"
GLEZEN_CDP = "28116"
GOLDSMITH_CDP = "28296"
GOODLAND_TOWN = "28332"
GOSHEN_CITY = "28386"
GOSPORT_TOWN = "28440"
GRABILL_TOWN = "28494"
GRAMMER_CDP = "28620"
GRANDVIEW_LAKE_CDP = "28728"
GRANDVIEW_TOWN = "28692"
GRANGER_CDP = "28800"
GRANTSBURG_CDP = "28908"
GRAYFORD_CDP = "29070"
GRAYSVILLE_CDP = "29106"
GREEN_HILL_CDP = "29592"
GREENCASTLE_CITY = "29358"
GREENDALE_CITY = "29448"
GREENFIELD_CITY = "29520"
GREENS_FORK_TOWN = "29754"
GREENSBORO_TOWN = "29682"
GREENSBURG_CITY = "29718"
GREENTOWN_TOWN = "29772"
GREENVILLE_TOWN = "29844"
GREENWOOD_CITY = "29898"
GRIFFIN_TOWN = "30024"
GRIFFITH_TOWN = "30042"
GRISSOM_AFB_CDP = "30060"
GROVELAND_CDP = "30114"
GROVERTON_CDP = "30150"
GWYNNEVILLE_CDP = "30294"
HAGERSTOWN_TOWN = "30402"
HAMBURG_CDP = "30564"
HAMILTON_TOWN = "30594"
HAMLET_TOWN = "30708"
HAMMOND_CITY = "31000"
HANNA_CDP = "31180"
HANOVER_TOWN = "31216"
HARDINSBURG_TOWN = "31396"
HARLAN_CDP = "31432"
HARMONY_TOWN = "31486"
HARRISON_LAKE_CDP = "32098"
HARRODSBURG_CDP = "32170"
HARTFORD_CITY_CITY = "32242"
HARTSVILLE_TOWN = "32332"
HARTZ_LAKE_CDP = "32768"
HASHTOWN_CDP = "32422"
HATFIELD_CDP = "32494"
HAUBSTADT_TOWN = "32512"
HAYDEN_CDP = "32584"
HAYSVILLE_CDP = "32638"
HAZLETON_TOWN = "32728"
HEBRON_TOWN = "32818"
HEDRICK_CDP = "32854"
HELMER_CDP = "32926"
HELMSBURG_CDP = "32944"
HELTONVILLE_CDP = "32980"
HEMLOCK_CDP = "32998"
HENRYVILLE_CDP = "33142"
HERBST_CDP = "33178"
HERITAGE_LAKE_CDP = "33187"
HESSEN_CASSEL_CDP = "33214"
HIDDEN_VALLEY_CDP = "33392"
HIGHLAND_CDP = "33484"
HIGHLAND_TOWN = "33466"
HILLISBURG_CDP = "33826"
HILLSBORO_TOWN = "33862"
HILLSDALE_CDP = "33952"
HOAGLAND_CDP = "34096"
HOBART_CITY = "34114"
HOBBS_CDP = "34168"
HOFFMAN_LAKE_CDP = "34186"
HOLIDAY_WOODS_CDP = "34284"
HOLLAND_TOWN = "34294"
HOLTON_TOWN = "34366"
HOMECROFT_TOWN = "34420"
HOMER_CDP = "34456"
HOPE_TOWN = "34744"
HORTONVILLE_CDP = "34816"
HOWE_CDP = "34978"
HUDSON_LAKE_CDP = "35104"
HUDSON_TOWN = "35086"
HUNTERTOWN_TOWN = "35266"
HUNTINGBURG_CITY = "35284"
HUNTINGTON_CITY = "35302"
HURON_CDP = "35392"
HYMERA_TOWN = "35500"
IDAVILLE_CDP = "35536"
INDEPENDENCE_CDP = "35626"
INDIAN_VILLAGE_TOWN = "36306"
INDIANAPOLIS_CITY_BALANCE = "36003"
INGALLS_TOWN = "36342"
IRELAND_CDP = "36468"
JALAPA_CDP = "37674"
JAMESTOWN_TOWN = "37692"
JASONVILLE_CITY = "37764"
JASPER_CITY = "37782"
JEFFERSON_CDP = "37908"
JEFFERSONVILLE_CITY = "38358"
JEROME_CDP = "38484"
JIMMERSON_LAKE_CDP = "38547"
JOHNSON_CDP = "38664"
JONESBORO_CITY = "38862"
JONESVILLE_TOWN = "38916"
JUDAH_CDP = "39042"
JUDSON_CDP = "39078"
JUDYVILLE_CDP = "39096"
KEMPTON_TOWN = "39366"
KENDALLVILLE_CITY = "39402"
KENNARD_TOWN = "39438"
KENT_CDP = "39510"
KENTLAND_TOWN = "39546"
KEWANNA_TOWN = "39618"
KEYSTONE_CDP = "39654"
KIMMELL_CDP = "39744"
KINGMAN_TOWN = "39798"
KINGSBURY_TOWN = "39816"
KINGSFORD_HEIGHTS_TOWN = "39852"
KIRKLIN_TOWN = "39942"
KNIGHTSTOWN_TOWN = "40266"
KNIGHTSVILLE_TOWN = "40302"
KNOX_CITY = "40374"
KOKOMO_CITY = "40392"
KOONTZ_LAKE_CDP = "40464"
KOUTS_TOWN = "40518"
KRAMER_CDP = "40536"
LA_CROSSE_TOWN = "40662"
LA_FONTAINE_TOWN = "40842"
LA_PAZ_TOWN = "42192"
LA_PORTE_CITY = "42246"
LACONIA_TOWN = "40644"
LADOGA_TOWN = "40698"
LAFAYETTE_CITY = "40788"
LAGRANGE_TOWN = "40860"
LAGRO_TOWN = "40896"
LAKE_BRUCE_CDP = "41004"
LAKE_CICOTT_CDP = "41022"
LAKE_DALECARLIA_CDP = "41058"
LAKE_ELIZA_CDP = "41112"
LAKE_EVERETT_CDP = "41130"
LAKE_HOLIDAY_CDP = "41211"
LAKE_HOLIDAY_HIDEAWAY_CDP = "41215"
LAKE_SANTEE_CDP = "41444"
LAKE_STATION_CITY = "41535"
LAKE_VIEW_CDP = "41580"
LAKE_VILLAGE_CDP = "41652"
LAKE_OF_THE_WOODS_CDP = "41400"
LAKES_OF_THE_FOUR_SEASONS_CDP = "41530"
LAKESHORE_RESORT_CDP = "41463"
LAKETON_CDP = "41562"
LAKEVILLE_TOWN = "41670"
LAKEWOOD_CDP = "41706"
LAMB_CDP = "41796"
LANDESS_CDP = "41994"
LANESVILLE_TOWN = "42048"
LAOTTO_CDP = "42138"
LAPEL_TOWN = "42228"
LARWILL_TOWN = "42282"
LAUD_CDP = "42318"
LAUREL_TOWN = "42372"
LAWRENCE_CITY = "42426"
LAWRENCEBURG_CITY = "42462"
LAWRENCEPORT_CDP = "42516"
LEAVENWORTH_TOWN = "42606"
LEBANON_CITY = "42624"
LEESBURG_TOWN = "42678"
LEITERS_FORD_CDP = "42822"
LEO_CEDARVILLE_TOWN = "42861"
LEOPOLD_CDP = "42876"
LETTS_CDP = "42984"
LEWIS_CDP = "43020"
LEWISVILLE_TOWN = "43074"
LIBERTY_CENTER_CDP = "43542"
LIBERTY_MILLS_CDP = "43596"
LIBERTY_TOWN = "43434"
LIBERTYVILLE_CDP = "43632"
LIGONIER_CITY = "43686"
LINCOLN_CDP = "43776"
LINDEN_TOWN = "44082"
LINN_GROVE_CDP = "44154"
LINNSBURG_CDP = "44172"
LINTON_CITY = "44190"
LITTLE_YORK_TOWN = "44370"
LIVONIA_TOWN = "44424"
LIZTON_TOWN = "44442"
LOGANSPORT_CITY = "44658"
LONDON_CDP = "44712"
LONG_BEACH_TOWN = "44784"
LOOGOOTEE_CITY = "44910"
LOSANTVILLE_TOWN = "45000"
LOWELL_TOWN = "45144"
LUCERNE_CDP = "45234"
LYFORD_CDP = "45396"
LYNN_TOWN = "45468"
LYNNVILLE_TOWN = "45486"
LYONS_TOWN = "45504"
MACE_CDP = "45720"
MACKEY_TOWN = "45774"
MACY_TOWN = "45864"
MADISON_CITY = "45990"
MALDEN_CDP = "46296"
MANILLA_CDP = "46422"
MAPLES_CDP = "46566"
MARENGO_TOWN = "46746"
MARIAH_HILL_CDP = "46764"
MARIETTA_CDP = "46782"
MARION_CDP = "47045"
MARION_CITY = "46908"
MARKLE_TOWN = "47160"
MARKLEVILLE_TOWN = "47178"
MARSHALL_TOWN = "47322"
MARSHFIELD_CDP = "47340"
MARTINSBURG_CDP = "47430"
MARTINSVILLE_CITY = "47448"
MATTHEWS_TOWN = "47592"
MAUCKPORT_TOWN = "47628"
MAXWELL_CDP = "47736"
MAYS_CDP = "47826"
MCCORDSVILLE_TOWN = "45648"
MECCA_TOWN = "48132"
MEDARYVILLE_TOWN = "48186"
MEDORA_TOWN = "48240"
MELLOTT_TOWN = "48294"
MELODY_HILL_CDP = "48330"
MEMPHIS_CDP = "48384"
MENTONE_TOWN = "48402"
MERIDIAN_HILLS_TOWN = "48456"
MEROM_TOWN = "48474"
MERRIAM_CDP = "48510"
MERRILLVILLE_TOWN = "48528"
METAMORA_CDP = "48563"
METZ_CDP = "48618"
MEXICO_CDP = "48636"
MIAMI_CDP = "48672"
MICHIANA_SHORES_TOWN = "48744"
MICHIGAN_CITY_CITY = "48798"
MICHIGANTOWN_TOWN = "48816"
MIDDLEBURY_CDP = "48906"
MIDDLEBURY_TOWN = "48924"
MIDDLETOWN_TOWN = "49014"
MIDLAND_CDP = "49086"
MIER_CDP = "49212"
MILAN_TOWN = "49266"
MILFORD_CDP = "49302"
MILFORD_TOWN = "49320"
MILLERSBURG_TOWN = "49536"
MILLGROVE_CDP = "49626"
MILLHOUSEN_TOWN = "49662"
MILLTOWN_TOWN = "49716"
MILLVILLE_CDP = "49734"
MILROY_CDP = "49806"
MILTON_TOWN = "49860"
MINERAL_SPRINGS_CDP = "49892"
MISHAWAKA_CITY = "49932"
MITCHELL_CITY = "49950"
MODOC_TOWN = "50058"
MONGO_CDP = "50094"
MONON_TOWN = "50148"
MONROE_CITY_TOWN = "50526"
MONROE_TOWN = "50202"
MONROEVILLE_TOWN = "50562"
MONROVIA_TOWN = "50580"
MONTEREY_TOWN = "50616"
MONTEZUMA_TOWN = "50652"
MONTGOMERY_TOWN = "50688"
MONTICELLO_CITY = "50760"
MONTMORENCI_CDP = "50778"
MONTPELIER_CITY = "50796"
MOORELAND_TOWN = "50940"
MOORES_HILL_TOWN = "50958"
MOORESVILLE_TOWN = "50976"
MORGANTOWN_TOWN = "51102"
MOROCCO_TOWN = "51138"
MORRIS_CDP = "51174"
MORRISTOWN_TOWN = "51192"
MOUNT_AUBURN_TOWN = "51318"
MOUNT_AYR_TOWN = "51336"
MOUNT_CARMEL_TOWN = "51354"
MOUNT_ETNA_TOWN = "51408"
MOUNT_SUMMIT_TOWN = "51714"
MOUNT_VERNON_CITY = "51732"
MULBERRY_TOWN = "51840"
MUNCIE_CITY = "51876"
MUNSTER_TOWN = "51912"
NAPOLEON_TOWN = "52002"
NAPPANEE_CITY = "52020"
NASHVILLE_TOWN = "52038"
NEEDHAM_CDP = "52146"
NEEDMORE_CDP = "52200"
NEW_ALBANY_CITY = "52326"
NEW_AMSTERDAM_TOWN = "52398"
NEW_CARLISLE_TOWN = "52704"
NEW_CASTLE_CITY = "52740"
NEW_CHICAGO_TOWN = "52776"
NEW_GOSHEN_CDP = "52956"
NEW_HARMONY_TOWN = "52974"
NEW_HAVEN_CITY = "52992"
NEW_LEBANON_CDP = "53118"
NEW_LISBON_CDP = "53154"
NEW_LONDON_CDP = "53190"
NEW_MARION_CDP = "53226"
NEW_MARKET_TOWN = "53262"
NEW_MIDDLETOWN_TOWN = "53298"
NEW_PALESTINE_TOWN = "53352"
NEW_PARIS_CDP = "53370"
NEW_PEKIN_TOWN = "53388"
NEW_POINT_TOWN = "53478"
NEW_RICHMOND_TOWN = "53532"
NEW_ROSS_TOWN = "53550"
NEW_SALISBURY_CDP = "53586"
NEW_TRENTON_CDP = "53712"
NEW_WASHINGTON_CDP = "53820"
NEW_WHITELAND_TOWN = "53874"
NEWBERN_CDP = "52506"
NEWBERRY_TOWN = "52524"
NEWBURGH_TOWN = "52650"
NEWPORT_TOWN = "53496"
NEWTONVILLE_CDP = "53676"
NEWTOWN_TOWN = "53694"
NINEVEH_CDP = "53982"
NOBLESVILLE_CITY = "54180"
NORTH_CROWS_NEST_TOWN = "54612"
NORTH_GROVE_CDP = "54792"
NORTH_JUDSON_TOWN = "54900"
NORTH_LIBERTY_TOWN = "54918"
NORTH_MANCHESTER_TOWN = "54954"
NORTH_SALEM_TOWN = "55080"
NORTH_TERRE_HAUTE_CDP = "55098"
NORTH_VERNON_CITY = "55116"
NORTH_WEBSTER_TOWN = "55134"
NORWAY_CDP = "55350"
NOTRE_DAME_CDP = "55386"
NYONA_LAKE_CDP = "55512"
OAKLAND_CITY_CITY = "55710"
OAKTOWN_TOWN = "55800"
OAKVILLE_CDP = "55818"
ODON_TOWN = "56052"
OGDEN_DUNES_TOWN = "56088"
OLDENBURG_TOWN = "56286"
ONTARIO_CDP = "56646"
ONWARD_TOWN = "56664"
OOLITIC_TOWN = "56682"
ORA_CDP = "56700"
ORESTES_TOWN = "56952"
ORLAND_TOWN = "57006"
ORLEANS_TOWN = "57024"
OSCEOLA_TOWN = "57114"
OSGOOD_TOWN = "57132"
OSSIAN_TOWN = "57168"
OSWEGO_CDP = "57186"
OTISCO_CDP = "57222"
OTTER_LAKE_CDP = "57330"
OTTERBEIN_TOWN = "57258"
OTWELL_CDP = "57384"
OWENSBURG_CDP = "57510"
OWENSVILLE_TOWN = "57528"
OXFORD_TOWN = "57546"
PAINTED_HILLS_CDP = "57632"
PALESTINE_CDP = "57672"
PALMYRA_TOWN = "57726"
PAOLI_TOWN = "57780"
PARAGON_TOWN = "57870"
PARIS_CROSSING_CDP = "57924"
PARKER_CITY_TOWN = "57978"
PARKERS_SETTLEMENT_CDP = "58050"
PATOKA_TOWN = "58320"
PATRICKSBURG_CDP = "58374"
PATRIOT_TOWN = "58392"
PAXTON_CDP = "58500"
PENCE_CDP = "58644"
PENDLETON_TOWN = "58662"
PENNTOWN_CDP = "58770"
PENNVILLE_TOWN = "58788"
PEPPERTOWN_CDP = "58878"
PERKINSVILLE_CDP = "58932"
PERRYSVILLE_TOWN = "59238"
PERU_CITY = "59328"
PETERSBURG_CITY = "59364"
PETERSVILLE_CDP = "59400"
PETROLEUM_CDP = "59418"
PHILADELPHIA_CDP = "59490"
PIERCETON_TOWN = "59598"
PIERCEVILLE_CDP = "59616"
PINE_VILLAGE_TOWN = "60084"
PITTSBORO_TOWN = "60192"
PITTSBURG_CDP = "60210"
PLAINFIELD_TOWN = "60246"
PLAINVILLE_TOWN = "60264"
PLEASANT_LAKE_CDP = "60534"
PLEASANT_MILLS_CDP = "60552"
PLEASANT_VIEW_CDP = "60678"
PLEASANT_VIEW_VILLAGE_CDP = "60696"
PLEASANTVILLE_CDP = "60732"
PLYMOUTH_CITY = "60822"
POINT_ISABEL_CDP = "60894"
POLAND_CDP = "60912"
PONETO_TOWN = "61020"
PORTAGE_CITY = "61092"
PORTER_TOWN = "61164"
PORTLAND_CITY = "61236"
POSEYVILLE_TOWN = "61416"
POTTAWATTAMIE_PARK_TOWN = "61470"
PRAIRIE_CREEK_CDP = "61686"
PRAIRIETON_CDP = "61758"
PREBLE_CDP = "61866"
PRINCES_LAKES_TOWN = "62028"
PRINCETON_CITY = "62046"
PROSPECT_CDP = "62154"
PULASKI_CDP = "62280"
PUTNAMVILLE_CDP = "62406"
RAGLESVILLE_CDP = "62712"
RAGSDALE_CDP = "62730"
RAINSVILLE_CDP = "62856"
RAMSEY_CDP = "62892"
RAUB_CDP = "63072"
REDDINGTON_CDP = "63432"
REDKEY_TOWN = "63450"
REMINGTON_TOWN = "63756"
RENSSELAER_CITY = "63792"
REO_CDP = "63810"
REYNOLDS_TOWN = "63918"
RICHLAND_TOWN = "64206"
RICHMOND_CITY = "64260"
RIDGEVILLE_TOWN = "64422"
RILEY_TOWN = "64512"
RISING_SUN_CITY = "64674"
RIVER_FOREST_TOWN = "64728"
RIVERWOOD_CDP = "64944"
ROACHDALE_TOWN = "64980"
ROANN_TOWN = "64998"
ROANOKE_TOWN = "65016"
ROB_ROY_CDP = "65178"
ROCHESTER_CITY = "65214"
ROCKFIELD_CDP = "65358"
ROCKFORD_CDP = "65376"
ROCKPORT_CITY = "65484"
ROCKVILLE_TOWN = "65520"
ROCKY_RIPPLE_TOWN = "65556"
ROLL_CDP = "65592"
ROLLING_PRAIRIE_CDP = "65736"
ROME_CITY_TOWN = "65808"
ROMNEY_CDP = "65826"
ROSEDALE_TOWN = "65934"
ROSELAND_TOWN = "65988"
ROSELAWN_CDP = "66006"
ROSSVILLE_TOWN = "66150"
ROYAL_CENTER_TOWN = "66222"
ROYERTON_CDP = "66312"
RUSHVILLE_CITY = "66438"
RUSSELLVILLE_TOWN = "66510"
RUSSIAVILLE_TOWN = "66546"
SALAMONIA_TOWN = "67302"
SALEM_CITY = "67464"
SALINE_CITY_CDP = "67518"
SALT_CREEK_COMMONS_CDP = "67608"
SALTILLO_TOWN = "67626"
SAN_PIERRE_CDP = "68004"
SANDBORN_TOWN = "67698"
SANDUSKY_CDP = "67896"
SANTA_CLAUS_TOWN = "68022"
SARATOGA_TOWN = "68058"
SARDINIA_CDP = "68076"
SAUGANY_LAKE_CDP = "68103"
SCHAEFER_LAKE_CDP = "68202"
SCHERERVILLE_TOWN = "68220"
SCHNEIDER_TOWN = "68238"
SCHNELLVILLE_CDP = "68256"
SCIPIO_CDP = "68328"
SCIRCLEVILLE_CDP = "68364"
SCOTLAND_CDP = "68382"
SCOTT_CDP = "68418"
SCOTTSBURG_CITY = "68526"
SEELYVILLE_TOWN = "68652"
SELLERSBURG_TOWN = "68670"
SELMA_TOWN = "68706"
SERVIA_CDP = "68742"
SEYMOUR_CITY = "68832"
SHADELAND_TOWN = "68868"
SHAMROCK_LAKES_TOWN = "68976"
SHARPSVILLE_TOWN = "69048"
SHELBURN_TOWN = "69192"
SHELBY_CDP = "69246"
SHELBYVILLE_CITY = "69318"
SHEPARDSVILLE_CDP = "69336"
SHERIDAN_TOWN = "69354"
SHIPSHEWANA_LAKE_CDP = "69489"
SHIPSHEWANA_TOWN = "69480"
SHIRLEY_TOWN = "69516"
SHOALS_TOWN = "69552"
SHOREWOOD_FOREST_CDP = "69642"
SIDNEY_TOWN = "69678"
SILVER_LAKE_TOWN = "69768"
SIMONTON_LAKE_CDP = "69840"
SIMS_CDP = "69894"
SMITHVILLE_SANDERS_CDP = "70330"
SNOW_LAKE_CDP = "70470"
SOLSBERRY_CDP = "70506"
SOMERSET_CDP = "70524"
SOMERVILLE_TOWN = "70542"
SOUTH_BEND_CITY = "71000"
SOUTH_CENTER_CDP = "71072"
SOUTH_HAVEN_CDP = "71288"
SOUTH_MILFORD_CDP = "71396"
SOUTH_WHITLEY_TOWN = "71612"
SOUTHPORT_CITY = "71486"
SPARTANBURG_CDP = "71774"
SPEEDWAY_TOWN = "71828"
SPENCER_TOWN = "71972"
SPENCERVILLE_CDP = "71990"
SPICELAND_TOWN = "72008"
SPRING_GROVE_TOWN = "72206"
SPRING_HILL_TOWN = "72232"
SPRING_LAKE_TOWN = "72296"
SPRINGPORT_TOWN = "72332"
SPURGEON_TOWN = "72440"
ST_ANTHONY_CDP = "66744"
ST_BERNICE_CDP = "66762"
ST_JOE_TOWN = "66834"
ST_JOHN_TOWN = "66852"
ST_LEON_TOWN = "66978"
ST_MARY_OF_THE_WOODS_CDP = "67050"
ST_MEINRAD_CDP = "67176"
ST_OMER_CDP = "67194"
ST_PAUL_TOWN = "67212"
ST_WENDEL_CDP = "67284"
STANFORD_CDP = "72584"
STAR_CITY_CDP = "72638"
STATE_LINE_CITY_TOWN = "72764"
STAUNTON_TOWN = "72782"
STENDAL_CDP = "72980"
STEWARTSVILLE_CDP = "73160"
STILESVILLE_TOWN = "73178"
STILLWELL_CDP = "73214"
STINESVILLE_TOWN = "73232"
STOCKWELL_CDP = "73340"
STONE_BLUFF_CDP = "73376"
STRAUGHN_TOWN = "73664"
STROH_CDP = "73790"
SULLIVAN_CITY = "74006"
SULPHUR_SPRINGS_TOWN = "74060"
SUMAVA_RESORTS_CDP = "74078"
SUMMITVILLE_TOWN = "74132"
SUNMAN_TOWN = "74168"
SWAYZEE_TOWN = "74510"
SWEETSER_TOWN = "74546"
SWITZ_CITY_TOWN = "74582"
SYRACUSE_TOWN = "74744"
TAB_CDP = "74780"
TALMA_CDP = "74870"
TASWELL_CDP = "74978"
TAYLORSVILLE_CDP = "75104"
TECUMSEH_CDP = "75176"
TEEGARDEN_CDP = "75194"
TELL_CITY_CITY = "75248"
TEMPLETON_CDP = "75284"
TENNYSON_TOWN = "75302"
TERRE_HAUTE_CITY = "75428"
THAYER_CDP = "75518"
THORNTOWN_TOWN = "75626"
TIPPECANOE_CDP = "75860"
TIPTON_CITY = "75986"
TOAD_HOP_CDP = "76022"
TOCSIN_CDP = "76076"
TOPEKA_TOWN = "76184"
TOWN_OF_PINES_TOWN = "76256"
TRAFALGAR_TOWN = "76310"
TRAIL_CREEK_TOWN = "76328"
TRI_LAKES_CDP = "76526"
TROY_TOWN = "76634"
TUNNELTON_CDP = "76742"
TWELVE_MILE_CDP = "76886"
TYNER_CDP = "77030"
ULEN_TOWN = "77066"
UNDERWOOD_CDP = "77084"
UNION_CITY_CITY = "77768"
UNION_MILLS_CDP = "77804"
UNIONDALE_TOWN = "77786"
UNIVERSAL_TOWN = "77912"
UPLAND_TOWN = "77966"
URBANA_CDP = "78056"
UTICA_TOWN = "78110"
VALLONIA_CDP = "78290"
VALPARAISO_CITY = "78326"
VAN_BIBBER_LAKE_CDP = "78380"
VAN_BUREN_TOWN = "78470"
VEEDERSBURG_TOWN = "78740"
VELPEN_CDP = "78758"
VERA_CRUZ_TOWN = "78776"
VERNON_TOWN = "78902"
VERSAILLES_TOWN = "78974"
VEVAY_TOWN = "79010"
VICKSBURG_CDP = "79028"
VINCENNES_CITY = "79208"
VISTULA_CDP = "79226"
WABASH_CITY = "79370"
WADESVILLE_CDP = "79442"
WAKARUSA_TOWN = "79478"
WALDRON_CDP = "79568"
WALESBORO_CDP = "79604"
WALKERTON_TOWN = "79694"
WALL_LAKE_CDP = "79784"
WALLACE_TOWN = "79730"
WALTON_TOWN = "79964"
WANATAH_TOWN = "80018"
WARREN_PARK_TOWN = "80234"
WARREN_TOWN = "80108"
WARRINGTON_CDP = "80288"
WARSAW_CITY = "80306"
WASHINGTON_CITY = "80504"
WATERLOO_TOWN = "81278"
WAVELAND_TOWN = "81458"
WAVERLY_CDP = "81494"
WAWAKA_CDP = "81530"
WAYNESVILLE_CDP = "82034"
WAYNETOWN_TOWN = "82052"
WEBSTER_CDP = "82142"
WELLSBORO_CDP = "82250"
WEST_BADEN_SPRINGS_TOWN = "82376"
WEST_COLLEGE_CORNER_TOWN = "82556"
WEST_HARRISON_TOWN = "82790"
WEST_LAFAYETTE_CITY = "82862"
WEST_LEBANON_TOWN = "82934"
WEST_MIDDLETON_CDP = "83042"
WEST_POINT_CDP = "83222"
WEST_TERRE_HAUTE_TOWN = "83384"
WESTFIELD_CITY = "82700"
WESTPHALIA_CDP = "83204"
WESTPORT_TOWN = "83276"
WESTVILLE_TOWN = "83420"
WESTWOOD_CDP = "83456"
WHEATFIELD_TOWN = "83528"
WHEATLAND_TOWN = "83564"
WHEELER_CDP = "83600"
WHITELAND_TOWN = "83816"
WHITESTOWN_TOWN = "84014"
WHITEWATER_TOWN = "84086"
WHITING_CITY = "84122"
WILDWOOD_CDP = "84234"
WILKINSON_TOWN = "84302"
WILLIAMS_CDP = "84338"
WILLIAMS_CREEK_TOWN = "84374"
WILLIAMSBURG_CDP = "84356"
WILLIAMSPORT_TOWN = "84410"
WILLOW_BRANCH_CDP = "84482"
WINAMAC_TOWN = "84734"
WINCHESTER_CITY = "84752"
WINDFALL_CITY_TOWN = "84806"
WINDSOR_CDP = "84842"
WINFIELD_TOWN = "84878"
WINGATE_TOWN = "84914"
WINONA_LAKE_TOWN = "84950"
WINSLOW_TOWN = "84968"
WOLCOTT_TOWN = "85058"
WOLCOTTVILLE_TOWN = "85076"
WOLFLAKE_CDP = "85130"
WOODBURN_CITY = "85184"
WOODLAWN_HEIGHTS_TOWN = "85400"
WOOSTER_CDP = "85562"
WORTHINGTON_TOWN = "85598"
WYATT_CDP = "85724"
WYNNEDALE_TOWN = "85742"
YEOMAN_TOWN = "85886"
YORKTOWN_TOWN = "86084"
YOUNG_AMERICA_CDP = "86156"
ZANESVILLE_TOWN = "86318"
ZIONSVILLE_TOWN = "86372"
