# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in New York."""


ALBANY = "001"
ALLEGANY = "003"
BRONX = "005"
BROOME = "007"
CATTARAUGUS = "009"
CAYUGA = "011"
CHAUTAUQUA = "013"
CHEMUNG = "015"
CHENANGO = "017"
CLINTON = "019"
COLUMBIA = "021"
CORTLAND = "023"
DELAWARE = "025"
DUTCHESS = "027"
ERIE = "029"
ESSEX = "031"
FRANKLIN = "033"
FULTON = "035"
GENESEE = "037"
GREENE = "039"
HAMILTON = "041"
HERKIMER = "043"
JEFFERSON = "045"
KINGS = "047"
LEWIS = "049"
LIVINGSTON = "051"
MADISON = "053"
MONROE = "055"
MONTGOMERY = "057"
NASSAU = "059"
NEW_YORK = "061"
NIAGARA = "063"
ONEIDA = "065"
ONONDAGA = "067"
ONTARIO = "069"
ORANGE = "071"
ORLEANS = "073"
OSWEGO = "075"
OTSEGO = "077"
PUTNAM = "079"
QUEENS = "081"
RENSSELAER = "083"
RICHMOND = "085"
ROCKLAND = "087"
SARATOGA = "091"
SCHENECTADY = "093"
SCHOHARIE = "095"
SCHUYLER = "097"
SENECA = "099"
ST_LAWRENCE = "089"
STEUBEN = "101"
SUFFOLK = "103"
SULLIVAN = "105"
TIOGA = "107"
TOMPKINS = "109"
ULSTER = "111"
WARREN = "113"
WASHINGTON = "115"
WAYNE = "117"
WESTCHESTER = "119"
WYOMING = "121"
YATES = "123"
