# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Connecticut."""


ANSONIA_CITY = "01150"
BALL_POND_CDP = "02480"
BALTIC_CDP = "02550"
BANTAM_BOROUGH = "02690"
BETHEL_CDP = "04790"
BETHLEHEM_VILLAGE_CDP = "04945"
BIGELOW_CORNERS_CDP = "04965"
BLUE_HILLS_CDP = "06050"
BOGUS_HILL_CDP = "06155"
BOTSFORD_CDP = "06680"
BRANCHVILLE_CDP = "07100"
BRANFORD_CENTER_CDP = "07345"
BRIDGEPORT_CITY = "08000"
BRIDGEWATER_CDP = "08140"
BRISTOL_CITY = "08420"
BROAD_BROOK_CDP = "08770"
BROOKFIELD_CENTER_CDP = "09050"
BROOKLYN_CDP = "09120"
BYRAM_CDP = "10660"
CANAAN_CDP = "10870"
CANDLEWOOD_ISLE_CDP = "11360"
CANDLEWOOD_KNOLLS_CDP = "11430"
CANDLEWOOD_LAKE_CLUB_CDP = "11500"
CANDLEWOOD_ORCHARDS_CDP = "11640"
CANDLEWOOD_SHORES_CDP = "11780"
CANNONDALE_CDP = "11990"
CANTON_VALLEY_CDP = "12370"
CHESHIRE_VILLAGE_CDP = "14200"
CHESTER_CENTER_CDP = "14370"
CHIMNEY_POINT_CDP = "14615"
CLINTON_CDP = "15420"
COLCHESTER_CDP = "15840"
COLEYTOWN_CDP = "16085"
COLLINSVILLE_CDP = "16120"
COMPO_CDP = "16525"
CONNING_TOWERS_NAUTILUS_PARK_CDP = "16960"
CORNWALL_BRIDGE_CDP = "17310"
CORNWALL_CDP = "17170"
COS_COB_CDP = "17520"
COVENTRY_LAKE_CDP = "17835"
CRYSTAL_LAKE_CDP = "18220"
DANBURY_CITY = "18430"
DANIELS_FARM_CDP = "18675"
DANIELSON_BOROUGH = "18780"
DARIEN_DOWNTOWN_CDP = "18936"
DAYVILLE_CDP = "18990"
DEEP_RIVER_CENTER_CDP = "19200"
DERBY_CITY = "19480"
DODGINGTOWN_CDP = "20250"
DURHAM_CDP = "20740"
EAST_BROOKLYN_CDP = "21160"
EAST_HAMPTON_CDP = "22420"
EAST_HARTFORD_CDP = "22700"
EAST_HAVEN_CDP = "22980"
EAST_VILLAGE_CDP = "24520"
ESSEX_VILLAGE_CDP = "26370"
FAIRFIELD_UNIVERSITY_CDP = "26698"
FALLS_VILLAGE_CDP = "27390"
FENWICK_BOROUGH = "27810"
GALES_FERRY_CDP = "30190"
GAYLORDSVILLE_CDP = "30470"
GEORGETOWN_CDP = "30540"
GLASTONBURY_CENTER_CDP = "31270"
GLENVILLE_CDP = "31520"
GREENS_FARMS_CDP = "33480"
GREENWICH_CDP = "33690"
GROTON_LONG_POINT_BOROUGH = "34460"
GROTON_CITY = "34180"
GUILFORD_CENTER_CDP = "35020"
HARTFORD_CITY = "37000"
HAWLEYVILLE_CDP = "37490"
HAZARDVILLE_CDP = "37770"
HERITAGE_VILLAGE_CDP = "37930"
HIGGANUM_CDP = "38050"
INDIAN_FIELD_CDP = "39695"
INGLENOOK_CDP = "39747"
JEWETT_CITY_BOROUGH = "39940"
KELLOGG_POINT_CDP = "40077"
KENSINGTON_CDP = "40150"
KNOLLCREST_CDP = "40920"
LAKE_BUNGEE_CDP = "41226"
LAKE_CHAFFEE_CDP = "41238"
LAKE_POCOTOPAUG_CDP = "41410"
LAKES_EAST_CDP = "41585"
LAKES_WEST_CDP = "41736"
LAKESIDE_WOODS_CDP = "41714"
LAKEVILLE_CDP = "41830"
LITCHFIELD_BOROUGH = "43300"
LONG_HILL_CDP_GREATER_BRIDGEPORT_COUNTY = "43580"
LONG_HILL_CDP_SOUTHEASTERN_CONNECTICUT_COUNTY = "43790"
LORDSHIP_CDP = "44000"
MADISON_CENTER_CDP = "44630"
MAMANASCO_LAKE_CDP = "44660"
MANCHESTER_CDP = "44690"
MANSFIELD_CENTER_CDP = "45120"
MASHANTUCKET_CDP = "45995"
MECHANICSVILLE_CDP = "46240"
MERIDEN_CITY = "46450"
MIDDLETOWN_CITY = "47290"
MILFORD_CITY_BALANCE = "47515"
MILL_PLAIN_CDP = "47990"
MOODUS_CDP = "49110"
MOOSUP_CDP = "49180"
MURRAY_CDP = "49720"
MYSTIC_CDP = "49810"
NAUGATUCK_BOROUGH = "49880"
NEW_BRITAIN_CITY = "50370"
NEW_CANAAN_CDP = "50576"
NEW_HARTFORD_CENTER_CDP = "51420"
NEW_HAVEN_CITY = "52000"
NEW_LONDON_CITY = "52280"
NEW_MILFORD_CDP = "52560"
NEW_PRESTON_CDP = "52770"
NEWINGTON_CDP = "52210"
NEWTOWN_BOROUGH = "52910"
NIANTIC_CDP = "53120"
NOANK_CDP = "53260"
NORFOLK_CDP = "53400"
NOROTON_CDP = "53540"
NOROTON_HEIGHTS_CDP = "53610"
NORTH_GRANBY_CDP = "54660"
NORTH_GROSVENOR_DALE_CDP = "54730"
NORTH_HAVEN_CDP = "54940"
NORTHFORD_CDP = "54450"
NORTHWEST_HARWINTON_CDP = "55725"
NORWALK_CITY = "55990"
NORWICH_CITY = "56200"
OAKVILLE_CDP = "56690"
OLD_GREENWICH_CDP = "56900"
OLD_HILL_CDP = "56935"
OLD_MYSTIC_CDP = "57180"
OLD_SAYBROOK_CENTER_CDP = "57390"
ORANGE_CDP = "57670"
ORONOQUE_CDP = "57880"
OXOBOXO_RIVER_CDP = "58520"
PAWCATUCK_CDP = "59140"
PEMBERWICK_CDP = "59210"
PLAINFIELD_VILLAGE_CDP = "60090"
PLANTSVILLE_CDP = "60260"
PLATTSVILLE_CDP = "60365"
PLEASANT_VALLEY_CDP = "60540"
POPLAR_PLAINS_CDP = "61555"
POQUONOCK_BRIDGE_CDP = "61730"
PORTLAND_CDP = "61870"
PUTNAM_CDP = "62640"
QUASSET_LAKE_CDP = "63165"
QUINEBAUG_CDP = "63270"
QUINNIPIAC_UNIVERSITY_CDP = "63313"
REDDING_CENTER_CDP = "63620"
RIDGEBURY_CDP = "63830"
RIDGEFIELD_CDP = "63900"
RIVERSIDE_CDP = "64530"
RIVERTON_CDP = "64880"
ROCK_RIDGE_CDP = "65160"
ROCKVILLE_CDP = "65230"
ROUTE_7_GATEWAY_CDP = "65685"
SACRED_HEART_UNIVERSITY_CDP = "66086"
SAIL_HARBOR_CDP = "66113"
SALMON_BROOK_CDP = "66455"
SANDY_HOOK_CDP = "66700"
SAUGATUCK_CDP = "66770"
SAYBROOK_MANOR_CDP = "67050"
SHARON_CDP = "67890"
SHELTON_CITY = "68100"
SHERMAN_CDP = "68240"
SHERWOOD_MANOR_CDP = "68450"
SIMSBURY_CENTER_CDP = "69010"
SOMERS_CDP = "69150"
SOUTH_COVENTRY_CDP = "69990"
SOUTH_WILTON_CDP = "71215"
SOUTH_WINDHAM_CDP = "71250"
SOUTH_WOODSTOCK_CDP = "71530"
SOUTHPORT_CDP = "71040"
SOUTHWOOD_ACRES_CDP = "71460"
STAFFORD_SPRINGS_CDP = "72300"
STAMFORD_CITY = "73000"
STAPLES_CDP = "73175"
STEPNEY_CDP = "73280"
STONINGTON_BOROUGH = "73700"
STORRS_CDP = "73980"
STRATFORD_DOWNTOWN_CDP = "74303"
SUFFIELD_DEPOT_CDP = "74655"
TARIFFVILLE_CDP = "75100"
TASHUA_CDP = "75116"
TAYLOR_CORNERS_CDP = "75065"
TERRAMUGGUS_CDP = "75200"
TERRYVILLE_CDP = "75240"
THOMASTON_CDP = "75660"
THOMPSONVILLE_CDP = "75940"
TOKENEKE_CDP = "76150"
TOPSTONE_CDP = "76400"
TORRINGTON_CITY = "76500"
TRUMBULL_CENTER_CDP = "77278"
WALLINGFORD_CENTER_CDP = "78880"
WATERBURY_CITY = "80000"
WATERFORD_CDP = "80210"
WATERTOWN_CDP = "80420"
WAUREGAN_CDP = "80630"
WEATOGUE_CDP = "80770"
WEST_CORNWALL_CDP = "82030"
WEST_HARTFORD_CDP = "82660"
WEST_HAVEN_CITY = "82800"
WEST_MOUNTAIN_CDP = "83045"
WEST_SIMSBURY_CDP = "83990"
WESTBROOK_CENTER_CDP = "81750"
WESTON_CDP = "83360"
WESTPORT_VILLAGE_CDP = "83586"
WETHERSFIELD_CDP = "84970"
WILLIMANTIC_CDP = "85810"
WILTON_CENTER_CDP = "86380"
WINDSOR_LOCKS_CDP = "87140"
WINSTED_CDP = "87350"
WITCHES_WOODS_CDP = "87455"
WOODBURY_CENTER_CDP = "87980"
WOODMONT_BOROUGH = "88050"
