# Copyright (c) 2023 Darren Erik Vengroff
"""Places in South Carolina."""


ABBEVILLE_CITY = "00100"
ABNEY_CROSSROADS_CDP = "00165"
ADAMS_RUN_CDP = "00370"
AIKEN_CITY = "00550"
ALCOLU_CDP = "00775"
ALLENDALE_TOWN = "00955"
ANDERSON_CITY = "01360"
ANDREWS_TOWN = "01450"
ANTREVILLE_CDP = "01810"
ARCADIA_CDP = "02080"
ARCADIA_LAKES_TOWN = "02125"
ARIAL_CDP = "02440"
ARKWRIGHT_CDP = "02530"
ARTHURTOWN_CDP = "02665"
ASHWOOD_CDP = "03115"
ATLANTIC_BEACH_TOWN = "03205"
AWENDAW_TOWN = "03385"
AYNOR_TOWN = "03430"
BAMBERG_TOWN = "03790"
BARNWELL_CITY = "04060"
BATESBURG_LEESVILLE_TOWN = "04300"
BAXTER_VILLAGE_CDP = "04528"
BEAUFORT_CITY = "04690"
BEECH_ISLAND_CDP = "04915"
BELTON_CITY = "05365"
BELVEDERE_CDP = "05410"
BEN_AVON_CDP = "05545"
BENNETTSVILLE_CITY = "05680"
BEREA_CDP = "05770"
BETHUNE_TOWN = "06040"
BISHOPVILLE_CITY = "06310"
BLACKSBURG_TOWN = "06400"
BLACKVILLE_TOWN = "06490"
BLENHEIM_TOWN = "06850"
BLUFFTON_TOWN = "07210"
BLYTHEWOOD_TOWN = "07255"
BOILING_SPRINGS_CDP = "07345"
BONNEAU_BEACH_CDP = "07535"
BONNEAU_TOWN = "07525"
BOWMAN_TOWN = "07840"
BOYKIN_CDP = "08110"
BRADLEY_CDP = "08155"
BRANCHVILLE_TOWN = "08245"
BRIARCLIFFE_ACRES_TOWN = "08830"
BROOKDALE_CDP = "09527"
BROWNTOWN_CDP = "09782"
BRUNSON_TOWN = "09865"
BUCKSPORT_CDP = "10000"
BUFFALO_CDP = "10090"
BUFORD_CDP = "10135"
BURNETTOWN_TOWN = "10270"
BURTON_CDP = "10360"
CAESARS_HEAD_CDP = "10585"
CALHOUN_FALLS_TOWN = "10720"
CAMDEN_CITY = "10855"
CAMERON_TOWN = "10900"
CAMP_CROFT_CDP = "11035"
CAMPOBELLO_TOWN = "11125"
CANE_SAVANNAH_CDP = "11350"
CAPITOL_VIEW_CDP = "11620"
CARLISLE_TOWN = "11755"
CAROLINA_FOREST_CDP = "11833"
CASH_CDP = "12205"
CATAWBA_CDP = "12430"
CATEECHEE_CDP = "12520"
CAYCE_CITY = "12655"
CENTENARY_CDP = "12925"
CENTERVILLE_CDP = "12965"
CENTRAL_PACOLET_TOWN = "13060"
CENTRAL_TOWN = "13015"
CHAPIN_TOWN = "13150"
CHARLESTON_CITY = "13330"
CHERAW_TOWN = "13600"
CHEROKEE_FALLS_CDP = "13735"
CHERRYVALE_CDP = "14018"
CHESNEE_CITY = "14050"
CHESTER_CITY = "14095"
CHESTERFIELD_TOWN = "14140"
CHICKASAW_POINT_CDP = "14230"
CITY_VIEW_CDP = "14455"
CLARKS_HILL_CDP = "14590"
CLEARWATER_CDP = "14860"
CLEMSON_UNIVERSITY_CDP = "15040"
CLEMSON_CITY = "14950"
CLIFTON_CDP = "15220"
CLINTON_CITY = "15295"
CLIO_TOWN = "15310"
CLOVER_TOWN = "15355"
COKESBURY_CDP = "15625"
COLUMBIA_CITY = "16000"
CONESTEE_CDP = "16180"
CONVERSE_CDP = "16360"
CONWAY_CITY = "16405"
COOSAWHATCHIE_CDP = "16675"
COPE_TOWN = "16720"
CORDOVA_TOWN = "16855"
CORONACA_CDP = "16945"
COTTAGEVILLE_TOWN = "16990"
COWARD_TOWN = "17215"
COWPENS_TOWN = "17260"
CROSS_ANCHOR_CDP = "17845"
CROSS_HILL_TOWN = "17890"
DACUSVILLE_CDP = "18250"
DALE_CDP = "18340"
DALZELL_CDP = "18430"
DANWOOD_CDP = "18475"
DARLINGTON_CITY = "18565"
DAUFUSKIE_ISLAND_CDP = "18610"
DAVISTON_CDP = "18706"
DEBORDIEU_COLONY_CDP = "18810"
DENMARK_CITY = "19105"
DENTSVILLE_CDP = "19285"
DILLON_CITY = "19420"
DONALDS_TOWN = "19870"
DOVESVILLE_CDP = "20365"
DRAYTON_CDP = "20590"
DUE_WEST_TOWN = "21040"
DUNBAR_CDP = "21130"
DUNCAN_TOWN = "21265"
DUNEAN_CDP = "21310"
EASLEY_CITY = "21985"
EAST_CAMDEN_CDP = "22050"
EAST_GAFFNEY_CDP = "22075"
EAST_SUMTER_CDP = "22547"
EASTOVER_TOWN = "22390"
EDGEFIELD_TOWN = "22795"
EDISTO_BEACH_TOWN = "23020"
EDISTO_CDP = "22997"
EDMUND_CDP = "23110"
EHRHARDT_TOWN = "23200"
ELGIN_CDP = "23290"
ELGIN_TOWN = "23245"
ELKO_TOWN = "23335"
ELLIOTT_CDP = "23425"
ELLOREE_TOWN = "23470"
ENOREE_CDP = "23605"
ESTILL_TOWN = "23830"
EUREKA_MILL_CDP = "24020"
EUTAWVILLE_TOWN = "24100"
FAIR_PLAY_CDP = "24730"
FAIRFAX_TOWN = "24370"
FAIRFOREST_CDP = "24505"
FAIRVIEW_CROSSROADS_CDP = "24865"
FINGERVILLE_CDP = "25360"
FINKLEA_CDP = "25405"
FIVE_FORKS_CDP = "25540"
FLORENCE_CITY = "25810"
FLOYDALE_CDP = "25945"
FOLLY_BEACH_CITY = "26035"
FOREST_ACRES_CITY = "26305"
FORESTBROOK_CDP = "26372"
FORESTON_CDP = "26485"
FORT_LAWN_TOWN = "26845"
FORT_MILL_TOWN = "26890"
FOUNTAIN_INN_CITY = "27070"
FRIPP_ISLAND_CDP = "27565"
FURMAN_TOWN = "27835"
GADSDEN_CDP = "27970"
GAFFNEY_CITY = "28060"
GANTT_CDP = "28375"
GARDEN_CITY_CDP = "28455"
GASTON_TOWN = "28780"
GAYLE_MILL_CDP = "28825"
GEORGETOWN_CITY = "28870"
GIFFORD_TOWN = "29005"
GILBERT_TOWN = "29050"
GILLISONVILLE_CDP = "29140"
GLENDALE_CDP = "29275"
GLENN_SPRINGS_CDP = "29320"
GLOVERVILLE_CDP = "29410"
GOLDEN_GROVE_CDP = "29635"
GOOSE_CREEK_CITY = "29815"
GOVAN_TOWN = "29950"
GRAMLING_CDP = "30220"
GRANITEVILLE_CDP = "30265"
GRAY_COURT_TOWN = "30355"
GREAT_FALLS_TOWN = "30490"
GREELEYVILLE_TOWN = "30535"
GREEN_SEA_CDP = "30760"
GREENVILLE_CITY = "30850"
GREENWOOD_CITY = "30895"
GREER_CITY = "30985"
GROVER_CDP = "31210"
HAMER_CDP = "31660"
HAMPTON_TOWN = "31885"
HANAHAN_CITY = "32065"
HARBOR_ISLAND_CDP = "32172"
HARDEEVILLE_CITY = "32245"
HARLEYVILLE_TOWN = "32335"
HARTSVILLE_CITY = "32560"
HEATH_SPRINGS_TOWN = "32965"
HELENA_CDP = "33100"
HEMINGWAY_TOWN = "33145"
HICKORY_GROVE_TOWN = "33640"
HILDA_TOWN = "33820"
HILLTOP_CDP = "33977"
HILTON_HEAD_ISLAND_TOWN = "34045"
HODGES_TOWN = "34225"
HOLLY_HILL_TOWN = "34360"
HOLLYWOOD_TOWN = "34495"
HOMELAND_PARK_CDP = "34720"
HOMEWOOD_CDP = "34765"
HONEA_PATH_TOWN = "34810"
HOPKINS_CDP = "34990"
INDIA_HOOK_CDP = "35635"
INMAN_MILLS_CDP = "35800"
INMAN_CITY = "35755"
IRMO_TOWN = "35890"
IRWIN_CDP = "35980"
ISLANDTON_CDP = "36070"
ISLE_OF_PALMS_CITY = "36115"
IVA_TOWN = "36160"
JACKSON_TOWN = "36205"
JACKSONBORO_CDP = "36250"
JAMES_ISLAND_TOWN = "36430"
JAMESTOWN_TOWN = "36475"
JEFFERSON_TOWN = "36610"
JENKINSVILLE_TOWN = "36655"
JOANNA_CDP = "36790"
JOHNSONVILLE_CITY = "37105"
JOHNSTON_TOWN = "37150"
JONESVILLE_TOWN = "37330"
JUDSON_CDP = "37465"
KEOWEE_KEY_CDP = "38058"
KERSHAW_TOWN = "38095"
KETCHUPTOWN_CDP = "38110"
KIAWAH_ISLAND_TOWN = "38162"
KINGSTREE_TOWN = "38590"
KLINE_TOWN = "38950"
LA_FRANCE_CDP = "39265"
LADSON_CDP = "39220"
LAKE_CITY_CITY = "39310"
LAKE_MURRAY_OF_RICHLAND_CDP = "39475"
LAKE_SECESSION_CDP = "39512"
LAKE_VIEW_TOWN = "39715"
LAKE_WYLIE_CDP = "39785"
LAKEWOOD_CDP = "39772"
LAMAR_TOWN = "39805"
LANCASTER_CITY = "39895"
LANDRUM_CITY = "40075"
LANE_TOWN = "40210"
LANGLEY_CDP = "40390"
LATTA_TOWN = "40480"
LAUREL_BAY_CDP = "40525"
LAURENS_CITY = "40615"
LESSLIE_CDP = "41065"
LEXINGTON_TOWN = "41335"
LIBERTY_CITY = "41380"
LINCOLNVILLE_TOWN = "41740"
LITCHFIELD_BEACH_CDP = "41830"
LITTLE_MOUNTAIN_TOWN = "41965"
LITTLE_RIVER_CDP = "42010"
LITTLE_ROCK_CDP = "42055"
LIVE_OAK_CDP = "42095"
LIVINGSTON_TOWN = "42100"
LOBECO_CDP = "42145"
LOCKHART_TOWN = "42190"
LODGE_TOWN = "42280"
LONGCREEK_CDP = "42460"
LORIS_CITY = "42730"
LOWNDESVILLE_TOWN = "42820"
LOWRYS_TOWN = "42865"
LUGOFF_CDP = "43000"
LURAY_TOWN = "43090"
LYDIA_CDP = "43135"
LYMAN_TOWN = "43315"
LYNCHBURG_TOWN = "43360"
MANNING_CITY = "44350"
MANVILLE_CDP = "44395"
MARION_CITY = "44575"
MAULDIN_CITY = "45115"
MAYESVILLE_TOWN = "45295"
MAYO_CDP = "45430"
MCBEE_TOWN = "43495"
MCCLELLANVILLE_TOWN = "43585"
MCCOLL_TOWN = "43630"
MCCONNELLS_TOWN = "43675"
MCCORMICK_TOWN = "43720"
MEGGETT_TOWN = "45790"
MODOC_CDP = "47050"
MONARCH_MILL_CDP = "47200"
MONCKS_CORNER_TOWN = "47275"
MONETTA_TOWN = "47320"
MOUNT_CARMEL_CDP = "48310"
MOUNT_CROGHAN_TOWN = "48355"
MOUNT_PLEASANT_TOWN = "48535"
MOUNTVILLE_CDP = "48670"
MULBERRY_CDP = "48737"
MULLINS_CITY = "48805"
MURPHYS_ESTATES_CDP = "48900"
MURRELLS_INLET_CDP = "48985"
MYRTLE_BEACH_CITY = "49075"
NEESES_TOWN = "49390"
NEW_ELLENTON_TOWN = "49705"
NEWBERRY_CITY = "49570"
NEWPORT_CDP = "49885"
NEWRY_CDP = "49975"
NEWTOWN_CDP = "50020"
NICHOLS_TOWN = "50110"
NINETY_SIX_TOWN = "50290"
NORRIS_TOWN = "50515"
NORTH_AUGUSTA_CITY = "50695"
NORTH_CHARLESTON_CITY = "50875"
NORTH_HARTSVILLE_CDP = "51145"
NORTH_MYRTLE_BEACH_CITY = "51280"
NORTH_SANTEE_CDP = "51367"
NORTH_TOWN = "50560"
NORTHLAKE_CDP = "51180"
NORWAY_TOWN = "51550"
OAK_GROVE_CDP = "51720"
OAKLAND_CDP = "51887"
OLANTA_TOWN = "52540"
OLAR_TOWN = "52585"
OLYMPIA_CDP = "52900"
ORANGEBURG_CITY = "53080"
OSWEGO_CDP = "53485"
PACOLET_TOWN = "53845"
PAGELAND_TOWN = "54025"
PAMPLICO_TOWN = "54340"
PARKER_CDP = "54535"
PARKSVILLE_TOWN = "54700"
PATRICK_TOWN = "54925"
PAULINE_CDP = "54970"
PAWLEYS_ISLAND_TOWN = "55015"
PAXVILLE_TOWN = "55060"
PEAK_TOWN = "55150"
PELION_TOWN = "55420"
PELZER_TOWN = "55465"
PENDLETON_TOWN = "55645"
PERRY_TOWN = "55960"
PICKENS_CITY = "56140"
PIEDMONT_CDP = "56365"
PIMLICO_CDP = "56545"
PINE_RIDGE_CDP = "56905"
PINE_RIDGE_TOWN = "56950"
PINEWOOD_TOWN = "57085"
PINOPOLIS_CDP = "57175"
PLUM_BRANCH_TOWN = "57670"
POMARIA_TOWN = "57850"
PORT_ROYAL_TOWN = "58030"
POWDERSVILLE_CDP = "58170"
PRINCETON_CDP = "58435"
PRIVATEER_CDP = "58570"
PROMISED_LAND_CDP = "58615"
PROSPERITY_TOWN = "58705"
QUINBY_TOWN = "58795"
RAINS_CDP = "58930"
RAVENEL_TOWN = "59020"
RED_BANK_CDP = "59110"
RED_HILL_CDP = "59190"
REEVESVILLE_TOWN = "59380"
REIDVILLE_TOWN = "59425"
REMBERT_CDP = "59470"
RICHBURG_TOWN = "59920"
RIDGE_SPRING_TOWN = "60325"
RIDGELAND_TOWN = "60280"
RIDGEVILLE_TOWN = "60370"
RIDGEWAY_TOWN = "60415"
RIVERVIEW_CDP = "61112"
ROCK_HILL_CITY = "61405"
ROCKVILLE_TOWN = "61495"
ROEBUCK_CDP = "61720"
ROWESVILLE_TOWN = "62035"
RUBY_TOWN = "62080"
RUSSELLVILLE_CDP = "62305"
SALEM_TOWN = "62980"
SALLEY_TOWN = "63115"
SALUDA_TOWN = "63250"
SANDY_SPRINGS_CDP = "63655"
SANGAREE_CDP = "63665"
SANS_SOUCI_CDP = "63700"
SANTEE_TOWN = "63790"
SAXON_CDP = "64240"
SCOTIA_TOWN = "64465"
SCRANTON_TOWN = "64600"
SEABROOK_CDP = "64690"
SEABROOK_ISLAND_TOWN = "64712"
SELLERS_TOWN = "65005"
SENECA_CITY = "65095"
SEVEN_OAKS_CDP = "65207"
SHARON_TOWN = "65410"
SHELDON_CDP = "65590"
SHELL_POINT_CDP = "65680"
SHILOH_CDP = "65950"
SILVERSTREET_TOWN = "66400"
SIMPSONVILLE_CITY = "66580"
SIX_MILE_TOWN = "66760"
SLATER_MARIETTA_CDP = "66917"
SMOAKS_TOWN = "67165"
SMYRNA_TOWN = "67210"
SNELLING_TOWN = "67255"
SOCASTEE_CDP = "67390"
SOCIETY_HILL_TOWN = "67435"
SOUTH_CONGAREE_TOWN = "67705"
SOUTH_SUMTER_CDP = "68177"
SOUTH_UNION_CDP = "68210"
SOUTHERN_SHOPS_CDP = "67750"
SPARTANBURG_CITY = "68290"
SPRINGDALE_CDP = "68380"
SPRINGDALE_TOWN = "68425"
SPRINGFIELD_TOWN = "68470"
ST_ANDREWS_CDP = "62395"
ST_CHARLES_CDP = "62485"
ST_GEORGE_TOWN = "62530"
ST_MATTHEWS_TOWN = "62620"
ST_STEPHEN_TOWN = "62755"
STARR_TOWN = "68875"
STARTEX_CDP = "68920"
STATEBURG_CDP = "69010"
STUCKEY_TOWN = "70045"
SULLIVANS_ISLAND_TOWN = "70090"
SUMMERTON_TOWN = "70225"
SUMMERVILLE_TOWN = "70270"
SUMMIT_TOWN = "70315"
SUMTER_CITY = "70405"
SURFSIDE_BEACH_TOWN = "70585"
SWANSEA_TOWN = "70675"
SYCAMORE_TOWN = "70900"
TAMASSEE_CDP = "71170"
TATUM_TOWN = "71305"
TAYLORS_CDP = "71395"
TEGA_CAY_CITY = "71417"
THE_CLIFFS_VALLEY_CDP = "71658"
TIGERVILLE_CDP = "71890"
TIMMONSVILLE_TOWN = "71980"
TRADESVILLE_CDP = "72295"
TRAVELERS_REST_CITY = "72430"
TRENTON_TOWN = "72520"
TROY_TOWN = "72655"
TURBEVILLE_TOWN = "72745"
ULMER_TOWN = "72880"
UNION_CITY = "73105"
UNITY_CDP = "73240"
UTICA_CDP = "73330"
VALLEY_FALLS_CDP = "73465"
VAN_WYCK_TOWN = "73555"
VANCE_TOWN = "73510"
VARNVILLE_TOWN = "73600"
WADE_HAMPTON_CDP = "73870"
WAGENER_TOWN = "74050"
WALHALLA_CITY = "74095"
WALLACE_CDP = "74140"
WALTERBORO_CITY = "74275"
WARD_TOWN = "74590"
WARE_PLACE_CDP = "74635"
WARE_SHOALS_TOWN = "74680"
WARRENVILLE_CDP = "74725"
WATERLOO_TOWN = "74995"
WATTS_MILLS_CDP = "75220"
WEDGEFIELD_CDP = "75445"
WELCOME_CDP = "75535"
WELLFORD_CITY = "75580"
WEST_COLUMBIA_CITY = "75850"
WEST_PELZER_TOWN = "76345"
WEST_UNION_TOWN = "76435"
WESTMINSTER_CITY = "76165"
WHITE_KNOLL_CDP = "77042"
WHITMIRE_TOWN = "77380"
WHITNEY_CDP = "77425"
WILKINSON_HEIGHTS_CDP = "77672"
WILLIAMS_TOWN = "77785"
WILLIAMSTON_TOWN = "77875"
WILLINGTON_CDP = "77920"
WILLISTON_TOWN = "77965"
WINDSOR_TOWN = "78190"
WINNSBORO_MILLS_CDP = "78505"
WINNSBORO_TOWN = "78460"
WISACKY_CDP = "78640"
WOODFIELD_CDP = "78820"
WOODFORD_TOWN = "78910"
WOODRUFF_CITY = "79090"
WYBOO_CDP = "79341"
YEMASSEE_TOWN = "79450"
YORK_CITY = "79630"
ZION_CDP = "79720"
